use std::collections::HashMap;
use std::hash::{Hash, Hasher};
#[derive(Debug)]
pub enum LinkType {
    Terrestrial,
    Submarine,
}
#[derive(Debug)]
pub struct LinkTo {
    pub code: &'static str,
    pub distance: f64,
    pub link_type: LinkType,
}
#[derive(Debug)]
pub struct Country {
    pub code: &'static str,
    pub name: &'static str,
    pub continent: Option<&'static str>,
    pub other_names: Vec<&'static str>,
    pub cable_connections_number: usize,
    pub internet_exchanges_number: usize,
    pub links: Vec<LinkTo>,
}
impl PartialEq for Country {
    fn eq(&self, other: &Self) -> bool {
        self.code == other.code
    }
}
impl Hash for Country {
    fn hash<H: Hasher>(&self, state: &mut H) {
        self.code.hash(state);
    }
}
impl Eq for Country {}
impl Country {
    pub fn from_str(s: &str) -> Option<&'static Country> {
        lazy_static! {
            static ref COUNTRIES: Vec<Country> = vec![
                Country {
                    code: "CX",
                    name: "Christmas Island",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 1usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "SG",
                            distance: 1322425.982f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PW",
                            distance: 3768485.802f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 5063800.933f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 8537023.472f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 7446108.256f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 8927991.097f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 485652.038f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 12616953.47f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 9043154.573f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 7867544.051f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 2610373.304f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 10077326.609f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 9008904.837f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 6878206.288f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 8274185.187f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 5825061.11f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 5206037.744f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 6775070.646f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 9175173.675f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 5797864.752f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 8359612.176f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 7337355.62f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 11441741.344f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 4604297.897f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "DM",
                    name: "Dominica",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 2489371.289f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 2722584.607f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1700764.385f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1934739.461f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1579978.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 613173.965f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1874908.642f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 1923353.404f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 375477.552f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3550469.287f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1346274.436f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 1239284.571f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 5303164.34f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 3918830.218f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 2120025.305f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 974601.013f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SX",
                            distance: 358507.717f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 240700.264f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 2865939.296f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 491508.105f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 457547.556f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5585593.134f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 106544.719f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 2406324.886f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 186142.759f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 963485.92f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 264312.94f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 514213.24f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 212215.059f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 328060.614f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 82604.157f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 312530.574f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 368945.551f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 147266.524f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 887642.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "US",
                            distance: 4543768.287f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 312121.72f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 2998394.864f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "FM",
                    name: "Micronesia, Federated States of",
                    continent: Some("Oceania"),
                    other_names: vec!["Micronesia"],
                    cable_connections_number: 6usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "PW",
                            distance: 439777.09f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 849818.052f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 4531563.278f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 5545663.081f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 4361938.221f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 1694216.494f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 6885641.231f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 4495820.854f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 3838016.996f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 10647862.641f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 5825061.11f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 5820108.233f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 4110147.271f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 1185361.321f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 3732581.919f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 1699926.861f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 1394703.155f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 6915230.167f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 931874.153f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 1307364.202f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 3177376.962f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 4740237.823f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 1816758.877f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 3883722.211f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 6875005.551f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 1787437.019f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "NI",
                    name: "Nicaragua",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 236704.618f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 621668.448f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 900272.166f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 522826.054f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1160745.662f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 1617444.295f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 2033886.463f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1630727.158f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 2875882.219f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 2271543.542f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 4550545.173f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1653136.087f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 1345789.796f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 4128483.458f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 1061363.953f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 765331.473f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 1481145.059f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 2419068.833f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 774093.57f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 2117424.593f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 2079830.758f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 6285673.067f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 2390446.889f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 919075.227f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 1595667.611f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 666194.673f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 1645006.906f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 1476628.436f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 1550805.014f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 2406324.886f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 1592779.565f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 2425088.731f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 2597742.166f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 2443582.048f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 2376110.68f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 2251363.983f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 2286901.558f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 2433500.051f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 2285996.056f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 2375991.654f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "PG",
                    name: "Papua New Guinea",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 18usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "PW",
                            distance: 2108506.126f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 2082644.987f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 4363476.054f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 4509137.306f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 4529025.547f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 1380513.043f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 8451689.815f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 4658454.58f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 3618158.51f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 4604297.897f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 5887648.128f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 4497484.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 2302649.085f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 3843187.81f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 1787437.019f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 2369071.313f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 2593708.21f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 2742953.514f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 4571888.942f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 1485504.117f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 3959455.25f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 2923259.912f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 7167710.823f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "AO",
                    name: "Angola",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 6usize,
                    internet_exchanges_number: 3usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 12198042.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 4007751.53f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 2944971.095f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 2521400.463f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 2237289.026f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 5177290.304f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 2076278.214f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 1565469.162f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 2185241.979f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 406463.585f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 4873226.89f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 5829783.536f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 1473263.823f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 2700978.181f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 2073667.379f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 4284424.467f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 1108282.256f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 5746132.828f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 2307742.955f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 4072016.41f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 3323940.387f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 3100928.99f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 1187952.895f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 2530004.527f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 2202612.088f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 3862443.194f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 3457617.875f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 3890992.264f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 1888492.214f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 5085383.613f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 4083259.321f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 3562220.19f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 4330331.593f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 2779673.683f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 5048187.299f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 3375808.675f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 2766973.536f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 4753694.38f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 1206430.626f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 4555618.725f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 5056736.975f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 6713756.449f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 2204882.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 3549094.013f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 2018202.875f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 4718789.673f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 2732589.418f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 2841752.311f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 4000646.756f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 2371212.079f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 2806113.815f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "BN",
                    name: "Brunei",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 4usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 4258602.418f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 7501674.271f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 11073139.641f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 10408675.275f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 6684632.681f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 7202221.147f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 10367038.757f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 6065448.85f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 4020389.616f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 10015153.748f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 5725665.115f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 2023997.112f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 12510498.828f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 11649084.154f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 11093342.926f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 7088487.005f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 1948676.886f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5561688.318f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 1342672.524f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 6365926.565f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 10143830.963f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 9380005.854f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 1269197.961f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 12313089.768f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 3417107.044f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 11589389.199f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 10745140.292f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 9639705.256f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 7283026.367f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 1650116.329f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 3619232.044f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 5775936.568f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 11703359.066f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 2445904.431f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 1520014.601f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 9003520.903f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 7690058.499f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 6830607.166f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 1943651.471f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 12702276.671f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 8329242.925f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 9566341.744f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 9563144.723f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 14532565.818f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 10862401.303f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 11008081.156f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 10316832.81f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 13542025.577f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 9710970.758f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 11498894.57f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 14966586.567f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 9389961.919f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 10310469.229f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 11022720.219f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 3878418.302f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 10035913.08f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 4102137.291f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 48178.402f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 9768467.793f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 12936713.686f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 9950428.637f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 8257567.914f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 10748530.225f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 12344689.84f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 9940743.548f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 8754763.041f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 8687061.375f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 9059131.663f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 8741576.66f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 8712075.349f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 10308740.004f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 12712858.337f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 10954415.744f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 1435437.814f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 10517453.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 15178846.213f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 9967545.391f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 13809853.389f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 10399800.741f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 4291346.519f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 6619450.213f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 1236397.244f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 4609377.3f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 9559744.196f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 10675412.084f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 3165224.658f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 14428315.118f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 10915739.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 9248780.136f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 9483864.513f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 7911485.489f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 9615715.492f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 8277775.131f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 7674717.102f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 3658508.777f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 11507024.89f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "TN",
                    name: "Tunisia",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 5usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 8553998.251f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 4608323.75f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 5533613.653f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 5048187.299f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 7097373.113f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 3564871.782f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 3824603.295f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 3763650.663f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 4732197.079f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 3324904.439f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5530240.126f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 4046917.281f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 6651088.229f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 4098933.116f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 10251586.366f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 6406666.262f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 6130048.957f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 7410925.145f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 3980013.123f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 3848887.439f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 159961.122f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 9580305.637f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 769753.231f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 4893033.172f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 191882.262f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 3296890.458f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3318067.115f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 5620363.725f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 3721054.596f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 3914046.958f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 3340611.887f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 7583072.334f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 1956313.056f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 7405042.448f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 7775985.497f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 7913936.802f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4572052.502f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 10062514.603f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 4374183.114f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4244898.644f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 7639717.092f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 3731974.598f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 6448224.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 3437175.797f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 7361973.424f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 7972922.894f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 3929284.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 874874.789f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 8101827.304f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 3179195.545f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 6459146.694f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 4139866.161f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 6616360.581f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 4777135.3f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 3509010.514f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 3666688.08f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 5534430.372f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 7153731.016f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 4665382.632f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 2995250.111f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "TO",
                    name: "Tonga",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 4usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "PW",
                            distance: 6347532.937f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 5805291.765f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 745544.753f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 2322329.295f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 770706.947f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 6587941.589f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 781078.613f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 8537023.472f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 1556239.9f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 1272115.535f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 3054028.429f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 904718.614f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 4531563.278f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 5833706.846f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 1807287.706f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 4289664.328f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 2442935.852f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 3166039.251f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 758089.701f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 3605273.911f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 2908072.975f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 4363476.054f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "IN",
                    name: "India",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 29usize,
                    internet_exchanges_number: 45usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 6721222.796f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 2764474.325f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 7991319.756f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 4451123.27f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 6087872.712f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3022988.171f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 2411064.446f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 6094454.556f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 2123028.388f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 928338.848f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 6123225.666f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 1446277.648f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 4915973.809f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 8922133.745f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 7584609.353f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 7421395.613f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 2314700.703f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 4275020.966f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 1928201.255f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 3417464.922f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 2414807.743f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 5769361.32f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 5659410.747f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 2887909.756f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 7739269.868f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 7564342.383f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 6074099.231f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 5681359.457f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 2930742.626f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 3249860.512f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 5720281.151f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 2095065.483f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 8490851.291f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 1749866.468f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 3827877.799f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 5222653.028f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 7592052.475f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 2734385.339f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 3734534.167f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 2487513.74f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 3766098.819f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3517840.032f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 5761939.521f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 5710505.386f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 11759975.638f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 6582491.972f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 6601047.646f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 5972026.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 10870166.254f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 5311683.06f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 8028706.241f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 7405042.448f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 12529779.168f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 5322931.871f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 6592952.242f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 6917912.733f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 525146.62f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 5748524.085f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 6927625.747f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 6276436.373f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 3345885.008f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 5978921.897f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 4134671.561f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 12135817.164f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 5586357.147f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 6081258.275f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 3884943.39f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 3956813.647f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 6466170.248f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 8616689.234f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 5782758.466f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3989832.95f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 4184955.853f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 4853636.801f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 4226029.133f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 4022932.977f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 6094643.972f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 7716637.572f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 6547963.46f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 3523124.938f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 6478162.821f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 12742162.619f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 5587353.433f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 12345412.818f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 6392382.544f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 4500828.725f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 1830191.475f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 4674200.358f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 3289457.572f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 6635204.803f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 4886800.599f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 4291346.519f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 2214419.2f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 1659248.141f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 1555232.114f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 5205377.711f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 6493977.235f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 13010216.352f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 6709722.09f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 5584472.922f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 4595851.805f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 1312489.957f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 7323388.539f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "PT",
                    name: "Portugal",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 30usize,
                    internet_exchanges_number: 6usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 11535098.222f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 6866970.313f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 5914776.765f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1703892.227f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 6915391.792f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 2664794.244f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 6433499.542f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 6309666.283f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 2700855.449f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 7002463.001f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 5829783.536f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 9066505.722f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 3260498.651f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 7383855.1f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 3762348.85f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 3740174.766f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 2895283.316f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 11474808.083f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 5428087.107f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 3786768.668f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 1323084.977f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 3796132.49f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 4273011.179f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 2991515.052f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 7249894.028f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 8485104.975f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1401122.14f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 2784939.914f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 7117736.601f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 5976667.638f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1644037.782f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 4669378.961f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 8367215.178f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 8407874.873f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 1334265.749f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 3847160.116f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 4928365.776f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 6547292.679f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4729023.153f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 3752388.757f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 12677960.212f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 12236411.852f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2943736.062f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 10691655.342f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 8922133.745f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 11118645.089f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 6230369.258f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 10771715.113f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 7161781.404f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 3271070.369f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 11817513.587f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 9446461.231f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 15035908.741f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 10119298.199f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 11185635.246f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 11870609.979f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 12510498.828f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 459171.036f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 3701697.954f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 4532112.813f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 3273441.393f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 3381270.067f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 3604630.859f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 2379955.549f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 4568975.655f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 3060493.985f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 4642357.124f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 418239.786f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1500910.096f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 2100632.364f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 9666194.226f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 6086712.023f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 2715130.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 6444876.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 11772332.918f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 2958866.319f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1793160.304f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 3546324.937f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 5825136.809f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 7301061.293f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 5640211.09f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 6517492.945f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 11521913.328f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 3727778.866f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 3692346.471f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 4390445.16f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 2205957.261f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 2766410.393f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 4240157.671f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 3414386.747f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 2852454.144f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 5103583.074f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 3721405.517f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 3199465f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 2159679.546f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 3032835.574f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 6993458.198f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 3145664.467f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 4852899.698f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 2319426.613f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 3149518.792f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 4788212.251f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 4626618.394f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 4009740.325f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 4693003.26f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 4637202.326f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 2768976.564f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 2184426.037f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 2680001.687f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 5199135.23f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 3140219.113f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 6169263.993f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 2814950.703f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 9777607.477f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 3532610.451f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 2424847.13f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 9945423.324f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 6366053.474f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 2178556.315f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 3523588.275f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 4953901.222f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 6589757.335f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 9412147.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 1635975.468f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "FI",
                    name: "Finland",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 18usize,
                    internet_exchanges_number: 15usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 7828388.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3881815.518f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1624679.803f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 1726163.387f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 2918157.016f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 4298908.349f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 1528375.583f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3696859.048f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 5782959.847f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 248183.512f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4316348.838f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3727778.866f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1792897.482f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 1659658.309f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 4420899.375f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 7598991.404f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5030194.769f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 8383511.49f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4858004.226f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1887958.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 2322400.625f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 9308760.399f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 3419838.731f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 2036556.286f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 2183013.705f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 390178.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 3009254.865f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 8236658.253f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 7214626.846f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 3885332.177f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 2076851.552f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 7378875.646f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 10357958.619f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2913639.971f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3536427.46f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 4159045.828f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 7855556.91f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4357220.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 914292.604f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 93176.185f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 202644.775f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 6031297.007f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 1815092.445f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 2172871.145f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 1794594.872f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 5218539.981f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1975753.58f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 2285013.558f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 6825265.005f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 756560.848f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 831785.79f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1570774.355f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 7536300.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 1480133.902f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 9168046.846f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2485302.105f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7243254.599f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1803694.944f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2352347.096f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 1753868.951f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 1006501.017f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3531838.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2964015.56f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1323660.49f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 3275907.918f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 3058271.241f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 1310844.927f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3754829.567f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 2357199.452f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 8310649.241f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 1057036.728f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 7025732.396f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1887220.092f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 7006535.502f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 918242.55f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 5761939.521f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4604271.832f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 9268567.732f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 7598195.519f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1752472.53f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 6662830.555f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 7567391.011f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 1659127.833f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 9566341.744f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 594303.919f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 5428544.892f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 6042147.582f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 2097055.077f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "MN",
                    name: "Mongolia",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 3usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9814948.984f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 10863953.34f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 6732678.741f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 7666250.308f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 9349391.3f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 11290512.081f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 7524063.548f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 10262808.912f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 11934126.835f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 6813186.256f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 11021439.905f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 6169263.993f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 6168400.751f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 5529965.407f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 11416979.434f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 11482130.818f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 11896061.881f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 13514749.083f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 11861878.667f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 8056594.828f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 9001077.582f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 14595604.472f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 7120292.443f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 5965795.979f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 7744752.583f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 7247187.752f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 9982572.568f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 13685843.248f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 10066266.003f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 10250439.459f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 6977895.986f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 13100674.636f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 14613096.301f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 9622799.099f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 10517388.862f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 11162425.859f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 12029984.615f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 11143224.648f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 7006535.502f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 7098982.744f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 1875387.071f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 7215749.893f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 7428093.426f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 7819858.652f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 2006463.804f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 8452633.436f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 4835537.895f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 1507113.448f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 7678211.501f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 6237099.068f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 6567488.996f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 14223386.118f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 7801935.246f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 14380199.169f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 8797565.304f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 1064927.512f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 8141913.028f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 9344229.26f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 7299934.344f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 7485371.197f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 10216635.386f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 9765992.984f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 8265292.08f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 10007310.582f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 9836026.5f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 7379547.253f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 6955085.324f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 7688372.112f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 13141362.956f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 6759136.704f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 1617498.746f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 8197940.562f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 6770078.563f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 12345412.818f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 11610399.455f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 12712054.677f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 14509729.849f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 8368814.305f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 7026076.949f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 12596808.282f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 697683.063f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 6935576.592f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 13809853.389f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 7422778.756f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 7913605.305f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 12228520.623f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 11959173.654f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 6473567.972f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "TT",
                    name: "Trinidad and Tobago",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 7usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 2433807.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 2796661.784f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1876702.21f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1954106.468f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GY",
                            distance: 577829.99f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SR",
                            distance: 788389.268f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1823488.049f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 820353.596f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 988857.231f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 2208799.903f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 2427112.201f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 850994.912f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 4057970.463f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1684621.23f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 1484686.023f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 5686196.488f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 4103320.898f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 2301682.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 948858.017f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SX",
                            distance: 837468.919f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 277664.892f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 2983202.816f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 915925.964f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 858624.576f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 6093835.251f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 618115.985f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 2425088.731f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GF",
                            distance: 1195092.288f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 585970.202f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 679533.695f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 1268900.881f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 514213.24f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 834615.292f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 744424.943f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 720119.966f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 812247.769f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 441077.325f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 346344.603f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 147860.406f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 379324.191f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 3003286.732f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 2599123.128f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 783145.441f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 3064231.651f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "BO",
                    name: "Bolivia",
                    continent: Some("South America"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 8usize,
                    links: vec![
                        LinkTo {
                            code: "GY",
                            distance: 2802031.419f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SR",
                            distance: 2779490.885f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PE",
                            distance: 1467110.722f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 3241006.015f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GF",
                            distance: 2900313.616f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 3091585.824f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 2489588.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PY",
                            distance: 1362427.827f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 2309664.075f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 4064025.038f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 2119939.199f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 1972970.84f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UY",
                            distance: 2308519.553f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "US",
                    name: "United States",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 142usize,
                    internet_exchanges_number: 603usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 7793835.748f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CR",
                            distance: 1807100.711f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 1388870.595f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 998104.063f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 9747026.253f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1921463.003f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 5164258.19f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 9199904.307f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 456102.396f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 10753519.845f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PE",
                            distance: 4309373.878f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PW",
                            distance: 7349448.189f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 9121580.601f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 4825692.015f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 849724.282f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 1945676.534f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 1670302.723f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 199363.164f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 1183635.879f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 10558754.846f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8481910.765f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 7007709.736f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 5482689.346f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 8577244.369f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 4193277.771f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 4184305.113f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3320133.822f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 934814.285f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 9207585.344f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 3487868.221f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 1337581.007f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 896120.784f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 755120.965f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 2303233.119f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 4739754.638f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 1250804.011f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 2172522.731f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 2672298.547f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 6915230.167f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 3898296.448f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 4445811.711f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 1595667.611f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 5880166.603f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 5768988.659f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GF",
                            distance: 3775124.556f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 2209790.807f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 674449.593f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 8159042.702f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 3151622.3f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 10729991.06f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 1189911.313f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 4543768.287f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 4300609.867f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 2599123.128f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 4854417.035f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 4675832.982f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 7687956.764f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 1839237.157f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 5614437.324f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 10062962.896f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 882261.749f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 4785011.626f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 7403063.219f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 5094935.764f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 5987314.18f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 8292724.42f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 5906222.527f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 1439693.6f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 2352741.498f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 9483864.513f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 4122543.913f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 4233856.033f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 4281821.969f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 4225006.973f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 4361926.803f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "PH",
                    name: "Philippines",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 62usize,
                    internet_exchanges_number: 8usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 3023791.234f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 7851369.714f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 10654881.106f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 10369320.369f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 6527092.813f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 7615733.442f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 10290958.653f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 6068542.808f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 4221119.937f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 9733769.096f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 5896480.161f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 944304.082f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 12236411.852f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 11202994.309f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 10659112.86f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 7518484.65f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 1130175.938f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5766684.69f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 1961214.155f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 6622970.082f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 10162092.424f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 9339890.84f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 2343763.353f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 12343854.249f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PW",
                            distance: 988171.093f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 2203787.825f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 11300965.538f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 10635003.667f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 9409249.919f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 7395399.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 2429920.796f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 2509428.531f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 5722793.857f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 11300698.404f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 2738523.969f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 2713212.544f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 9014730.133f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 7981885.148f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 7175759.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 1425344.427f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 11898060.371f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 8628547.128f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 9268567.732f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 9286947.1f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 13616909.034f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 10772641.787f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 10980967.097f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 10301570.417f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 12657049.436f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 9768530.452f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 10963687.156f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 1394703.155f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 13956386.399f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 9227559.458f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 9935981.858f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 10806702.764f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 4566439.237f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 9984013.572f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 5113922.475f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 2239307.535f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 9745344.262f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 11803235.085f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 9965614.633f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 8342812.327f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 10665107.925f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 12157415.589f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 9804886.797f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 9096528.999f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 8922269.959f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 8991921.8f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 9036413.073f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 8965773.069f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 10193261.523f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 12741012.154f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 10979351.729f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 1403680.253f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 10286675.102f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 14157042.143f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 9997385.457f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 12712054.677f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 10157337.702f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 4886800.599f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 6843942.524f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 1236397.244f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 9329692.696f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 8417496.149f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 8292724.42f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 5502429.641f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 9580208.68f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 10522732.003f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 3489889.895f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 13306703.377f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 10769528.967f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 9423372.434f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 8005351.697f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 8321063.635f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 3806040.785f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 11320548.426f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "LI",
                    name: "Liechtenstein",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9532696.744f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3842341.626f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 574359.502f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 399047.905f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 4138018.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 4268503.59f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 381523.251f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4683097.682f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 6754452.335f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1374534.177f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 5086930.027f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2319426.613f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1133228.55f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 1960527.99f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 4406107.109f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 9068796.835f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5521707.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 9458589.903f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4995255.582f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 784280.856f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1814657.546f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 10223618.632f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 1737027.806f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1339878.446f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 537752.07f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1435858.032f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 3539376.37f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 9224002.701f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8869923.192f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4984067.399f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 493700.029f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 8362058.442f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 11433649.905f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2389095.692f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3525761.218f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 4367045.981f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 9240788.987f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3875384.802f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 1753868.951f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1668762.369f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 5867939.039f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 116368.449f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 419699.609f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 544705.055f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 5312256.159f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1237734.446f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 2596074.364f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 6671173.959f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1468855.639f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 1720437.751f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 752398.336f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 7983910.064f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 720559.292f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 10124577.348f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1500051.157f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7825226.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 923774.26f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2583040.51f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 885144.911f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 2941475.385f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2581846.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1690738.242f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 2760007.53f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2627518.555f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 489968.683f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2111608.514f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 641241.82f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 9483045.651f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 863559.872f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 6828733.406f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 953345.256f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 7299934.344f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 973047.553f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 6466170.248f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4725450.978f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 10665107.925f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 7803298.857f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1274025.336f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 392523.386f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 7637464.858f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 7714231.292f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 367482.216f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 10748530.225f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1333261.913f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2774834.839f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4943162.375f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 7094329.495f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 902612.994f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "AZ",
                    name: "Azerbaijan",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 8usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8910835.674f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 11119182.247f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 7250869.666f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 8162376.298f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 333703.276f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 11526976.821f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 7997889.322f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 10152283.769f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 11589958.891f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 7129586.935f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 10930291.509f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 6993458.198f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 6698703.367f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 5935394.214f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 11642569.943f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 10702794.28f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 11861250.8f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 12810797.281f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 12002280.704f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 8540795.852f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 9407801.752f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 13847091.263f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 7891889.306f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 6528953.725f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 8310846.034f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 7534596.942f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 346450.648f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 13038699.284f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 9243202.515f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 10073678.224f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 7564929.806f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 12560465.094f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 13691887.185f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 10034765.728f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 10775746.705f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 11312808.587f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 11258231.517f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 11547591.057f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 7243254.599f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 7348189.831f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 2875147.234f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 7754605.019f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 8012847.384f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 8313590.879f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 2753336.13f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 8893892.416f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 5253732.992f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 2572040.022f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 7965498.303f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 6545254.752f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 7074609.052f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 13968685.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 8239270.561f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 13631875.537f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 9292504.076f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 8597698.833f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 9591595.496f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 7825226.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 7868353.658f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 10650210.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 10143495.101f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 8553692.99f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 10418670.201f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 10225221.584f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 7826711.149f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 7771998.317f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 8286109.249f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 12405265.789f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 7181316.305f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 2676861.738f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 8662656.763f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 1064927.512f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 7167975.506f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 12135817.164f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 11771466.622f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 11803235.085f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 14414896.273f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 8771877.631f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 7509978.272f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 12147192.717f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 1512772.848f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 7457893.63f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 12936713.686f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 7727651.749f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 7972967.051f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 12637373.672f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 11545603.235f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 7066241.234f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "VA",
                    name: "Holy See (Vatican City State)",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 4usize,
                    internet_exchanges_number: 6usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 11288536.946f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 10639878.46f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 6308257.47f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 7223912.998f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 9740370.271f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 11072449.442f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 7127274.938f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 10622915.668f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 12557606.756f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 6719396.376f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 11313140.831f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 5199135.23f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 5761193.027f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 5388978.546f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 11208624.742f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 12765933.419f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 426166.834f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 12054462.401f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 14620677.42f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 11757717.889f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 7613013.73f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 8635095.561f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 15723937.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 6211358.546f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 5514850.396f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 2254324.185f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 7178903.329f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 7171166.874f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 10015021.102f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 14691649.315f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 11436361.454f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 10709077.375f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 6017882.758f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 13965472.004f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 16040641.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 9217351.368f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 10306615.291f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 11082172.913f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 13289667.575f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 10675506.436f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 7025732.396f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 7092627.395f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 996077.054f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 6726054.14f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 6846637.376f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 7373089.368f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 1893023.378f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 8059002.352f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 4740750.971f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 227823.705f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 7575843.467f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 6197646.166f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 6173081.465f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 14560201.057f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 7450034.09f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 15519554.253f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 8298409.865f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 2676861.738f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 7740880.862f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 9211658.443f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 6828733.406f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 7241052.508f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 9748154.272f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 9408047.564f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 5944769.146f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 8127140.72f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 9584017.69f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 9456146.971f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 7035806.853f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 6068618.618f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 7070527.508f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 14313235.739f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 6496150.946f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "US",
                            distance: 882261.749f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 7779178.574f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 1617498.746f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 6546648.637f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 12742162.619f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 11489230.326f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 14157042.143f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 14573588.603f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 8041773.534f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 6641984.333f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 13346757.186f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 1350014.156f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 6491236.288f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 15178846.213f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 7308047.477f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 8146718.674f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 11699109.804f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 12686175.492f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 5934180.058f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "PS",
                    name: "Palestine",
                    continent: Some("Eurasia"),
                    other_names: vec!["Palestinian Territory"],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9020305.267f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 1253767.617f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 3302972.584f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 2370617.918f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3255610.722f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 1621348.349f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 2492248.926f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3190885.419f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 4816597.509f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 3304244.45f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 3155027.658f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 4693003.26f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 3865348.928f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 4496189.841f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 1754749.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 7761843.699f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 3169236.579f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 7399092.623f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 2391690.302f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1977967.606f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1012019.595f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 7922865.073f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 3738926.693f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 4093093.812f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 2421025.529f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 2932986.295f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 1830532.162f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 7069810.815f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8176810.197f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 3591847.493f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 3169362.803f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 6270694.474f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 9238550.82f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 385373.034f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 1057639.223f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 1913102.581f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 7722838.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 1136750.187f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 3275907.918f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 3159047.223f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 8627728.861f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 2859765.615f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 2752962.321f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 2218645.072f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 8046947.709f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1556465.841f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 5187836.012f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 9429857.451f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 2520257.072f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 3885104.69f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 3456663.074f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 5408586.636f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 2205379.833f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 7874243.264f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1294651.98f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 10418670.201f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1871032.735f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 1275208.118f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 2760007.53f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 2550416.834f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 264240.759f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 338704.27f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1967391.504f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 232295.572f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 2627869.787f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 4113059.781f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 2558689.61f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 7561016.241f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 3253843.547f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 9584017.69f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1821398.198f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 10007310.582f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 3255530.739f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 4226029.133f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 2137865.626f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 9036413.073f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 5108351.7f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1648495.048f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 2990295.906f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 5602312.19f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 10458281.224f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 3109049.988f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 8741576.66f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 2727874.581f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 3123798.838f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 2227008.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 5230476.848f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 3649919.719f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "IR",
                    name: "Iran",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 11usize,
                    internet_exchanges_number: 4usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 7568581.459f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 282046.33f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 4825778.791f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 3970629.477f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 2454023.862f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 303943.137f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 4022891.176f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 1867441.066f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 2965274.307f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 4394197.427f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 1452549.371f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 6517492.945f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 5347345.993f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 5720916.606f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 386276.754f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 6030094.125f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 1256158.742f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 5488696.617f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 320881.98f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 3611710.851f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 2584983.288f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 6024283.547f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 5607957.91f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 5605296.139f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 4161723.072f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 3946517.768f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 1216242.8f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 5156708.265f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 6691925.1f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 2231622.147f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 4837371.892f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 4362177.234f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 7331029.581f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2150385.499f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 247597.133f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 2115599.497f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 159640.578f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 304783.024f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 2487513.74f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 1291389.714f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 3357907.539f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 3145578.556f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 2334880.159f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 5919306.993f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 4159045.828f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 4070949.346f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 10090377.706f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 4480268.634f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 4477252.137f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 3836411.094f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 9352260.779f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 3144759.738f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 6398868.821f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 10899091.057f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 3525635.854f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 4951405.819f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 4940951.599f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 3682302.515f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 5968204.659f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 3088071.829f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 11312808.587f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 3447605.54f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 1870775.173f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 4367045.981f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 3843791.835f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 1930909.71f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 1900940.766f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 2958919.135f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 1913102.581f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 1906824.51f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 4078091.506f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 5993235.336f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 4336132.458f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 5664402.108f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 4587080.762f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 11082172.913f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 3430859.29f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 11162425.859f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 4535777.02f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 7175759.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 3097601.297f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 4481042.008f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 3707193.716f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 11724852.456f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 4663554.305f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 6830607.166f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 3791021.802f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 3349972.603f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 3390155.435f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 5263721.325f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "BG",
                    name: "Bulgaria",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 28usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9075823.553f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 2605159.265f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1754969.686f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 838895.922f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3339059.076f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 3030781.073f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 938287.096f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3701104.577f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 5690636.066f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1865558.206f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 3989079.695f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3414386.747f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 2313643.813f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 2958860.742f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 3168395.787f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8271634.443f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 4330022.978f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 8389678.734f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 3760809.458f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 466963.648f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 147364.131f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 9082283.156f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 2604076.615f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 2548494.396f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1044934.731f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1589252.95f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 2428682.324f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 8121663.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8320181.175f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4048417.236f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 1694198.716f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 7271465.588f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 10335797.744f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 1174414.054f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 2291992.057f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 3144759.738f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 8364794.794f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 2690772.971f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 1975753.58f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1855338.362f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 7091010.547f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 1346773.331f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1341430.647f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 695987.766f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 6490853.17f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 1109424.887f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 86610.707f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 3645426.588f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 7897171.473f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1273348.578f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 2420292.123f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1903090.26f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 6761502.444f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 655168.237f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 8998527.248f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 512769.622f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 8893892.416f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 318354.835f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 1237734.446f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 1063319.547f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 1766057.264f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 1349308.947f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 985892.081f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 1556465.841f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 1402330.238f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 1074167.692f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3004627.638f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 1245048.196f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 8461812.099f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 1712721.336f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 8059002.352f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 286759.247f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 8452633.436f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 1730370.801f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 5311683.06f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 3491419.474f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 9768530.452f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 6565703.225f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 1435007.175f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 6556214.715f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 8902835.616f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 1567873.078f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 9710970.758f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1381563.23f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2397376.101f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 3776893.48f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 6059775.526f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 2140302.016f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "TM",
                    name: "Turkmenistan",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 1usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 7190054.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 1266455.021f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 3911402.081f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 3167548.789f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 1501375.275f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 1547445.651f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 3165281.731f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 1379567.238f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 3262722.699f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 3295866.274f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 1561128.435f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 5825136.809f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 4384444.102f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 4626099.09f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 1628220.388f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 6002359.465f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 2052416.644f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 5961281.461f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 1902155.765f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 2870047.946f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1975510.112f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 6684807.882f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 5030221.25f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 4650921.859f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 3469498.362f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 2844168.812f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 346450.648f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 5700008.646f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 6346839.345f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 1774077.763f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 4031648.065f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 4845510.595f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 7914596.27f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 1838956.105f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 1048587.938f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 1216242.8f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 6022276.956f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 2196137.546f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 3009254.865f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 2932080.55f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 9018945.309f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 3655742.4f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 3745969.673f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 3059184.952f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 8227530.587f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 2428682.324f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 5284412.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 9820466.181f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 2447822.335f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 3825657.754f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 3996825.396f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 4571387.891f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 2819991.18f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 6589557.8f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2569580.839f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 2680357.33f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 975575.533f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 3539376.37f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 2863274.711f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 2005050.213f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 1606879.475f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1935481.743f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 1830532.162f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 1679601.86f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 3164734.439f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 5430254.945f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 3673426.343f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 6037988.402f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 3578882.094f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 10015021.102f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 2690824.53f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 9982572.568f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 3505488.834f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 2930742.626f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 1675413.651f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 7395399.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 4588983.895f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 2292526.691f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 3565363.271f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 4128135.583f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 10565975.203f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 3779143.563f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 7283026.367f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 2715369.936f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2133730.752f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 2976571.497f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 3638173.071f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 4392798.93f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "BT",
                    name: "Bhutan",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 4560506.005f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 4060454.839f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 7368616.803f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 6750580.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3124687.283f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 3862412.565f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 6712855.115f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 2416278.254f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 428207.454f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 6464815.591f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 2100135.332f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 9412147.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 7747086.84f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 7662553.786f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 3779917.632f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 2704138.493f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 2244275.392f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 2371263.227f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 3249303.594f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 6487298.485f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 5610175.59f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 3271511.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 8663850.872f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 8011531.641f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 7091419.052f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 6058605.433f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 3638173.071f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 2194512.581f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 3708155.61f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 2162428.914f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 7586038.269f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 1341505.866f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 4357234.401f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 5374745.467f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 4176925.163f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 3390155.435f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 2533284.951f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4889672.618f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 6042147.582f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 6019626.68f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 11763684.213f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 7208862.814f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 7349616.082f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 6658372.038f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 10797243.257f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 6059775.526f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 8183386.491f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 12460776.958f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 5771520.237f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 6840369.344f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 7410916.421f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 2516001.544f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 6379333.188f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 3126018.624f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 6198249.288f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 11545603.235f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 6293293.523f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 4608398.415f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 7094329.495f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 6304780.537f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 5295884.32f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 5121008.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 5408299.897f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 5230476.848f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 5161728.632f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 6663481.78f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 9064396.233f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 7300369.564f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 2402168.842f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 6921159.339f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 12686175.492f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 6312115.318f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 11959173.654f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 6812844.776f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 1312489.957f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 3383186.492f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 3806040.785f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 3219237.28f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 5902543.575f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 7039505.304f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 660684.946f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 12653754.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 7275769.113f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 3658508.777f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 6010494.225f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 4770505.205f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4820144.253f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 7876547.837f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "SN",
                    name: "Senegal",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 6usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 7983852.219f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 7026849.009f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 6628625.265f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 4284424.467f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 6443242.805f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 2251078.949f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 1799939.299f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 165957.913f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 4006532.991f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2784939.914f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 4182664.319f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 5374503.343f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 1182354.83f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 5420899.923f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 3100771.816f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 7617708.28f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 6686417.14f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 3639327.126f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 7777481.043f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 828209.543f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 370388.848f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 4137693.731f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 3851171.567f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 5532803.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 3233965.357f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 5811535.044f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 5884562.231f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 3357299.051f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 652979.691f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 2141737.877f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3519686.784f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 6605517.901f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 6694478.159f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 6552054.855f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 2456874.804f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 7050785.71f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 5364234.706f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 2361432.929f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 3200835.825f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 3310895.114f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 704838.827f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 409153.469f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 3096677.571f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 7021490.698f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 6868032.812f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 3721054.596f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 7352540.135f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 6953371.376f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 8882177.739f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 4111120.408f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 9157452.204f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 2950173.559f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 6416826.845f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 7542683.98f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 5549487.476f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 5725054.102f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 1741704.103f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "GL",
                    name: "Greenland",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 6usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 6625027.466f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 6121290.762f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 5556403.754f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 6146147.354f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 5318225.056f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 5562506.058f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 4842320.737f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 3755001.97f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 5280355.138f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 2036617.353f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 5036868.857f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 5386926.993f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 3960821.238f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 5719543.248f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 5524851.702f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 6016700.169f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 5833667.262f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 5929279.238f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 5278578.709f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 1529872.115f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 5322963.5f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1781257.311f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 5477557.999f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 6285673.067f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 4849568.026f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 5305826.857f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 5585593.134f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 6036866.721f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 6093835.251f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 5812845.745f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 5722348.211f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 5940064.715f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "US",
                            distance: 3898296.448f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 5355262.655f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 5377912.954f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 5656472.498f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 5313120.712f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 6241038.007f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 5389196.59f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "JE",
                    name: "Jersey",
                    continent: None,
                    other_names: vec![],
                    cable_connections_number: 4usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "UK",
                            distance: 230658.821f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GG",
                            distance: 32371.021f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 27708.437f64,
                            link_type: LinkType::Submarine,
                        }
                    ],
                },
                Country {
                    code: "BI",
                    name: "Burundi",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 13142129.47f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 2137968.433f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 1097029.735f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 1888492.214f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 2459581.42f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 3297524.671f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 3831209.942f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 5407990.325f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 1646736.653f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 2009177.834f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 4585866.952f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 2675744.648f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 2547744.553f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 1514445.806f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 4079953.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 2661904.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 4903329.123f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 5267414.891f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 5166103.216f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 2696757.932f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 9237759.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 5532803.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 4981083.479f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 5509356.753f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 2891310.23f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 4893033.172f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 3004970.843f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 2284349.686f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 1840433.553f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 2953148.586f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 2557084.521f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 3428310.426f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 2343464.544f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 4138693.248f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 3669129.057f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 7415351.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 1615090.986f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 6237429.343f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 2032358.435f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 178477.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 3178160.295f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 3429624.177f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 3740320.826f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 961236.468f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 2275202.851f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 2257301.906f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 544690.619f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 3833801.742f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "CO",
                    name: "Colombia",
                    continent: Some("South America"),
                    other_names: vec![],
                    cable_connections_number: 20usize,
                    internet_exchanges_number: 10usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 821451.874f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 1517193.677f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 849837.353f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 477108.402f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GY",
                            distance: 2706752.1f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SR",
                            distance: 2928271.537f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PE",
                            distance: 1797248.529f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 745372.747f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 1252496.644f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1558580.056f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 2588312.389f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1324880.891f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 1692641.08f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 1244195.138f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BO",
                            distance: 4064025.038f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 558262.867f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 1578897.668f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 1474514.097f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 2038713.787f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 919075.227f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GF",
                            distance: 3356363.243f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 854982.158f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 1386169.332f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 1077977.401f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PY",
                            distance: 5347966.264f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 4328517.139f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 1839237.157f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 1586274.945f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 4959673.862f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 4145849.425f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UY",
                            distance: 6367159.728f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "CK",
                    name: "Cook Islands",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "PW",
                            distance: 7804730.402f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 7120100.847f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 1556239.9f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 3236894.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 1394218.657f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 1066845.263f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 1324308.697f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 2279972.745f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 10077326.609f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 1109745.095f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 1779308.164f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 4288096.452f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 2114552.3f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 5820108.233f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 7122731.281f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 3361550.694f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 5669433.052f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 2767008.564f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 4663418.9f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 1974218.841f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 4611319.86f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 5887648.128f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "PK",
                    name: "Pakistan",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 9usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 6028248.901f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 2070351.597f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 1924804.529f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 6095972.929f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 4063664.373f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 5132994.785f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 2617202.126f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 1651103.886f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 5160391.37f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 1735740.857f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 1817562.786f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 5341720.45f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 964120.724f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 5439046.548f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 7161781.404f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 6666945.684f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 6668303.151f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 1561575.765f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 5324040.025f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 3390529.265f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 3711465.11f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 2751265.075f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 5070485.606f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 4505165.826f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 1077769.155f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 2915256.668f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 2378647.676f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 3901209.678f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 2552017.611f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 4532511.933f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 2973317.345f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 866905.185f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 5846335.847f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 4721714.338f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 2922769.21f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 5766684.69f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 4263119.932f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 1928201.255f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 4384110.373f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 5949695.333f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 8173259.894f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 4058556.659f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 5561688.318f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 6907145.584f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 3490154.986f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 3178056.011f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 5719765.193f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 5530240.126f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 3116687.825f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 4157574.988f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 4794320.021f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 6847405.406f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 6691957.125f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 4890795.429f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 2052416.644f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 1917282.075f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 2129709.661f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 1256158.742f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 4768565.369f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 5030194.769f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 4961849.839f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 11058977.371f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 5637194.082f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 5671313.735f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 5008108.816f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 10237461.516f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 4330022.978f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 7314803.329f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 11855356.905f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 4499764.534f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 5856905.584f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 6032786.584f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 4814381.675f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 11861250.8f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 4618860.882f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2947576.413f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 5521707.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 4904810.314f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3178639.95f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 3145642.972f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 3981848.62f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 3169236.579f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 5185318.913f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 7236374.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 5550024.326f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 5628539.505f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 12054462.401f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 4611890.339f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 11896061.881f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 5557381.719f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 2614400.628f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 4248832.133f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 5589307.527f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 12518129.389f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 5791207.525f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 4767066.483f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 3988422.588f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 2244275.392f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 6401934.167f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "UK",
                    name: "United Kingdom",
                    continent: Some("Eurasia"),
                    other_names: vec!["GB"],
                    cable_connections_number: 113usize,
                    internet_exchanges_number: 61usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9946211.755f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 7145229.804f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 4878911.917f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 585672.749f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 7408166.787f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 1500452.241f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 4650369.468f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 5311285.552f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 1375402.775f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 5346231.59f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 7452226.392f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1328987.724f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 5867164.525f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 5060122.922f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 10377136.125f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 6516019.177f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 1401122.14f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 3606678.227f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 4081672.29f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 1514575.18f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 5919661.09f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 9556261.825f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 5027513.301f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 10027074.737f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 7584609.353f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 2005376.888f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 10677182.397f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 10546980.336f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 613342.463f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 211323.588f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 767532.658f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 5164258.19f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 1090963.603f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 5049945.793f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 4990800.196f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 245916.536f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 4113595.498f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 4728605.826f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IM",
                            distance: 62491.479f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 9688856.868f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 4182664.319f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 7658164.021f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 6125069.309f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 5761489.901f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 8894331.134f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 9284055.647f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 5031175.782f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 6360985.692f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 12090813.019f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 11202994.309f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2848634.737f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 10219141.108f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 6666945.684f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 3034997.755f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 9072054.049f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 14828885.891f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 9377701.335f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 11221010.505f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 11649084.154f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 3475047.557f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 412770.048f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 1632731.299f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1196018.012f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 2464317.904f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JE",
                            distance: 230658.821f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 625514.608f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 922757.355f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GG",
                            distance: 119051.712f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 5447559.28f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 10112003.415f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1892922.868f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1693780.423f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 4384444.102f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 5586534.459f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 4547439.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 5347345.993f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 9647908.47f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 1792897.482f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1779125.202f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 4784168.754f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 1056442.885f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 1654022.228f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 4186427.659f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 2313643.813f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 5592628.829f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1987575.106f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 1689404.824f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 6698703.367f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1996172.628f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 3492807.679f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 1133228.55f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 1522285.711f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 3659633.779f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 2449018.281f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 3865348.928f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 3715810.274f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 1275169.53f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 1616486.327f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 827716.443f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 5761193.027f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 2043975.778f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 6168400.751f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 8827886.13f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 2280753.555f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 8341060.833f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 6594341.467f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 767332.337f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1738810.43f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 3067718.178f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 6067676.045f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 7747086.84f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 506736.097f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "CM",
                    name: "Cameroon",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 6usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 11069179.789f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 4029719.328f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 3346341.011f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 1565469.162f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 3610758.853f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 914531.545f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 1473899.15f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 3137143.697f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 1159849.173f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 4273011.179f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 2762614.217f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 2325035.255f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 3023848.342f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 456336.034f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 3489696.594f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 2760550.522f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 4804688.465f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 2633416.34f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 2996852.533f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 5173924.919f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 2284349.686f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 3737262.051f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 3459040.978f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 407145.095f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 3200835.825f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 2709285.546f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 3285279.61f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 4094519.833f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 3731974.598f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 4259856.205f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 1056643.355f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3724670.948f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 694977.863f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 3782280.496f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 844585.066f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 5435133.625f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 120336.561f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 4098771.52f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 4017599.565f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 5643753.02f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 3325949f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 5910220.729f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 5445722.184f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 3297477.433f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 4289175.504f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 2315438.38f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 3739783.726f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 3245062.778f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 3996141.361f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 3763521.164f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 2536976.177f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 1605582.983f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "MO",
                    name: "Macao",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 15usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 10410171.32f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 11384409.943f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 7158303.399f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 8093721.686f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 10001299.868f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 11815609.284f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 7966033.15f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 10913512.101f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 12622217.821f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 7342391.637f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 11664000.703f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 6366053.474f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 6594341.467f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 6033047.493f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 11945771.96f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 12138400.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 12518129.389f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 14194704.602f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 12422619.893f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 8486689.45f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 9464451.887f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 15266893.238f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 7353958.894f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 6374400.452f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 8128039.076f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 7784809.397f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 10565975.203f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 14375721.255f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 10704050.065f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 10915806.277f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 7356905.856f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 13798073.682f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 15200436.363f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 10077249.09f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 11039460.764f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 11724852.456f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 12689579.658f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 11586413.512f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 7567391.011f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 7653985.077f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 1975626.356f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 7622724.638f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 7802920.362f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 8247003.491f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 2413279.184f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 8902835.616f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 5343099.971f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 1340779.842f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 8211873.908f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 6776082.823f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 7001805.523f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 14889367.84f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 8261104.813f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 15051060.606f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 9213367.436f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 1512772.848f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 8587296.327f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 9880968.648f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 7714231.292f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 7976173.938f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 10653226.342f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 10237291.862f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 8793196.316f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 10458281.224f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 10300541.088f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 7837988.338f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 7147691.046f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 8051266.367f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 13813137.833f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 7237989.426f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 1350014.156f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 8637696.876f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 697683.063f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 7261203.389f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 13010216.352f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 12164909.271f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 13306703.377f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 15130871.527f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 8840374.825f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 7468103.378f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 13293008.974f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 7356150.079f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 14428315.118f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 7951067.802f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 8529728.773f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 12656990.625f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 12653754.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 6855628.817f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "SG",
                    name: "Singapore",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 31usize,
                    internet_exchanges_number: 33usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 5299719.531f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 6669250.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 10635401.759f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 9851491.506f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 6394350.132f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 6321361.843f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 9847638.279f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 5636498.612f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 3532044.252f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 9723079.363f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 5140583.49f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 2937980.785f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 11870609.979f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 11221010.505f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 10934056.651f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 6196294.336f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 2588097.629f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 4721714.338f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 1104198.979f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5445362.927f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 9539162.827f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 8622199.707f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 21481.703f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 2343763.353f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 1269197.961f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 8405125.336f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 6817210.99f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 9791668.002f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 5717669.572f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 6765593.584f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 2707596.363f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 2614041.342f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 189557.05f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 2001009.18f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 10530623.838f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 7472588.636f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 4560753.73f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 2887909.756f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 8983914.634f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 1710919.898f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 3918988.389f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 708323.626f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 11628547.967f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 8211133.594f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 10753519.845f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 13844861.67f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 4689217.239f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PW",
                            distance: 3455633.878f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 1322425.982f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 10441346.641f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 10251586.366f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 11627344.058f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 11247212.403f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 9306056.347f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 6684807.882f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 5423486.404f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 6904744.627f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 6024283.547f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 2588863.863f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 9308760.399f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 9281947.651f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 14899209.024f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 10339954.565f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 10419337.976f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 9739077.949f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 13901492.816f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 9082283.156f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 11445381.031f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 15497223.51f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 8993041.105f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 10111409.722f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 10624033.378f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 9503486.077f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 13847091.263f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 9354921.142f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 7649926.587f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 10223618.632f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 9496668.859f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 7894612f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 7923519.689f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 8575576.646f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 7922865.073f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 7931014.415f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 9831054.127f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 12015927.097f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 10317754.092f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 10152539.018f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 15723937.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 9357338.442f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 14595604.472f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 10051613.598f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 3399982.923f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 8971740.935f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 10223103.985f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 15266893.238f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 10448421.54f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 9242249.269f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 8041660.385f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 3271511.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 11060074.824f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "PR",
                    name: "Puerto Rico",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 17usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 2059298.358f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 2346404.723f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1171466.026f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1787230.2f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PE",
                            distance: 3616836.471f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 956028.415f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 768642.388f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 539426.726f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SX",
                            distance: 325377.248f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 156399.469f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 256063.29f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 1252496.644f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 2179909.202f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 3898624.349f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 1670302.723f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 2408023.359f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 380042.137f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 452868.368f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 613173.965f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 988857.231f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 473756.482f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 349728.497f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 790189.871f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 684552.961f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 917186.593f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 854190.772f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 735519.973f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 876763.34f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GF",
                            distance: 2119101.45f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 2345313.003f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 2033886.463f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1186055.896f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 741255.481f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 2254324.185f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 775426.141f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 2685522.672f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 159322.924f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 4133046.302f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 6188427.864f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 1812592.201f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 417028.629f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3554512.17f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 721327.35f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 4892263.147f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 1592646.57f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5562506.058f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 522317.164f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 374057.02f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "HT",
                    name: "Haiti",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 1553513.813f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 1562518.674f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 440044.314f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 945800.835f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 343637.884f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 721327.35f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 730069.814f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 1696942.837f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 994762.005f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3469199.633f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 351934.4f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 226451.36f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 4243973.37f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 2679696.871f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 888511.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 743361.764f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 1355863.164f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 1660237.266f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 830537.984f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 805214.008f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5386926.993f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 1182995.995f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 1345789.796f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 645657.135f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 1239284.571f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 822951.146f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 1484686.023f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 1511985.416f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 1330451.597f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 1366971.288f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "US",
                            distance: 3487868.221f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 997464.986f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 1042134.889f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 1293816.695f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 1019958.196f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 1836893.81f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 1137821.726f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "AR",
                    name: "Argentina",
                    continent: Some("South America"),
                    other_names: vec![],
                    cable_connections_number: 9usize,
                    internet_exchanges_number: 51usize,
                    links: vec![
                        LinkTo {
                            code: "PA",
                            distance: 5643599.615f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GY",
                            distance: 4659495.571f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SR",
                            distance: 4569083.239f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 9666194.226f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PE",
                            distance: 3362395.235f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 5329106.77f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 6188427.864f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BO",
                            distance: 2119939.199f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 7021490.698f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 6091828.31f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GF",
                            distance: 4529276.611f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 5346130.485f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 4542911.01f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 6249230.343f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PY",
                            distance: 1118293.079f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 4088405.966f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 4959673.862f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 6691583.597f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 9627037.356f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 1413992.23f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 7403063.219f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 6701101.462f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UY",
                            distance: 235376.623f64,
                            link_type: LinkType::Submarine,
                        }
                    ],
                },
                Country {
                    code: "IM",
                    name: "Isle of Man",
                    continent: None,
                    other_names: vec![],
                    cable_connections_number: 7usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "UK",
                            distance: 62491.479f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 127821.877f64,
                            link_type: LinkType::Submarine,
                        }
                    ],
                },
                Country {
                    code: "CH",
                    name: "Switzerland",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 27usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9612877.608f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3951924.952f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 511564.19f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 510048.621f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 4245823.237f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 4377213.692f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 496209.1f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4796963.756f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 6869812.261f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1418410.223f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 5203101.205f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2205957.261f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1056442.885f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 1917594.318f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 4514872.409f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 9171826.856f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5637194.082f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 9573675.564f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5106252.19f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 888812.386f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1922950.488f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 10339954.565f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 1645470.959f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1250862.894f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 572837.153f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1510903.356f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 3655742.4f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 9339886.932f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8957525.103f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 5096265.203f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 377908.851f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 8477790.023f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 11549247.392f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2491323.084f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3636842.066f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 4480268.634f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 9347976.663f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3970526.446f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 1815092.445f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1734981.954f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 5768152.94f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 382183.867f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 651411.725f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 5224211.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1346773.331f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 2538959.778f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 6570177.537f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1566296.771f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 1728659.319f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 694645.075f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 8097458.514f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 836758.892f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 10240777.622f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1590796.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7754605.019f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1034775.291f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2699210.135f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 116368.449f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 981517.342f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3036840.712f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2687574.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1803786.668f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 2859765.615f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2731343.36f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 585922.672f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2014538.915f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 637170.767f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 9596606.632f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 877832.394f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 6726054.14f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1061212.712f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 7215749.893f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 997293.265f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 6582491.972f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4836566.843f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 10772641.787f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 7912322.208f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1388986.441f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 406773.572f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 7753082.31f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 7622724.638f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 307575.179f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 10862401.303f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1419392.586f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2866302.513f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 5034280.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 7208862.814f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 794733.622f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "UG",
                    name: "Uganda",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 13085922.626f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 1637193.846f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 859538.625f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 2371212.079f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 2933314.684f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 3539609.75f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 4101743.15f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 5611731.158f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 2090508.613f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 1567440.424f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 4858926.536f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 3218033.329f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 2874437.186f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 1811718.746f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 4573479.119f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 2758966.177f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 5155610.04f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 5487951.514f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 544690.619f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 4996213.941f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 2204915.505f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 9336986.239f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 5725054.102f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 5222452.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 5658791.509f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 3338739.408f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 4665382.632f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 3466510.171f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 2536976.177f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 1831004.198f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 3171581.973f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 2963949.988f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 3425467.255f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 2638113.441f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 3863517.455f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 3626292.231f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 7373072.72f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 2024203.752f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 6434474.619f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 2014996.143f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 374090.572f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 3411428.326f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 3685804.503f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 3324927.183f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 888212.867f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 2620870.84f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 1712734.046f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 3992279.854f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "RO",
                    name: "Romania",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 1usize,
                    internet_exchanges_number: 27usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8826185.812f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 2599387.471f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1738147.751f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 884632.419f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3116269.204f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 3031093.866f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 926054.669f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3521448.591f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 5543056.146f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1685542.464f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 3851953.59f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3532610.451f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 2280753.555f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 2848494.109f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 3167649.109f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8061581.235f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 4248832.133f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 8247618.969f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 3738259.817f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 585581.745f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 220389.951f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 8971740.935f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 2771195.294f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 2528530.329f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1190329.704f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1372266.165f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 2292526.691f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 7992381.28f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8077581.017f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 3857479.956f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 1756601.241f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 7136439.276f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 10206829.911f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 1263565.762f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 2271668.629f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 3097601.297f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 8169893.63f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 2783532.248f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 1752472.53f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1631540.578f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 7064266.373f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 1388986.441f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1453775.144f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 767422.288f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 6427235.333f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 86610.707f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 3541131.085f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 7873112.595f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1028981.18f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 2255875.551f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1868709.172f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 6712269.901f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 592004.11f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 8880507.825f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 762887.295f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 8771877.631f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 390750.482f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 1321873.857f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 1274025.336f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 904928.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 1879059.701f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 1398209.79f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 724099.108f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 1648495.048f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 1467443.757f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 1008475.01f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3171360.255f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 1403070.968f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 8303853.641f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 1609761.014f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 8041773.534f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 417372.615f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 8368814.305f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 1607129.375f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 5205377.711f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 3468082.835f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 9580208.68f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 6555862.745f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 1400022.716f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 6416586.629f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 8840374.825f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 1567812.033f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 9559744.196f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1162055.023f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2133488.937f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 3874787.309f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 5902543.575f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 2166295.371f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "MU",
                    name: "Mauritius",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 5usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 16654213.288f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 3187195.726f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 2782528.118f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 5056736.975f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 3402871.984f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 6906390.214f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 7390533.411f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 9022298.788f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 5012375.582f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 4776929.123f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 8119153.154f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 4542327.45f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 6073780.321f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 2527520.729f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 6763419.861f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 1208234.851f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 8462621.646f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 8864174.918f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 3669129.057f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 8519057.611f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 4995844.533f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 12904724.384f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 9157452.204f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 8554987.53f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 9165546.802f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 3280371.132f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 8101827.304f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 2886611.641f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 5910220.729f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 1829212.7f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 6589436.383f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 2869871.551f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 5492077.421f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 245866.589f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 5925712.803f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 7238178.635f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 3956813.647f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 10991257.869f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 2907489.241f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 9849610.566f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 1637410.445f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 3690900.767f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 6798139.556f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 7019551.014f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 6300625.87f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 2756152.34f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 2475542.745f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 3912134.901f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 3626292.231f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 7493984.119f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "AU",
                    name: "Australia",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 28usize,
                    internet_exchanges_number: 125usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 6588158.189f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 14266083.977f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 6048716.153f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 15035908.741f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 14828885.891f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 7093001.172f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 8173259.894f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 8670168.009f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 11875684.872f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 3918988.389f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PW",
                            distance: 4706601.514f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 4552056.611f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 13178563.318f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 4603815.905f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 4289664.328f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 7551827.529f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 2155952.619f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 14760425.83f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 4341751.634f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 5778624.984f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 3020627.717f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 11430904.369f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 10441826.023f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 4401706.968f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 3389645.522f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 12076923.467f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 10082889.556f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 2610373.304f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 5669433.052f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 4668528.916f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 4477838.345f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 1967234.393f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 4740237.823f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 5395346.743f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 2968703.263f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 5757715.237f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 6675281.478f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 11440642.9f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 5113922.475f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 12147778.422f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 6276436.373f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 5399732.921f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 9108344.1f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 8951829.504f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 4013474.571f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 4102137.291f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 14649782.243f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 8159042.702f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 2954783.545f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 2742953.514f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 4454703.812f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 5347317.99f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 7006177.921f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "BY",
                    name: "Belarus",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8097835.31f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3186421.653f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1606233.742f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 1276122.095f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 2715775.436f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 3612321.781f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 1128062.71f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3362402.921f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 5467517.525f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 869829.463f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 3885756.031f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3721405.517f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1987575.106f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 2195871.075f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 3739372.147f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 7610206.375f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 4499764.534f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 8141486.536f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4217934.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1299872.37f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1569687.25f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 8993041.105f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 3205043.07f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 2255138.549f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1746271.392f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 432584.243f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 2447822.335f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 7948533.758f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 7412342.233f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 3618447.702f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 1914289.606f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 7082626.183f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 10128089.534f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2157079.44f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 2839742.45f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 3525635.854f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 7802280.812f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3609611.645f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 756560.848f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 638851.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 6580410.514f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 1566296.771f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1846556.091f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 1286252.271f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 5827224.751f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1273348.578f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 2874141.717f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 7385815.047f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 1441168.321f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1639402.469f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 7019007.184f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 927399.45f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 8871109.001f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1785582.832f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7965498.303f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1167250.688f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 1669182.329f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 1468855.639f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 584791.003f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 2775530.425f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2211274.247f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 589764.279f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 2520257.072f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2304138.689f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 980483.849f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3580066.081f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 1952873.07f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 8122137.01f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 1160845.412f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 7575843.467f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1247347.893f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 7678211.501f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 1069497.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 5322931.871f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 3956341.79f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 9227559.458f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 7006225.099f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1028981.18f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 1296798.785f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 6356745.48f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 8211873.908f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 1542849.593f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 9389961.919f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 267934.627f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 1315400.011f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4687138.391f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 5771520.237f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 2117964.675f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "CZ",
                    name: "Czech Republic",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 18usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9047958.534f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3604075.977f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 751615.242f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 437677.135f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3668515.39f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 4036721.167f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 228955.125f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4247574.942f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 6335398.768f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 992496.642f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4690899.855f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2768976.564f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1275169.53f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 1892473.798f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 4172820.624f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8586969.623f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5185318.913f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 9033089.146f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4733244.104f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 735849.148f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1626502.442f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 9831054.127f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 2226914.247f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1528360.814f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 873513.56f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 965921.22f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 3164734.439f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 8813393.125f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8380683.381f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4534821.557f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 942761.541f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 7948615.645f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 11015022.046f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2243774.805f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3272279.698f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 4078091.506f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 8768132.207f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3763725.51f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 1310844.927f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1214918.21f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 6056505.887f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 585922.672f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 887585.403f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 549564.466f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 5424801.295f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1074167.692f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 2574288.882f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 6865637.538f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 980483.849f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 1451298.407f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 864698.61f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 7678222.32f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 423240.306f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 9723462.789f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1478528.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7826711.149f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 771022.718f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2238737.57f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 489968.683f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 395838.389f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 2840214.411f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2399896.158f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1258440.041f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 2627869.787f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2462752.676f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2599726.995f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 1047712.606f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 9041203.276f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 652387.695f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 7035806.853f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 837119.493f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 7379547.253f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 700283.376f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 6094643.972f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4463324.974f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 10193261.523f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 7553650.573f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1008475.01f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 404476.878f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 7222293.26f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 7837988.338f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 617371.113f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 10308740.004f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 847172.954f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2284916.154f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4850882.69f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 6663481.78f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 1229946.131f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "GA",
                    name: "Gabon",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 6usize,
                    internet_exchanges_number: 17usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 4216908.805f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 3993894.432f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 3393767.682f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 1108282.256f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 10195198.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 1113336.995f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 1593832.139f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 3213910.191f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 773568.819f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 4669378.961f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 5761489.901f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 8565668.282f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 2340975.517f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 9107893.376f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 302638.697f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5230725.322f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 10478674.623f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 7032778.264f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 4425331.334f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 2669646.282f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 3060203.435f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 4894602.108f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 4787413.121f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 9237759.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 5048005.868f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 3702844.872f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4056827.282f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 1215921.816f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 4616527.763f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 3928666.539f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 3357299.051f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 3403727.362f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 3922165.446f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 948386.304f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 3840371.354f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 4190062.344f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 1022365.25f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 407145.095f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 166682.7f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 2755878.559f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 3404384.842f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 4100794.245f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 10589576.399f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 5620363.725f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 11077947.637f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 10723933.026f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 12647888.706f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 6432620.884f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 12904724.384f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 10218251.994f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 3154904.001f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 11269848.703f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 9226056.71f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 9336986.239f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 5412021.747f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "NG",
                    name: "Nigeria",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 11usize,
                    internet_exchanges_number: 9usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 10403980.753f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 4672496.543f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 4189861.859f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 2076278.214f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 4201174.953f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 245132.912f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 833243.861f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 2324027.313f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 1695296.978f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3796132.49f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 4990800.196f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 3168284.854f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 1571501.067f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 3455793.41f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 771873.146f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5630599.175f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 4164279.403f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 2681738.612f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 5326165.571f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 1850793.005f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 2190405.768f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 4256123.953f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 4102474.514f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 2953148.586f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 3340579.47f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 3932153.939f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4185967.334f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 948386.304f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 2456874.804f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 1916384.083f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 2470112.343f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 4676217.289f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 3437175.797f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 4689258.398f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 694977.863f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 4775627.85f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 412581.437f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3107974.002f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 3087873.017f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 4241525.119f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 4396059.703f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 4784136.488f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 4077135.932f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 109041.69f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 868403.263f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 4637654.894f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 6323507.326f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 3191617.207f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 6589436.383f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 4823303.931f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 3955890.999f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 4966365.066f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 2974169.224f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 3171581.973f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 936705.651f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "MP",
                    name: "Northern Mariana Islands",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 6usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "PW",
                            distance: 1439345.515f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 89304.21f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 5833706.846f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 6676861.717f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 5665495.485f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 7416467.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 5798919.984f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 5130480.889f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 5206037.744f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 7122731.281f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 5396278.61f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 2834800.383f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 5039874.895f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 1307364.202f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 4394675.291f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 5395346.743f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 4861831.705f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 2939913.118f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 5191084.111f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 2693448.44f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 8144017.773f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 2369071.313f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "SO",
                    name: "Somalia",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 11usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 13521113.004f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 659221.481f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 2003372.766f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 5489029.7f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 5066928.325f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 6140785.553f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 7145229.804f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 4890676.748f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 6866970.313f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 7026849.009f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 1194163.493f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 5911824.925f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 4672496.543f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 3993894.432f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 1977140.628f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 3403464.065f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 6051010.452f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 3769411.753f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 3526567.71f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 2144583.59f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 1930872.965f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 2570220.174f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 1545569.024f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 2070351.597f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 1898014.661f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 3111959.137f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 4955294.223f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 4608323.75f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 2017515.704f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 373817.14f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 4007751.53f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 4106145.344f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 4979416.039f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 6930147.95f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 6306027.785f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 4685448.414f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 4429285.663f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 2705158.588f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 6209156.174f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 6565327.252f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 6838476.518f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 2137968.433f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 6613547.355f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 6875760.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 4393359.408f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 4029719.328f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 3927639.41f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 3139033.57f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 4169594.98f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 4134373.141f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 3187195.726f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 8086388.674f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 3122441.279f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 7720001.612f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 2075460.466f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 1992915.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 4844170.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 1637193.846f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 5288547.053f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "BJ",
                    name: "Benin",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 3usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 10236039.863f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 4844170.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 4233531.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 2073667.379f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 4316911.039f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 136412.266f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 724423.618f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 2226436.814f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 1879671.056f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3752388.757f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 3413097.81f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 1462903.162f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 3486120.562f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 821889.443f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 4351251.343f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 2634349.922f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 5677560.752f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 1744650.768f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 2089580.795f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 4654279.078f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 3178160.295f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 3368795.161f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 4034687.061f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 1022365.25f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 2361432.929f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 1811894.727f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 2385228.09f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 4784813.81f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 3509010.514f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 4765419.611f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 844585.066f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 4991298.961f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 109041.69f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 4771261.508f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 6527145.842f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 954068.733f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 3323717.16f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 6798139.556f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 3202893.853f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 4122745.319f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 3061616.628f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3073332.111f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 5181351.63f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 3205342.427f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 305269.265f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 4034435.37f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 4138456.544f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 4803695.521f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 4505272.926f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 3411428.326f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 797165.943f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "GH",
                    name: "Ghana",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 6usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 10077082.806f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 5066928.325f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 4555261.588f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 2237289.026f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 4419175.96f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 170201.172f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 424223.188f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 1998010.368f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 1890490.53f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3786768.668f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 5049945.793f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 3718155.752f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 1174800.837f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 3524735.162f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 964424.161f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 6042530.937f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 4546244.433f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 2464138.005f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 5640057.939f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 1474924.758f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 1846924.414f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 4411004.689f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 4231472.422f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 3429624.177f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 3479862.628f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 4337011.576f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4579498.89f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 1215921.816f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 2141737.877f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 1551729.237f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 2207779.907f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 4876046.649f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 3666688.08f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 4739088.943f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 1056643.355f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 5225448.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 412581.437f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 4894520.62f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 6741422.347f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 1179989.712f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 3542988.989f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 7019551.014f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 4629462.948f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 4291642.535f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 2752637.619f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2962918.815f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 5414199.748f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 3465989.438f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 305269.265f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 4591308.013f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 4808092.43f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 4978643.291f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 4428938.518f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 3685804.503f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 771101.719f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "BH",
                    name: "Bahrain",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 4usize,
                    internet_exchanges_number: 4usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8104708.653f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 436851.587f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 4767703.745f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 3869569.857f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 2922797.757f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 111562.253f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 459353.355f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 44351.533f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 809434.841f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 303943.137f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 582359.858f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 2411064.446f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 1126348.479f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 3770831.199f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 3460048.101f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 1551558.481f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 1816175.498f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 3950370.768f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 2396680.902f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 3434587.829f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 4478665.322f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 1988081.69f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 6309666.283f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 5311285.552f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 5782787.513f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 6530338.021f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 1651103.886f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 5867225.048f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 3490655.858f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 2454277.812f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 6321361.843f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 5360248.864f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 5559456.78f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 3998304.958f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 4043411.842f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 1547445.651f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 5513632.921f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 7227162.36f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 2767745.031f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 4715977.019f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 4752446.496f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 7647661.858f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 1927699.788f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 6395681.374f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 4298908.349f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 4200467.733f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 10092135.547f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 4377213.692f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 4324957.484f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 3725859.803f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 9414133.728f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 3030781.073f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 6472661.823f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 10901686.118f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 3612321.781f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 5053413.292f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 4899529.743f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 3623060.591f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 6283237.575f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2885157.182f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 11526976.821f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 3345922.689f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 1948499.709f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 4268503.59f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 3851390.676f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 1573256.207f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 1701550.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 3026055.068f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 1621348.349f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 1677542.003f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 4036721.167f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 5733127.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 4153701.934f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 6073460.774f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 4596177.794f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 11072449.442f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 3316006.464f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 11290512.081f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 4562079.372f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 7615733.442f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 3031093.866f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 4431116.553f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 4128871.691f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 11815609.284f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 4590654.422f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 7202221.147f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 3868969.206f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 3634902.559f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 3862412.565f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 5171082.926f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "MK",
                    name: "North Macedonia",
                    continent: Some("Eurasia"),
                    other_names: vec!["Macedonia"],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 4usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9208930.732f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 2891144.19f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1481835.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 555558.418f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3528921.279f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 3316006.464f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 673896.296f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3936941.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 5948603.517f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1713779.198f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4251919.281f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3140219.113f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 2043975.778f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 2729457.043f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 3453670.353f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8477225.877f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 4611890.339f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 8651156.65f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4047442.887f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 182470.485f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 861737.811f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 9357338.442f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 2356412.177f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 2273480.541f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 779707.49f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1497139.586f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 2690824.53f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 8389266.782f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8471821.933f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4274605.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 1407495.889f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 7536266.77f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 10603907.931f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 1443877.718f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 2578723.194f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 3430859.29f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 8587265.146f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 2949974.286f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 1887220.092f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1769796.339f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 6814000.112f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 1061212.712f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1062337.5f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 409878.106f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 6227659.045f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 286759.247f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 3409214.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 7619131.813f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1247347.893f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 2243241.703f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1635973.968f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 7047884.615f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 446246.176f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 9270899.759f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 647716.071f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 8662656.763f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 83531.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 1715732.535f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 953345.256f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 910921.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 2019312.676f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 1629309.096f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1095915.854f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 1821398.198f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 1677882.177f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 837119.493f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2756870.807f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 988978.552f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 8714079.04f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 1488030.356f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 7779178.574f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 8197940.562f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 1521892.85f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 5587353.433f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 3778097.948f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 9997385.457f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 6851142.075f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 417372.615f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 1172192.114f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 6818606.623f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 8637696.876f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 1290276.75f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 9967545.391f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1299833.228f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2468576.82f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4030854.618f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 6312115.318f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 1855438.835f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "NP",
                    name: "Nepal",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 4944934.662f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3637139.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 7052745.492f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 6401781.126f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 2882670.667f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 3434587.829f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 6373687.446f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 2106017.383f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 6191852.57f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 1708753.847f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 9066505.722f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 7452226.392f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 7422765.484f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 3351731.555f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 3127341.72f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 1817562.786f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 2705926.3f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 2823485.904f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 6125828.608f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 5226468.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 3532044.252f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 8292936.796f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 7718595.413f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 6728275.516f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 5774124.443f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 3262722.699f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 2481821.31f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 4082813.701f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 1902442.315f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 7247667.026f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 1615723.949f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 4680433.726f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 4970655.029f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3761000.713f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 2965274.307f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 2961125.665f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4461498.665f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 5782959.847f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 5752608.211f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 11611913.874f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 6869812.261f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 6994857.95f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 6304146.354f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 10664584.005f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 5690636.066f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 7970477.245f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 12335053.691f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 5467517.525f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 6594687.051f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 7104093.348f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 2395427.003f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 6036029.106f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 3404020.155f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 5809814.902f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 11589958.891f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 5933371.117f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 4237197.42f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 6754452.335f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 5985999.154f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 4876456.052f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 4716091.259f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 5077159.242f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 4816597.509f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 4753803.408f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 6335398.768f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 8692913.402f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 6934480.56f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 2779577.308f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 6624568.429f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 12557606.756f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 5948603.517f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 11934126.835f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 6521402.338f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 928338.848f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 2955130.193f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 4221119.937f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 3021699.913f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 5543056.146f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 6718474.071f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 889297.608f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 12622217.821f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 6950856.385f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 4020389.616f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 5713443.571f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 4530430.683f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4404713.12f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 428207.454f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 7556968.093f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "GD",
                    name: "Grenada",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 5usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 2407990.225f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 2732813.23f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1779696.914f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1902071.163f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GY",
                            distance: 702737.394f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SR",
                            distance: 903809.846f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1708979.471f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 854190.772f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 2075131.426f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 2267018.926f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 703609.998f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3904900.661f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1547829.136f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 1366971.288f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 5545493.824f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 4011422.074f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 2205646.11f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 895314.959f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SX",
                            distance: 690162.744f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 63535.131f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 2907545.156f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 773279.89f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 718665.219f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5940064.715f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 471574.233f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 2376110.68f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 531690.52f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 1135621.741f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 368945.551f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 785895.858f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 147860.406f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 271290.859f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 241537.474f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 596814.092f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 572768.254f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 664654.01f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 299484.257f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 4785011.626f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 622862.399f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 3003710.957f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "MX",
                    name: "Mexico",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 16usize,
                    internet_exchanges_number: 3usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 1297845.646f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 596947.519f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 2232267.438f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1498038.217f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 2341454.917f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 2148577.272f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 2179909.202f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1209521.018f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 3395740.883f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 3653928.039f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 4537421.216f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1517408.838f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 2679696.871f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 1908562.681f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 896120.784f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 1692641.08f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 5932374.992f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 627365.059f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 1680440.825f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 618234.069f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 2538142.478f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 426932.102f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 1061363.953f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 2049511.349f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 3178953.216f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 4018567.797f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 3490533.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 3473031.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5719543.248f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 3860994.739f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 2360301.357f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 3918830.218f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 3293761.112f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 4103320.898f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 4183299.41f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 4004692.023f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 4011422.074f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 3667656.576f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 3714318.609f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 3971607.048f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 3684198.569f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 3809954.477f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "IL",
                    name: "Israel",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 5usize,
                    internet_exchanges_number: 20usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9935353.751f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 8981518.319f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 4751136.395f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 5686861.549f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 7857051.549f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 9414133.728f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 5555020.821f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 8747436.681f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 10664584.005f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 4958113.306f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 9454450.305f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 4240157.671f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 4186427.659f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 3635266.999f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 9545959.91f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 11113124.139f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 10237461.516f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 12809524.154f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 10045096.73f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 6079305.546f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1059031.202f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 13901492.816f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 5151585.229f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 3973437.057f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 2111818.878f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 5406066.938f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 8227530.587f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 12841649.045f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 9913374.908f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 8821233.047f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 4975790.859f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 12088647.473f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 14437372.347f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 370515.346f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 8638066.153f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 9352260.779f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 11603122.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 9177555.853f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 5218539.981f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 5296242.173f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 1002061.541f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 5224211.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 5425388.96f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 5840401.988f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1170091.539f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 6490853.17f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 2953392.089f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 1671199.131f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 5827224.751f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 4405680.331f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 4591828.952f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 12713789.723f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 5847956.85f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 13706305.945f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 2753336.13f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 6175988.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 7492273.63f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 5312256.159f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 5567092.09f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 8245550.736f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 7824013.162f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 6401505.652f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 8046947.709f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 7887469.534f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 5424801.295f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 5019576.729f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 5683585.096f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 12542116.284f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 4826675.374f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 1893023.378f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 6227659.045f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 2006463.804f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 4853398.796f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 10870166.254f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 9782716.421f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 12657049.436f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 12816452.029f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 6427235.333f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 5056738.535f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 11457924.911f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 2413279.184f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 4951087.524f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 13542025.577f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 5562998.596f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 6283459.568f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 10253912.722f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 10797243.257f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 4471738.304f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "CW",
                    name: "Curaçao",
                    continent: Some("South America"),
                    other_names: vec![],
                    cable_connections_number: 7usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 1560743.683f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 2096433.207f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1222083.228f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GY",
                            distance: 1317842.551f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SR",
                            distance: 1539397.513f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PE",
                            distance: 2297020.351f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 67675.405f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 275379.145f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GF",
                            distance: 1987510.807f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 3787898.622f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 1945676.534f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 889310.344f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 768642.388f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 820353.596f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 768186.186f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 112448.376f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 2156987.192f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 1617444.295f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 2148577.272f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 745372.747f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1536414.9f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1137517.511f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 2163350.912f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 877834.163f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 1952866.969f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 837098.86f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BO",
                            distance: 3241006.015f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PY",
                            distance: 4356579.332f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 5329106.77f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 5153841.795f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UY",
                            distance: 5430024.798f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "EC",
                    name: "Ecuador",
                    continent: Some("South America"),
                    other_names: vec![],
                    cable_connections_number: 9usize,
                    internet_exchanges_number: 3usize,
                    links: vec![
                        LinkTo {
                            code: "HN",
                            distance: 2029330.593f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1108176.443f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GY",
                            distance: 2891224.313f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SR",
                            distance: 3052712.687f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PE",
                            distance: 1206768.486f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 1952866.969f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 2685522.672f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 2538142.478f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 2252493.111f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BO",
                            distance: 2489588.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 2037825.642f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 2782520.749f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 2842228.198f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GF",
                            distance: 3452881.94f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 1954097.563f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 2150144.787f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 2097687.997f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 1386169.332f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 3151622.3f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 4707362.512f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 4542911.01f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 2694641.36f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PY",
                            distance: 3851444.725f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UY",
                            distance: 4726623.614f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "MA",
                    name: "Morocco",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 8usize,
                    internet_exchanges_number: 4usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 11561383.886f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NE",
                            distance: 5727565.127f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 8086388.674f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1863761.311f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 8208940.974f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 6713756.449f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 9021450.126f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 3189303.893f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 3166805.498f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 3105091.184f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 11439512.529f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 6545046.92f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 459171.036f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 4728605.826f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 10708923.926f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 6326759.476f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 6907145.584f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 4057634.876f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 8149912.409f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 5527153.596f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 6221256.638f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 3006391.992f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 11628547.967f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 8849793.056f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 6578146.867f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 10077113.623f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 3740989.115f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 3310020.285f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 4795702.467f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1619247.82f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 10956381.429f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 10843566.057f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 1364394.726f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 7415351.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 9924087.173f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 12408694.459f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 3421071.506f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 2631447.438f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 6367930.134f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 641730.593f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4583375.142f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 4100794.245f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 2950173.559f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 3616508.339f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 2634847.742f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 9490956.738f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 3179195.545f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 9138652.316f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 9470625.306f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 5445722.184f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 9200157.281f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 14649782.243f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 4823303.931f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 9458746.973f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 11581619.874f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2650501.68f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 10798456.085f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 5533329.896f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 4024708.157f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 10991257.869f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 3294202.882f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 12157415.589f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 8616689.234f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 10981144.861f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 5545538.949f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 5941117.128f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 12344689.84f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 98281.814f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 3202893.853f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 8725542.573f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 2718558.768f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 9386630.665f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 7356494.021f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 4629462.948f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 8256488.677f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 9433393.688f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 7373072.72f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 3908978.381f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "SX",
                    name: "Sint Maarten",
                    continent: None,
                    other_names: vec!["Saint Martin"],
                    cable_connections_number: 6usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "PR",
                            distance: 325377.248f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 20795.997f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 269880.556f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 190553.62f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 95373.009f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 172483.597f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 358507.717f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 837468.919f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 166519.151f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 32174.679f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 585106.842f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 440502.633f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 669434.777f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 690162.744f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 503055.23f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 166473.456f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 61439.264f64,
                            link_type: LinkType::Submarine,
                        }
                    ],
                },
                Country {
                    code: "IE",
                    name: "Ireland",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 17usize,
                    internet_exchanges_number: 13usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9659842.215f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 5127917.755f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 793950.446f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 1722602.02f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 4910667.131f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 5559456.78f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 1613023.542f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 5612578.957f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 7718595.413f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1577567.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 6135208.973f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 1793160.304f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 211323.588f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 1000652.023f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 5696118.019f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 9622903.841f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 6691957.125f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 10375060.827f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 6261446.526f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 2115588.918f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 3122479.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 11247212.403f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 1897344.048f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 4172848.988f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 4795702.467f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 4825692.015f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IM",
                            distance: 127821.877f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 1173747.429f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 1199524.664f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 1402943.274f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1786121.942f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1955186.992f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 4650921.859f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 10197132.501f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 9131769.779f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 5850308.058f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 1037976.905f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 9332029.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 12359465.894f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 3717311.593f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 4798754.471f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 5605296.139f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 9891034.137f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 5213924.803f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 2036556.286f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 2029448.522f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 4542807.499f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 1250862.894f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1484003.909f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 1875101.227f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 3973437.057f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 2548494.396f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 5349772.449f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 2255138.549f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 664344.552f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 9196832.185f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 1936529.395f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 11122551.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2839645.314f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 6528953.725f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 2230179.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 3754868.132f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 1339878.446f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 1788004.283f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 4280109.876f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 3897321.104f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 2715694.634f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 4093093.812f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 3950239.978f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 1528360.814f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2088857.056f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 1759126.951f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 10327507.314f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 1094720.924f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 5514850.396f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 2273480.541f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 5965795.979f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 7564342.383f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 5991471.203f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 11300965.538f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 9081603.176f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 2528530.329f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 1128842.951f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 8607273.502f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 6374400.452f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 984054.567f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 11589389.199f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 2005231.77f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 3318321.922f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 6283025.345f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 8011531.641f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 554100.438f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "NE",
                    name: "Niger",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "SO",
                            distance: 13521113.004f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 13901718.84f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 12198042.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 14411110.386f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 10152850.172f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 9776928.563f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 8138729.871f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 12114802.847f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 11878366.274f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 9140691.258f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 13319857.136f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 11038273.253f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 14546643.112f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 11184842.111f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 15803996.052f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 8778186.862f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 8328644.602f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 13142129.47f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 8137268.373f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 11703028.225f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 4216908.805f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 7983852.219f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 8665061.335f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 7869884.551f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 14804701.089f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 8553998.251f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 14716109.23f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 11069179.789f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 14916923.082f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 10403980.753f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 14934374.22f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 16501687.412f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 11112745.387f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 9420537.999f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 16654213.288f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 5727565.127f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 14358353.717f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 7364625.679f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 15099999.038f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 13083721.941f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 10236039.863f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 10077082.806f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 10414135.379f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 13973362.753f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 15034904.69f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 12797605.637f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 13085922.626f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 9467649.423f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "TC",
                    name: "Turks and Caicos Islands",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 1usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 1759641.823f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 1792845.718f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 662445.645f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1603152.722f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 405555.779f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 1137517.511f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 741255.481f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 449207.828f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 1370121.946f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 1029081.577f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3131527.68f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 1748900.521f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 1653136.087f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 1517408.838f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 1324880.891f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 934814.285f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 1861782.978f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 272219.464f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 1146028.191f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 351934.4f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 4002484.249f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 953533.354f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 1067298.465f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 1512740.627f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 872644.63f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 866992.598f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5036868.857f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 1265498.784f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 365472.851f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 1346274.436f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 1131954.887f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 1684621.23f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 1646449.064f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 1463069.097f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 1547829.136f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 1056980.733f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 1105859.815f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 1413783.723f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 1064005.221f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 1198249.912f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "MS",
                    name: "Montserrat",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 1849399.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 1588802.237f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 711243.001f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1307240.805f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 469801.289f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 452868.368f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 176975.176f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 1329046.421f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 1373014.182f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3017373.334f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 365472.851f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 645657.135f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 3637731.685f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 2360301.357f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 829881.007f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 1388913.572f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SX",
                            distance: 172483.597f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 417677.283f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 1569643.739f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 1222710.423f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 297522.823f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 4849568.026f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 90685.014f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 1550805.014f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 79843.57f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 186142.759f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 679533.695f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 58572.524f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 141924.544f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 268400.902f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 497117.736f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 531690.52f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 331706.059f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 674449.593f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 782193.085f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 1465440.861f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 1407392.553f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 1829754.922f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "VE",
                    name: "Venezuela",
                    continent: Some("South America"),
                    other_names: vec![],
                    cable_connections_number: 18usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 1414323.212f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 1969554.58f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1399233.577f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1416220.4f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GY",
                            distance: 1127110.007f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SR",
                            distance: 1348368.57f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PE",
                            distance: 2767696.286f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1419480.438f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 275379.145f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 876763.34f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1518998.3f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 2424792.738f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1146028.191f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 2049511.349f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BO",
                            distance: 3091585.824f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 86075.448f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 2037205.664f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 827085.321f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 1476628.436f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GF",
                            distance: 1722355.002f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 3517879.744f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 2209790.807f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 769735.381f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 585970.202f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 854982.158f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 5346130.485f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 4878776.421f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 2035540.171f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 901153.884f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 1954097.563f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PY",
                            distance: 4179669.127f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UY",
                            distance: 5256210.9f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "KZ",
                    name: "Kazakhstan",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 1usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 5828956.544f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 2729142.611f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 4320087.227f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 3850385.676f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 333703.276f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 2922797.757f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 3764440.959f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 913505.99f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 2882670.667f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 3347496.444f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 1683161.408f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 6433499.542f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 4650369.468f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 4542890.364f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 2966528.256f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 4954587.745f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 2617202.126f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 5469638.417f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 3002316.384f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 3679027.978f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 3078260.88f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 6394350.132f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 5833089.825f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 4910667.131f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 4265393.654f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 2956650.891f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 1501375.275f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 5319057.197f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 5025409.493f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 981722.882f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 4611187.801f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 4463524.543f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 7450463.539f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 3169196.343f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 2546985.19f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 2454023.862f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 5103024.497f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3690247.607f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 2918157.016f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 2899124.424f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 8770941.739f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 4245823.237f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 4461541.882f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 3793730.003f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 7857051.549f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 3339059.076f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 5089929.503f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 9523805.099f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 2715775.436f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 3717491.613f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 4339250.621f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 4895110.603f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 3463777.125f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 6250674.808f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 3658465.245f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 3484974.807f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2091597.735f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 4138018.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 3284058.842f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3461187.299f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2977752.667f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 2474755.293f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 3255610.722f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 3068812.579f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 3668515.39f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 6225532.923f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 4484212.831f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 5419281.035f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 3832891.223f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 9740370.271f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 3528921.279f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 9349391.3f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 3716408.815f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 3022988.171f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 2859265.158f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 6527092.813f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 5184094.977f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 3116269.204f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 4011459.109f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 3752389.375f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 10001299.868f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 4256399.564f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 6684632.681f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 2932851.889f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 1648982.149f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4381177.326f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 3124687.283f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 4831917.539f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "VG",
                    name: "Virgin Islands, British",
                    continent: Some("North America"),
                    other_names: vec!["Virgin Islands (U.K.)"],
                    cable_connections_number: 4usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 2261043.62f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 2380943.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1281157.444f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1927532.143f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1153443.663f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 837098.86f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 159322.924f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1396219.243f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 1545422.401f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 164042.905f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3260661.014f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 872644.63f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 830537.984f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 4814740.245f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 3490533.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 1717167.122f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 869830.896f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SX",
                            distance: 166473.456f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 688980.826f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 2490339.139f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 587411.218f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 233261.562f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 795987.113f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 623295.729f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 915925.964f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 563792.384f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 405210.59f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 773279.89f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 491508.105f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 327330.58f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 1474514.097f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 2172522.731f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 2782520.749f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 50099.974f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5278578.709f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 2117424.593f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 1222710.423f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 838553.981f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 184748.154f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 193846.926f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 2657042.493f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "PM",
                    name: "Saint Pierre and Miquelon",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 4863592.838f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 4489595.426f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 3723662.397f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 4319165.585f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 3466238.923f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 3554512.17f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 3055717.203f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 1779547.004f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 3252532.269f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 39597.46f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 3131527.68f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 3469199.633f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 3783653.766f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 4537421.216f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 3791772.516f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 4038300.039f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 3797893.862f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 4363106.486f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 3260661.014f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 3306611.689f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 2036617.353f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 3443221.822f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 4550545.173f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 3017373.334f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 3343841.947f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 3550469.287f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 4046678.622f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 4057970.463f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 3776395.016f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 3686366.866f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 3904900.661f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "US",
                            distance: 3320133.822f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 3327224.619f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 3347906.848f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 3620721.418f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 3284047.557f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 4670859.343f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 3355817.143f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "AE",
                    name: "United Arab Emirates",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 21usize,
                    internet_exchanges_number: 5usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 7858698.659f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 2017515.704f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 951624.121f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 5339607.114f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 3709599.544f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 4326770.926f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 2859265.158f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 582359.858f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 4393510.927f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 2192644.899f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 2955130.193f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 4826096.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 1645992.74f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 6495338.625f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 6230369.258f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 5919661.09f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 6148063.08f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 492801.789f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 5830442.85f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 1077769.155f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 5215364.092f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 283435.825f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 3956169.85f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 2962429.227f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 5717669.572f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 5929593.64f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 5991471.203f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 4274675.131f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 4381027.345f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 1675413.651f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 5078481.299f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 6898910.31f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 2525189.775f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 4964890.566f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 4042133.362f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 5490993.181f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2528677.234f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 4757307.002f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 936028.951f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 1960306.332f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 159640.578f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 5912700.66f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 1796265.137f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 4604271.832f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 4513785.793f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 10501035.383f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 4836566.843f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 4855079.393f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 4187189.839f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 9782716.421f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 3491419.474f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 6830331.65f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 4572052.502f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 11310759.304f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 3956341.79f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 5388900.648f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 5328002.639f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 3344992.693f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 4058288.513f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 8951829.504f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 5175906.352f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 3292431.696f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 11771466.622f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 3801868.262f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 4253910.754f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2290902.732f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 4725450.978f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 5941117.128f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 4248729.731f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 2159660.619f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2190033.821f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 3381943.289f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 2137865.626f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2224992.22f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 4463324.974f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 5908334.215f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 4646191.831f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 5461680.87f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 4994281.499f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 11489230.326f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 3778097.948f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 11610399.455f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 4949235.339f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 1830191.475f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 2671651.846f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 1810825.408f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 2046770.978f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 3456414.919f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 6843942.524f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 6619450.213f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 3046195.972f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 3468082.835f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 4863359.107f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 12164909.271f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 5035449.427f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 4219819.238f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 3809127.079f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 3383186.492f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 5626874.494f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "JO",
                    name: "Jordan",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9342297.515f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 1255098.643f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 3495079.744f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 2559515.452f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3461187.299f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 1573256.207f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 2693125.98f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3340838.582f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 4876456.052f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 3548107.691f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 3246123.921f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 4788212.251f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 4081672.29f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 4720037.919f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 1699600.625f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 7788848.698f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 3178639.95f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 7414526.869f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 2341578.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 2166620.275f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1244939.207f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 7894612f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 3813278.262f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 4280109.876f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 2208785.457f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 3184598.079f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 2005050.213f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 7237470.561f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8483194.966f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 3743511.249f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 3330955.034f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 6290555.255f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 9219921.627f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 622577.235f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 1127797.683f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 1930909.71f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 7806888.63f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 988157.981f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 3531838.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 3414349.512f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 8801330.651f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 3036840.712f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 2903086.332f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 2406225.368f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 8245550.736f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1766057.264f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 5409327.471f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 9599478.816f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 2775530.425f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 4126793.872f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 3653998.862f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 5334240.192f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 2420178.391f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 7335543.362f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1450656.351f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 10650210.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 2074768.739f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 1524946.605f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 2941475.385f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 2783770.276f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 524451.25f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3794964.146f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 2159660.619f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 3989832.95f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 601853.453f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 2227866.745f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 264240.759f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 496087.004f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 2840214.411f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 2692319.579f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 7595289.183f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 3474861.655f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 9748154.272f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 2019312.676f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 10216635.386f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 3482646.929f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 9096528.999f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 4992578.338f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1879059.701f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 3191502.306f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 5637699.413f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 10653226.342f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 3297240.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 8754763.041f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 2978195.772f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 3384929.363f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 2011886.947f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 5295884.32f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 3820083.339f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "IT",
                    name: "Italy",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 30usize,
                    internet_exchanges_number: 45usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 10167729.227f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 5911824.925f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3585871.296f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1690997.235f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 6197461.8f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 472797.602f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 4265393.654f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 3998304.958f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 655825.849f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4710808.213f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 6728275.516f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1853416.634f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 5030609.488f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 4526373.358f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 9982218.606f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 5608373.599f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 1644037.782f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 2005376.888f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 2489785.914f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 3639022.452f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 9368275.272f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5070485.606f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 8953328.969f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4399188.677f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 604751.146f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1169478.72f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 9791668.002f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 1582693.021f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 7682305.441f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1786121.942f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 1693553.067f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 2208785.457f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 1645340.282f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4274675.131f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 9511539.354f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3085303.536f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 6074099.231f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 9378795.577f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 9267002.388f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 3743976.691f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 9575513.524f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 4017205.04f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 7272101.924f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 7451310.842f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 7950966.164f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 993826.143f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 99760.066f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 4411004.689f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 8762491.374f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 4137693.731f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 6455712.815f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 4256123.953f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 4894602.108f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 8186854.915f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 3798144.989f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 186630.306f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 159961.122f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 2111818.878f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 1808240.955f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 10635003.667f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1046399.468f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 9405618.621f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 13178563.318f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 10745140.292f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 1619247.82f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 1897817.962f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 217104.662f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 105330.052f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 533462.038f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 512354.63f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1826760.203f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 3469498.362f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 5042122.287f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3292467.092f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 4161723.072f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 9347757.241f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 2183013.705f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 2084098.137f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 6239941.652f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 572837.153f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1044934.731f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 3109894.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 7033488.769f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1746271.392f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 2246064.589f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1267180.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 832971.712f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 8310846.034f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 800327.308f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2494014.079f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 537752.07f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 1210094.577f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2297065.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1793921.104f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 2421025.529f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 873513.56f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 1389953.861f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 7178903.329f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 779707.49f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 7744752.583f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 1488708.676f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 7522417.609f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1190329.704f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 926536.658f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 8128039.076f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 880375.431f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1681302.218f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 3055394.902f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 7091419.052f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "CI",
                    name: "Ivory Coast",
                    continent: Some("Africa"),
                    other_names: vec!["Côte d'Ivoire"],
                    cable_connections_number: 6usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 9776928.563f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 5489029.7f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 4964049.468f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 2521400.463f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 4672103.024f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 588111.808f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 424223.188f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2788994.425f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 833243.861f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 1473899.15f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 2207218.577f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 2383326.389f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3740174.766f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 3710060.412f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 4894023.158f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 5060122.922f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 1799939.299f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 4990959.86f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 5228774.454f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 4526373.358f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 1593832.139f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 6014030.855f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 5261247.943f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 4321827.118f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 4756534.005f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 4734585.649f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 6455183.462f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4959339.464f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 724423.618f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 1646571.428f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 1578318.032f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 1164123.171f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 1075803.359f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 756841.097f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 1923186.695f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 1317149.447f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 1478522.299f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 3166805.498f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 4129073.548f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 4896798.548f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 2370249.846f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 3831209.942f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 3573396.297f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 5113503.444f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 3824603.295f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 5610414.738f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 5168594.157f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 7105952.743f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 3792967.244f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 7390533.411f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 4617297.992f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 5797766.207f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 3873821.244f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 4101743.15f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 829815.432f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "MD",
                    name: "Moldova",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 11096739.09f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 10468489.369f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 6143709.593f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 7064581.279f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 9523805.099f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 10901686.118f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 6962790.166f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 10409054.943f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 12335053.691f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 6526276.096f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 11104077.333f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 5103583.074f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 5592628.829f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 5194947.409f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 11037326.855f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 12549469.506f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 11855356.905f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 14394221.79f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 11578489.139f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 7455105.472f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 8472112.881f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 15497223.51f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 6110039.201f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 5349772.449f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 7033488.769f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 6977978.884f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 9820466.181f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 14463876.443f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 11229376.898f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 10490756.33f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 6268763.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 13738254.085f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 15833586.56f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 9060202.501f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 10133081.228f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 10899091.057f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 13070952.227f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 10529501.606f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 6825265.005f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 6894107.335f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 809927.318f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 6570177.537f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 6701910.05f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 7214739.182f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 1671199.131f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 7897171.473f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 4540568.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 7385815.047f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 5998934.236f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 6004892.702f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 14355645.158f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 7282028.075f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 15293254.121f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 8148868.66f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 2572040.022f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 7578837.951f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 9028336.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 6671173.959f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 7062123.727f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 9599478.816f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 9246455.7f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 7941502.942f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 9429857.451f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 9296976.289f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 6865637.538f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 5875540.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 6931099.584f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 14088997.681f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 6316481.209f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 227823.705f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 7619131.813f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 1507113.448f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 6363625.309f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 12529779.168f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 11310759.304f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 13956386.399f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 14389424.489f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 7873112.595f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 6474502.907f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 13121280.568f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 1340779.842f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 6329506.299f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 14966586.567f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 7118267.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 7935581.346f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 11563508.345f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 12460776.958f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 5780830.846f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "LT",
                    name: "Lithuania",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 3usize,
                    internet_exchanges_number: 15usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8200837.518f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3441231.945f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1391821.934f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 1209796.856f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 2932851.889f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 3868969.206f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 1032902.994f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3607434.856f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 5713443.571f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 344258.892f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4145068.215f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3523588.275f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1738810.43f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 1929908.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 3997107.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 7790571.659f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 4767066.483f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 8378183.507f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4482194.758f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1315187.526f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1749928.593f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 9242249.269f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 3064645.45f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 2005231.77f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1681302.218f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 53542.587f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 2715369.936f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 8192745.183f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 7538175.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 3852438.511f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 1744869.2f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 7327324.693f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 10364524.42f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2356211.938f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3094744.701f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 3791021.802f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 7999111.76f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3832903.842f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 594303.919f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 474229.605f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 6312676.215f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 1419392.586f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1734285.738f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 1251855.512f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 5562998.596f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1381563.23f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 2610688.801f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 7118267.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 267934.627f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 1189017.941f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1407008.249f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 7286341.161f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 913157.994f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 9117450.887f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1891036.764f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7727651.749f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1216521.077f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 1930451.016f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 1333261.913f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 471359.987f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 2978195.772f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2428992.812f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 842928.623f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 2727874.581f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2518000.004f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 847172.954f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3428721.838f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 1875312.03f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 8348890.666f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 911312.798f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 7308047.477f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1299833.228f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 7422778.756f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 811136.758f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 5584472.922f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4219819.238f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 9423372.434f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 7273296.06f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1162055.023f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 1105753.829f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 6602250.602f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 7951067.802f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 1352559.531f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 9615715.492f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 1451058.723f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4916074.792f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 6010494.225f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 1902434.994f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "BS",
                    name: "Bahamas",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 25usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 1789244.031f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 1606872.704f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 722128.402f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1723414.712f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 522679.321f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 1536414.9f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 1186055.896f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 199363.164f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 1520942.968f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 1630727.158f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 1209521.018f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 1558580.056f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 449207.828f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 1669933.983f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 714110.312f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 1518998.3f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 730069.814f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 1419127.095f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 1547988.01f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3055717.203f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 3485375.703f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 743986.078f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 1506966.551f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 2042371.872f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 1396219.243f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 1393788.482f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 4842320.737f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 1791443.031f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 176975.176f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 1874908.642f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 1590746.464f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 2208799.903f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 2176326.853f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 1993032.066f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 2075131.426f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 1580967.134f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 1630038.902f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 1943256.388f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 1584654.556f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 1720715.295f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "LB",
                    name: "Lebanon",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 5usize,
                    internet_exchanges_number: 3usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8858600.513f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 1278004.347f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 3157091.37f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 2232522.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3068812.579f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 1677542.003f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 2340413.008f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3053902.947f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 4753803.408f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 3101524.17f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 3071082.777f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 4637202.326f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 3715810.274f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 4314354.493f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 1814309.843f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 7652810.178f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 3178056.011f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 7369706.522f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 2438442.548f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1843277.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 836337.408f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 7931014.415f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 3705813.626f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 3950239.978f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1897817.962f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 2721219.331f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 1679601.86f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 7051921.185f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8022284.401f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 3451863.87f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 2798099.914f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 6239495.068f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 9236241.02f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 201647.879f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 1028124.634f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 1906824.51f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 7633389.055f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 1477109.031f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 3058271.241f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 2942315.328f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 8491830.699f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 2731343.36f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 2652654.328f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 2083059.645f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 7887469.534f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1402330.238f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 5007728.23f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 9296976.289f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 2304138.689f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 3684267.406f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 3304838.193f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 5462256.566f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 2039543.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 7874322.532f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1207680.132f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 10225221.584f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1720355.461f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 1053847.122f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 2627518.555f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 2361580.219f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 496087.004f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 117381.864f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1744220.711f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 232295.572f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 664312.162f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 2224992.22f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 4022932.977f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 2462752.676f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 4088215.053f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 2476223.458f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 7514916.704f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 3077177.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 9456146.971f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1677882.177f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 9836026.5f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 3072099.218f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 8965773.069f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 5199370.447f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1467443.757f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 2835900.609f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 5558960.585f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 10300541.088f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 2967957.596f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 8712075.349f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 2518000.004f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2892188.196f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 2413109.124f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 5161728.632f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 3525333.65f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "VC",
                    name: "Saint Vincent and the Grenadines",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 9usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 2465939.337f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 2764320.852f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1786821.41f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1944357.467f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1699414.499f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 790189.871f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 2042371.872f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 2172908.823f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 597678.091f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3797893.862f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1512740.627f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 1355863.164f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 5500105.817f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 4018567.797f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 2212134.217f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 944233.177f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SX",
                            distance: 585106.842f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 63535.131f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 346807.682f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 489837.568f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 417677.283f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 240700.264f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 277664.892f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 451579.521f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 556955.149f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 163929.985f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 172947.95f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 101792.921f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 643677.73f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 688980.826f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 2929639.313f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5833667.262f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 2419068.833f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 1107767.16f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 839923.738f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "US",
                            distance: 4739754.638f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 540384.297f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 3037192.906f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "AN",
                    name: "Netherlands Antilles",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 1626017.084f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 1962680.633f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1099057.804f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1120269.227f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1115573.41f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 522317.164f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1590746.464f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 2282366.563f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 924226.535f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 4046678.622f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1131954.887f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 822951.146f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 5053357.903f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 3293761.112f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 1512285.943f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 115546.503f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 839923.738f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 2155702.279f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 838553.981f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 788463.442f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 6036866.721f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 913787.766f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 1592779.565f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 1465440.861f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 757495.089f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 887642.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 834615.292f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 1018760.427f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 884351.509f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 785895.858f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "US",
                            distance: 4300609.867f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 867369.639f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 879655.987f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 891127.83f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 914620.729f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 2229653.921f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 940765.401f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "LY",
                    name: "Libyan Arab Jamahiriya",
                    continent: Some("Africa"),
                    other_names: vec!["Libya"],
                    cable_connections_number: 18usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 9420537.999f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 4134373.141f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 4569139.233f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 4555618.725f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 6446492.334f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 3410013.45f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 3792967.244f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 4119194.33f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 4210595.034f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2100632.364f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 2464317.904f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 2464446.923f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 4178317.467f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 6130605.22f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 3759840.447f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4471931.386f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 5641100.822f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 1733981.581f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 5943520.135f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 6584908.606f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 4192511.192f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 4161347.146f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 533462.038f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 4138693.248f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 1393828.675f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 2355312.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 2855614.752f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 6432620.884f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1306971.65f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 4111120.408f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 4151777.033f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 3772668.323f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 6923316.081f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 874874.789f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 6997635.071f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 3325949f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 5614050.86f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 3191617.207f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 6661183.105f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 330674.266f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 7117689.92f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 3543861.959f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 1569030.238f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4253910.754f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 3864288.835f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 6081258.275f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 7238178.635f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 4024708.157f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 5736503.553f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 4633428.033f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 5777436.78f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 4009145.307f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 3323717.16f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 3542988.989f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 4715761.71f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 6413477.32f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 3863517.455f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 3001562.948f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "TG",
                    name: "Togo",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 10152850.172f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 4979416.039f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 4358003.477f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 2185241.979f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 4374176.232f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 588111.808f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 170201.172f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2994623.596f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 245132.912f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 914531.545f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 1822616.574f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 2873621.685f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3762348.85f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 3514535.81f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 4738531.696f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 3189303.893f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 136412.266f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 1113336.995f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 2118039.849f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 3548975.759f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 1328795.021f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 888238.008f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 4448079.617f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 2567435.629f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 5777906.122f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 1616132.311f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 1970554.198f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 3297524.671f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 3402248.01f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 4167528.037f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 2251078.949f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 1686547.987f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 2291166f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 4837553.047f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 3564871.782f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 5104298.963f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 4837862.201f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 6632475.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 982062.011f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 3410013.45f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 6906390.214f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 4208510.935f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 5293873.975f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 3328301.571f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 4148445.925f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 4258456.326f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 4883526.299f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 4642123.232f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 3539609.75f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 756598.158f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "LS",
                    name: "Lesotho",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 14804701.089f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 4393359.408f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 3113803.031f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 2779673.683f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 489663.357f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 4837553.047f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 5113503.444f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 6708602.07f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 2984789.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 4892720.342f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 5692281.483f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 1487802.895f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 3964108.606f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 1688991.964f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 3700018.123f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 2191948.448f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 6054081.673f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 6510869.9f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 2891310.23f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 7730624.228f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 5540142.297f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 10589576.399f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 6868032.812f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 6171674.547f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 7035447.75f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 7583072.334f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 187145.268f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 4094519.833f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 2555694.292f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 4676217.289f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 491558.235f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 2953396.149f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 3976456.25f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 6923316.081f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 3280371.132f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 9490956.738f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 1325425.245f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 7454459.314f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 2590565.698f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 3055831.074f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 4784813.81f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 4876046.649f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 6631604.062f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 2819002.676f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 994273.375f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 4849332.086f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 3338739.408f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 5581979.102f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "YT",
                    name: "Mayotte",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 3usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 15099999.038f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 2075460.466f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 1144953.998f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 3549094.013f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 2466001.633f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 5293873.975f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 5797766.207f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 7411871.811f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 3451375.097f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 3329104.819f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 6539422.205f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 3419141.834f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 4484625.293f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 1145384.757f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 5481061.691f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 843285.649f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 6873840.179f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 7260975.316f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 2032358.435f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 6986307.609f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 3709156.668f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 11269848.703f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 7542683.98f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 6960541.59f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 7536287.305f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 2590565.698f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 6616360.581f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 2775236.4f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 4289175.504f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 242992.293f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 4966365.066f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 2099041.243f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 1412873.399f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 4318238.786f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 5777436.78f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 1637410.445f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 9386630.665f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 1628033.028f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 8241361.536f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 2054715.604f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 5181351.63f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 5414199.748f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 4999784.421f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 1130295.276f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 1596324.144f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 2721965.815f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 2014996.143f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 5862221.769f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "KR",
                    name: "South Korea",
                    continent: Some("Eurasia"),
                    other_names: vec!["Korea"],
                    cable_connections_number: 11usize,
                    internet_exchanges_number: 13usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 1001536.955f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 7276386.876f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 9072375.61f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 8678591.528f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 5025409.493f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 7227162.36f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 8540389.996f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4997289.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 4082813.701f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 7674381.266f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 5239627.758f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 1649155.707f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 10771715.113f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 9556261.825f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 8321504.491f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 7184265.397f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 2001094.937f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5949695.333f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 3650440.439f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 6775469.952f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 8598343.688f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 8561594.282f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 4560753.73f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 10602210.4f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 9131769.779f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 9511539.354f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 7458772.123f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 6346839.345f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 4292068.969f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 8791169.808f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 8483194.966f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 10753471.019f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 6898910.31f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 8614151.234f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 5720281.151f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 4381592.925f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 2509428.531f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 5101465.461f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 8958598.313f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 2917878.071f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 8864890.794f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 5868112.635f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 9698553.259f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 7551827.529f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 3869700.082f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 3619232.044f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 10843566.057f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 8371570.825f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 8481910.765f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4594418.049f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 7253602.578f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 6691925.1f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 2044729.235f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 7214626.846f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 7267767.26f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 10869591.99f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 8957525.103f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 9258668.586f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 8661477.613f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 9913374.908f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 8320181.175f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 8489983.625f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 11229376.898f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 7412342.233f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 7718962.571f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 8779020.27f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 8304647.473f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 9243202.515f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 8414809.152f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 7109444.041f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 8869923.192f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 7988389.906f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 7942982.53f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 7377079.163f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 8176810.197f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 8022284.401f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 8380683.381f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 9351815.671f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 8271333.827f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 11436361.454f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 8471821.933f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 10066266.003f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 8132025.563f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 6684102.296f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 8077581.017f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 8619588.689f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 3900524.579f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 10704050.065f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 8858386.875f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 7538175.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 6097818.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 8422483.616f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 3708155.61f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 9303839.214f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "SZ",
                    name: "Swaziland",
                    continent: Some("Africa"),
                    other_names: vec!["Eswatini"],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 14934374.22f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 3927639.41f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 2665098.864f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 2766973.536f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 559831.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 4837862.201f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 5168594.157f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 6797326.336f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 2913751.587f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 4530054.518f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 5793761.873f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 1726898.867f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 3951278.024f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 1235087f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 3977164.265f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 1734163.499f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 6156228.578f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 6606097.655f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 2557084.521f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 7552537.892f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 5148215.452f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 10723933.026f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 6953371.376f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 6269372.604f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 7088153.384f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 491558.235f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 7361973.424f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 676536.995f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 4017599.565f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 2065399.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 4637654.894f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 2539098.644f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 3925830.939f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 6661183.105f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 2869871.551f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 9458746.973f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 944189.41f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 7571054.983f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 2099041.243f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 2711128.801f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 4771261.508f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 4894520.62f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 6283190.389f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 2376722.895f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 502723.931f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 4409466.421f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 2963949.988f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 5563800.707f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "SI",
                    name: "Slovenia",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9373141.275f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3443294.311f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 935744.083f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3850385.676f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 3869569.857f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 208886.818f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4348264.547f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 6401781.126f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1429514.019f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4722157.741f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2664794.244f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1500452.241f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 2251121.249f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 4007158.369f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8800616.535f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5132994.785f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 9107675.905f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4596518.672f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 393127.377f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1416016.824f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 9851491.506f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 1983319.756f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1722602.02f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 472797.602f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1361140.219f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 3167548.789f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 8862828.763f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8678591.528f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4663087.304f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 872101.237f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 8003569.567f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 11075727.29f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 1996348.066f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3127051.105f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 3970629.477f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 8948580.233f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3492815.879f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 1726163.387f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1623188.831f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 6260059.731f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 510048.621f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 611726.488f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 153646.713f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 5686861.549f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 838895.922f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 2913556.794f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 7064581.279f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1276122.095f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 1879364.401f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1098953.163f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 7588030.181f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 386728.392f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 9756985.974f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1134047.637f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 8162376.298f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 524908.568f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2202955.618f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 399047.905f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 739261.52f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 2559515.452f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2184854.657f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1377623.118f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 2370617.918f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2232522.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 437677.135f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2375218.775f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 676814.958f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 9146634.79f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 1049115.062f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 7223912.998f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 555558.418f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 7666250.308f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 1119997.057f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 6087872.712f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4326770.926f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 10369320.369f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 7404282.269f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 884632.419f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 652856.961f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 7280930.983f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 8093721.686f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 738579.753f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 10408675.275f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1209796.856f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2588598.568f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4567250.298f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 6750580.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 1301635.267f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "BR",
                    name: "Brazil",
                    continent: Some("South America"),
                    other_names: vec![],
                    cable_connections_number: 41usize,
                    internet_exchanges_number: 141usize,
                    links: vec![
                        LinkTo {
                            code: "AO",
                            distance: 5746132.828f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 4807748.049f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GY",
                            distance: 3122775.299f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SR",
                            distance: 2943932.086f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 4642357.124f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PE",
                            distance: 4321117.43f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 3787898.622f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 3898624.349f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 4869267.029f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 5932374.992f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BO",
                            distance: 2309664.075f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 3096677.571f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 3743481.873f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 5435133.625f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GF",
                            distance: 1808249.138f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 3517879.744f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 4707362.512f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 4378654.671f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PY",
                            distance: 1493762.002f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 3003286.732f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 7687956.764f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 2652349.237f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 4328517.139f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 5914620.407f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 5579225.456f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 4088405.966f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 3214337.033f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 4735230.103f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 5944769.146f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UY",
                            distance: 1473831.604f64,
                            link_type: LinkType::Submarine,
                        }
                    ],
                },
                Country {
                    code: "CN",
                    name: "China",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 38usize,
                    internet_exchanges_number: 4usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 2870993.778f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 6680113.247f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 9019376.701f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 8800616.535f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 4954587.745f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 6530338.021f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 8703332.362f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4628788.92f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 3127341.72f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 8066223.681f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4625388.701f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 664763.028f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 10691655.342f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 10027074.737f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 8960112.939f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 6336287.907f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 8211256.553f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 7788848.698f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 10883162.252f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 5830442.85f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 2001094.937f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 7626703.653f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 4275020.966f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 9368275.272f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 2381517.004f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 2290997.688f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 1130175.938f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 1948676.886f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 2588097.629f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 4472962.656f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 8623946.3f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 2185192.028f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 8230759.835f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5324040.025f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 8218589.714f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 5108967.136f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 6169702.261f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 9660331.085f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 7093001.172f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 3106731.398f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 10708923.926f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 7985762.859f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 9199904.307f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 11411195.748f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 3398610.534f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 7358333.457f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 1722514.012f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 8631446.097f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 10783802.087f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 9622903.841f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 7761318.536f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 6002359.465f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4249956.403f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 6741869.372f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 6030094.125f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 556367.086f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 7598991.404f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 7623928.646f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 12101482.156f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 9171826.856f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 9410038.69f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 8747887.467f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 11113124.139f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 8271634.443f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 9265625.148f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 12549469.506f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 7610206.375f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 8245545.329f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 9152828.791f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 8413949.528f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 10702794.28f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 8436475.71f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 6899062.636f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 9068796.835f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 8193397.675f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 7592988.49f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 7428334.754f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 7761843.699f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 7652810.178f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 8586969.623f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 9438784.386f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 8631663.846f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 12765933.419f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 8477225.877f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 11482130.818f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 8499314.538f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 5336656.233f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 8061581.235f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 8895814.147f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 2685025.921f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 12138400.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 9142854.235f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 7790571.659f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 6353748.119f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 2704138.493f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 9672933.815f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "ID",
                    name: "Indonesia",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 212usize,
                    internet_exchanges_number: 14usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 4241297.335f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 7985225.232f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 11505972.07f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 11075727.29f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 7450463.539f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 7647661.858f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 11053315.199f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 6772021.249f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 4680433.726f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 10796746.476f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 6355079.369f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 3496397.607f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 12677960.212f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 12090813.019f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 11921726.717f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 7524558.397f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 4472962.656f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 4505165.826f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 1986614.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5217161.861f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 10783993.595f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 8406352.507f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 21481.703f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 12912592.55f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PW",
                            distance: 1255021.7f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 2543914.817f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 12359465.894f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 9575513.524f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 10404279.401f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 7914596.27f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 1603592.151f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 5101465.461f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 6512111.316f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 10327968.75f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 1857331.02f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 162495.667f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 8178314.306f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 6572210.732f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 5490993.181f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 6519030.3f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 2554307.013f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 2367328.315f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 7236568.357f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 2713212.544f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 9758248.278f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 3827877.799f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 2471088.549f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 3020627.717f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 1520014.601f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 12408694.459f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 8988809.531f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 1380513.043f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 12336389.595f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 1694216.494f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 8577244.369f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 485652.038f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 8208160.822f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 7331029.581f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 2841158.567f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 10357958.619f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 10346601.073f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 15425361.641f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 11549247.392f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 11660511.272f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 10972520.191f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 14437372.347f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 10335797.744f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 12355025.628f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 15833586.56f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 10128089.534f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 11124049.081f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 11767408.755f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 10714231.674f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 13691887.185f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 10594941.571f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 8888472.536f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 11433649.905f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 10660877.237f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 9219921.627f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 9223342.154f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 9757171.573f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 9238550.82f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 9236241.02f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 11015022.046f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 13306543.6f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 11579220.735f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 11273729.12f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 16040641.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 10603907.931f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 14613096.301f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 11162154.669f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 4688890.781f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 10206829.911f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 11395056.681f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 15200436.363f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 11629531.38f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 10364524.42f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 9070763.967f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 4357234.401f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 12232831.597f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "CA",
                    name: "Canada",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 34usize,
                    internet_exchanges_number: 141usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8827044.241f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CR",
                            distance: 4638852.554f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 3731866.31f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 3999224.438f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 10898205.449f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 4838520.683f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 4113595.498f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 11411195.748f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 13844861.67f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PW",
                            distance: 11084217.016f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 9807757.595f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 4172848.988f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 3938046.724f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 4892263.147f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 3485375.703f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 3791666.692f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 13072679.284f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 10491806.504f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 7767523.712f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 12336389.595f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 4942646.432f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3783653.766f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 4002484.249f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 8689128.875f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 4243973.37f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "US",
                            distance: 1337581.007f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 12076923.467f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 5413813.798f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 7410269.978f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 641730.593f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 11898060.371f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 10647862.641f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 13782757.842f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 12702276.671f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 12884034.985f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 187164.584f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 8906910.09f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 1908562.681f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 3655935.562f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 4957644.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 5500105.817f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 3444230.65f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 4814740.245f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 4825093.223f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 3960821.238f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 5204613.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 4128483.458f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 3637731.685f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 4419914.193f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 5303164.34f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 5053357.903f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 5686196.488f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 5613997.72f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 5435734.621f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 5545493.824f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 4992891.936f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 5040735.76f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 5378389.285f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 4983466.903f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 3657820.924f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 5120175.665f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "GI",
                    name: "Gibraltar",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 1usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 11245643.118f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 4980762.34f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1820225.646f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 1983319.756f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 5833089.825f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 5360248.864f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 2086958.168f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 6292633.917f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 8292936.796f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 2982042.753f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 6587928.704f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 418239.786f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1632731.299f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 2896313.3f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 5493208.456f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 10783802.087f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 6847405.406f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 10986593.833f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 6154406.634f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 2186201.88f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 3080666.207f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 11627344.058f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 3276444.991f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 5929593.64f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 5562955.817f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4588559.985f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1373560.145f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 7739269.868f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 1733981.581f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1897344.048f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1582693.021f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 3146795.54f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 5030221.25f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 10704731.702f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 10602210.4f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 6624671.582f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 1343118.447f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 9863187.507f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 12912592.55f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 3459053.262f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 4726639.852f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 5607957.91f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 10926614.042f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 3419838.731f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 3353030.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 5381112.523f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 1645470.959f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 2042949.178f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 5151585.229f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 2604076.615f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 3256902.352f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 6110039.201f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 3205043.07f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 3114849.5f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1928400.925f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 9144518.064f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 2370042.456f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 11559916.461f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2526316.557f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7891889.306f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 2382403.605f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 4056460.021f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 1737027.806f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 2622113.325f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3813278.262f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 3707026.575f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 3358681.253f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 3738926.693f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 3705813.626f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 2226914.247f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 400663.786f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 1368131.252f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 11065875.138f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 2384990.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 6211358.546f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 2356412.177f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 7120292.443f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 2523933.718f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 12343854.249f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 8787180.613f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 2771195.294f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 1990645.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 9153149.419f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 7353958.894f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 1760747.195f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 12313089.768f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 3064645.45f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 4511230.407f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 5574914.79f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 8663850.872f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 1461065.9f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "IQ",
                    name: "Iraq",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8115679.208f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 81412.456f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 4009749.868f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 3127051.105f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 2546985.19f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 459353.355f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 3195908.305f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 2264104.678f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 3761000.713f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 3704433.381f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 2118343.434f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 5640211.09f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 4547439.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 5006563.384f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 565895.158f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 6741869.372f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 2129709.661f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 6347389.971f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 1181255.403f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 2757255.945f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1722129.21f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 6904744.627f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 4726639.852f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 4798754.471f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 3292467.092f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 3271578.208f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 1048587.938f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 6025271.488f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 7253602.578f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 2665495.437f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 3985645.133f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 5217869.7f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 8208160.822f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 1269643.777f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 436780.132f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 247597.133f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 936028.951f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 2734385.339f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 1569547.036f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 4152594.09f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 3883951.926f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 1616054.208f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 1540484.735f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 6680720.795f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 3536427.46f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 3435373.016f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 9323228.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 3636842.066f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 3612269.777f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 2987612.131f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 8638066.153f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 2291992.057f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 5696635.111f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 10133081.228f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 2839742.45f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 4280831.975f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 4136606.51f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 2863059.128f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 6846503.462f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2208206.122f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 10775746.705f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 2602146.149f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 1184496.68f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 3525761.218f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 3077110.564f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 1127797.683f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 1019619.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 2252097.259f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 1057639.223f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 1028124.634f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 3272279.698f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 5112097.377f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 3461987.349f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 6503868.208f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 3822470.787f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 10306615.291f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 2578723.194f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 10517388.862f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 3786652.589f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 7981885.148f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 2271668.629f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 3669937.867f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 4545377.766f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 11039460.764f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 3837711.017f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 7690058.499f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 3094744.701f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2962406.077f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 4176925.163f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 4427354.207f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "HK",
                    name: "Hong Kong",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 19usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 2620841.993f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 6585269.318f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 9389710.157f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 8948580.233f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 5103024.497f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 6395681.374f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 8867393.921f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4673446.67f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 2961125.665f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 8319096.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4567811.125f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 11521913.328f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 9647908.47f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 9285560.017f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 6312188.306f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 556367.086f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 4768565.369f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 1608879.246f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5766837.619f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 8749424.305f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 7983979.12f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 2588863.863f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 10926614.042f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 9891034.137f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 9347757.241f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 7987676.992f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 6022276.956f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 1953656.286f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 2044729.235f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4316482.826f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 9710655.572f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 2044805.824f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 2841158.567f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 7830719.749f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 6680720.795f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 5919306.993f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 7421973.432f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 7855556.91f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 7870582.866f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 12597577.429f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 9347976.663f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 9560305.57f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 8883668.685f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 11603122.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 8364794.794f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 9633168.032f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 13070952.227f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 7802280.812f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 8541624.096f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 9385719.407f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 4054643.133f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 8562751.462f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 2373763.372f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 8582873.505f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 11258231.517f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 8553073.911f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 6953661.614f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 9240788.987f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 8379562.68f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 7806888.63f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 7582130.301f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 7570957.116f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 7722838.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 7633389.055f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 8768132.207f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 11322400.435f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 9565202.72f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 1166469.653f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 8866406.489f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 13289667.575f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 8587265.146f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 12029984.615f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 8738160.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 3766098.819f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 5912700.66f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 1425344.427f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 4899789.102f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 8169893.63f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 9097661.046f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 2382749.063f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 12689579.658f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 9344402.848f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 1943651.471f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 7999111.76f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 6586024.053f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 7280883.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 2533284.951f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 9897741.759f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "NA",
                    name: "Namibia",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 13319857.136f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 4685448.414f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 3400187.75f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 1473263.823f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 1167334.197f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 3514535.81f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 3710060.412f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 5259680.813f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 1876563.39f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 7249894.028f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 4569084.72f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 4239340.766f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 3524735.162f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 6482050.171f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 3455793.41f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 3023848.342f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 5885466.625f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 1238447.52f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 2250406.675f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 2694331.393f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 2279869.074f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 3343645.052f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 4598621.483f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 5058093.333f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 2675744.648f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 6685835.349f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 5309039.012f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 9107893.376f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 5420899.923f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 4718821.268f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 5615902.625f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 1487802.895f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 6651088.229f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 3306071.366f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 1726898.867f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 4211270.684f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 2780819.54f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 6130605.22f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 4542327.45f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 8149912.409f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 1791799.888f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 3419141.834f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 2852501.807f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 3486120.562f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 6154626.767f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 3107205.011f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 2066855.134f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 4923612.036f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 3218033.329f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 4271396.04f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "ST",
                    name: "Sao Tome and Principe",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 11038273.253f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 4429285.663f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 3638767.603f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 1187952.895f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 3495124.278f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 888238.008f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 1317149.447f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 2953227.898f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 1082792.175f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 4568975.655f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 3245781.834f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 2055162.228f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 2694331.393f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 964424.161f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 377702.146f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 2481256.494f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 821889.443f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 3100771.816f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 3976657.086f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 2390686.859f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3954022.319f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 456336.034f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 771873.146f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 302638.697f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 3170828.829f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 5386546.783f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 2792738.391f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 3585812.246f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 2265373.682f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 4921926.29f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 2547744.553f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 4044747.821f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 3952214.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 3964108.606f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 4098933.116f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 4298284.499f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 3951278.024f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 5789948.573f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 3759840.447f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 6073780.321f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 5527153.596f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 3327323.667f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 3780319.232f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 4484625.293f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 2609001.511f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 4232269.659f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 3501800.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 3997022.696f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 4210452.591f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 2874437.186f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 1618532.831f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "MG",
                    name: "Madagascar",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 4usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 15803996.052f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 1977140.628f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 1486167.32f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 3862443.194f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 2232108.232f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 5777906.122f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 6014030.855f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 7880179.957f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 3859003.169f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 8367215.178f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 8894331.134f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 4153140.798f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 6948429.294f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 3343645.052f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 4921926.29f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 3747981.571f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 1338640.699f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 5548834.125f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 1208234.851f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 964364.399f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 1678716.215f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 5640057.939f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 7802794.982f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 7777481.043f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 1251541.944f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 3056976.83f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 7682305.441f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 5326165.571f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 4425331.334f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 1824374.242f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 7773449.5f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 5433910.625f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 4052365.475f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4512725.433f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 1296633.689f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 7298214.195f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 7713219.418f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 2661904.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 7755146.613f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 7395637.626f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 8061227.591f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 2191948.448f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 7410925.145f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 4804688.465f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 1734163.499f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 4796592.681f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 6584908.606f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 10077113.623f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 1689610.732f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 8701249.513f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 843285.649f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 2724807.419f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 5677560.752f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 2758966.177f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 6407205.17f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "GN",
                    name: "Guinea",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 1usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 8665061.335f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 6613547.355f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 6044518.14f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 3562220.19f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 5752737.146f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 1686547.987f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 1164123.171f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 538925.704f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 3549745.008f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3273441.393f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 5057268.463f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 479728.808f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 4718821.268f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 2481256.494f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 6057199.765f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 2961662.256f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 7395637.626f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 125259.498f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 339418.927f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 4348460.11f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 4981083.479f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 3501421.563f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 5573808.313f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 2755878.559f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 704838.827f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 1551729.237f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 2730939.743f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 1811894.727f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 5883646.437f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2083087.49f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 2709285.546f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 1916384.083f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 984042.011f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 6171674.547f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 3914046.958f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 6772669.043f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 6269372.604f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 8269576.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 4151777.033f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 8554987.53f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 3616508.339f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 5765265.253f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 1312070.876f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 6960541.59f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 5014700.243f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 5216232.419f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 5942318.715f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 6398092.467f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 6209578.949f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 5222452.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 1368007.347f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "BW",
                    name: "Botswana",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 14411110.386f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 4106145.344f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 2803113.774f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 2307742.955f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 4374176.232f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 4672103.024f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 6285419.269f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 2500340.547f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 4468468.441f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 5274889.991f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 1167334.197f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 3495124.278f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 1426813.07f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 3417733.096f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 2232108.232f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 5637455.568f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 6090940.231f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 2459581.42f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 7241173.19f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 5137938.965f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 10195198.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 6443242.805f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 5752737.146f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 6595107.924f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 489663.357f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 7097373.113f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 554026.27f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 3610758.853f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 2395670.477f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 4201174.953f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 559831.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 3071254.013f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 3497595.881f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 6446492.334f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 3402871.984f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 9021450.126f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 983981.704f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 7047293.606f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 2466001.633f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 2629578.783f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 4316911.039f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 4419175.96f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 6192691.525f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 2501411.459f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 944236.063f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 4508629.835f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 2933314.684f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 5113628.306f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "RE",
                    name: "Reunion",
                    continent: Some("Africa"),
                    other_names: vec!["Réunion"],
                    cable_connections_number: 3usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 16501687.412f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 3139033.57f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 2600195.919f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 4753694.38f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 3071254.013f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 6632475.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 7105952.743f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 8744445.087f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 4721729.837f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 4653374.192f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 7828510.809f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 4211270.684f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 5789948.573f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 2224028.691f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 6434751.322f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 964364.399f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 8174951.752f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 8582524.906f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 3428310.426f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 8369133.969f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 4924222.038f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 12647888.706f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 8882177.739f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 8269576.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 8902857.795f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 2953396.149f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 7972922.894f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 2641965.943f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 5643753.02f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 1601422.096f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 6323507.326f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 2539098.644f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 5723722.659f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 245866.589f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 4134671.561f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 5650572.464f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 7117689.92f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 10798456.085f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 2589372.571f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 9569584.627f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 1412873.399f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 3462303.463f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 6527145.842f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 6741422.347f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 6231780.728f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 2543009.314f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 2144419.602f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 3856640.769f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 3425467.255f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 7236265.574f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "CR",
                    name: "Costa Rica",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 3usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "MX",
                            distance: 1297845.646f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 1052852.635f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 1807100.711f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 365123.035f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 840678.585f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 821451.874f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 1002470.455f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 236704.618f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1789244.031f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 2059298.358f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1759641.823f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 877520.346f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 1715992.369f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 1414323.212f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 1560743.683f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 4638852.554f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1161354.437f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1426415.69f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 3160441.705f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 2405182.353f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 4863592.838f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 1553513.813f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 1523930.097f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 2465939.337f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 2261043.62f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 2218902.457f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 6625027.466f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 2489576.472f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 1849399.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 2489371.289f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 1626017.084f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 2433807.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 2644746.69f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 2506001.741f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 2407990.225f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 2374898.295f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 2405190.695f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 2505587.791f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 2413958.041f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 2488413.646f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "ZA",
                    name: "South Africa",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 12usize,
                    internet_exchanges_number: 14usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 14716109.23f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 4890676.748f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 2891740.621f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 2700978.181f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 554026.27f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 4738531.696f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 4894023.158f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 6422378.045f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 3106848.007f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 8485104.975f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 9688856.868f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 5011911.254f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 5409320.099f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 1238447.52f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 3976657.086f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 6818894.534f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 1854216.149f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 3125728.705f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 1678716.215f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 5760159.638f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 6219627.631f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 8762491.374f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 8687378.38f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 3004970.843f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 7769825.906f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 6277109.82f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 5663993.982f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 3928666.539f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 6605517.901f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 5883646.437f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 6816565.12f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 187145.268f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 7639717.092f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 2886611.641f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 2641965.943f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 4739088.943f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 7680728.79f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 4689258.398f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 4259856.205f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 6952787.095f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 2583653.41f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 4671470.11f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 341383.55f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 6927625.747f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 6457487.696f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 4765419.611f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 2257756.914f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 4056589.334f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 9595542.694f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 676536.995f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 6997635.071f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 9470625.306f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 1469424.075f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 2775236.4f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 3172776.986f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 3466510.171f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 5563773.164f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "EE",
                    name: "Estonia",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 6usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 7892713.925f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3781276.038f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1573764.599f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 1623188.831f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 2899124.424f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 4200467.733f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 1428415.607f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3659337.797f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 5752608.211f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 233168.261f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4264257.213f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3692346.471f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1779125.202f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 1713428.062f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 4323578.299f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 7623928.646f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 4961849.839f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 8368331.463f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4769235.936f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1774062.056f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 2202518.213f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 9281947.651f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 3353030.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 2029448.522f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 2084098.137f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 273211.816f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 2932080.55f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 8213597.454f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 7267767.26f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 3859387.792f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 2010348.628f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 7353611.884f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 10346601.073f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2795510.004f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3435373.016f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 4070949.346f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 7870582.866f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4243981.684f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 93176.185f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 6097303.076f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 1734981.954f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 2086239.395f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 1686754.032f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 5296242.173f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1855338.362f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 2354041.654f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 6894107.335f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 638851.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 895173.117f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1532667.295f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 7472481.054f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 1366916.527f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 9144321.73f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2365227.296f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7348189.831f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1686299.101f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2252420.965f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 1668762.369f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 896575.838f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3414349.512f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2848693.691f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1211938.641f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 3159047.223f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2942315.328f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 1214918.21f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3694574.371f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 2262606.993f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 8304267.02f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 1013109.621f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 7092627.395f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1769796.339f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 7098982.744f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 877400.15f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 5710505.386f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4513785.793f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 9286947.1f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 7520380.604f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1631540.578f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 1362795.933f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 6635141.471f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 7653985.077f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 1594544.923f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 9563144.723f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 474229.605f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 1289007.222f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 5317405.781f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 6019626.68f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 2057513.678f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "AW",
                    name: "Aruba",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 3usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 1523930.097f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 1847930.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 990416.908f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1145785.552f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PE",
                            distance: 2852114.645f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1020181.852f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 112448.376f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 775426.141f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1506966.551f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 2266209.554f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 974775.469f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 4038300.039f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1067298.465f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 743361.764f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 4957644.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 3178953.216f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 1400573.424f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 3434904.317f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 558262.867f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 2037825.642f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 86075.448f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 806019.35f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 2303233.119f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 869830.896f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 944233.177f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 2040159.329f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 6016700.169f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 991079.925f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 1481145.059f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 1388913.572f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 716484.788f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 974601.013f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 115546.503f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 948858.017f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 1123408.016f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 982241.215f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 895314.959f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 923710.179f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 941166.018f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 984283.146f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 969648.233f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 2115459.818f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 1009451.965f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "PY",
                    name: "Paraguay",
                    continent: Some("South America"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 11usize,
                    links: vec![
                        LinkTo {
                            code: "GY",
                            distance: 3575052.497f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SR",
                            distance: 3471722.79f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PE",
                            distance: 2829444.345f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 4356579.332f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BO",
                            distance: 1362427.827f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GF",
                            distance: 3414179.497f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 4179669.127f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 3851444.725f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 1493762.002f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 5347966.264f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 1118293.079f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 1695776.305f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UY",
                            distance: 1083069.83f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "FJ",
                    name: "Fiji Islands",
                    continent: Some("Oceania"),
                    other_names: vec!["Fiji"],
                    cable_connections_number: 8usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "PW",
                            distance: 5601588.722f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 5093932.201f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 745544.753f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 2266894.918f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 1008300.194f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 6766701.919f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 1201930.649f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 3389645.522f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 3287369.522f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 8689128.875f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 1279029.656f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 1321355.35f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 9207585.344f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 1070851.132f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 386297.674f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 7867544.051f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 2279972.745f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 2410748.872f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 3838016.996f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 5130480.889f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 2418128.883f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 3063300.147f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 3606485.951f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 3618158.51f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "NC",
                    name: "New Caledonia",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 10usize,
                    internet_exchanges_number: 3usize,
                    links: vec![
                        LinkTo {
                            code: "PW",
                            distance: 5694808.711f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 5026674.462f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 904718.614f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 2994643.766f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 686929.263f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 6109092.147f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 818764.88f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 1321355.35f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 8274185.187f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 2114552.3f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 794761.942f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 2216026.512f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 1967234.393f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 3732581.919f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 5039874.895f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 1558074.545f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 1726599.956f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 2598137.983f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 155134.342f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 2707701.005f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 3328882.847f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 3843187.81f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "MH",
                    name: "Marshall Islands",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "PW",
                            distance: 3827229.06f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 2522110.704f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 3605273.911f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 5253033.478f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 3207162.749f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 5528534.081f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 3329807.167f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 3063300.147f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 7337355.62f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 4611319.86f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 2833107.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 886684.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 2707701.005f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 931874.153f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 2693448.44f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 2880623.847f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 5347317.99f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 2168432.456f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 2183119.718f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 2860957.551f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 5495804.961f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 2923259.912f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "VU",
                    name: "Vanuatu",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 1usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "PW",
                            distance: 4651395.965f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 4329240.874f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 1807287.706f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 2421244.126f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 2165078.55f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 7480187.475f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 2273885.768f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 1070851.132f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 6775070.646f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 3361550.694f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 2348129.981f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 2038100.759f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 1558074.545f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 3177376.962f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 4394675.291f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 2968703.263f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 3030769.46f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 1489271.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 1612986.347f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 2880623.847f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 4699521.511f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 2593708.21f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "TH",
                    name: "Thailand",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 12usize,
                    internet_exchanges_number: 8usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 5133469.819f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 5823089.99f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 9928954.95f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 8862828.763f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 5319057.197f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 5513632.921f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 8844519.576f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4586167.208f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 2481821.31f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 8657878.853f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4141052.337f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 2811034.877f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 11185635.246f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 10546980.336f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 9853096.831f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 5551630.432f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 2290997.688f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 4058556.659f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 332299.605f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4812007.282f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 8569314.718f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 7951374.905f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 708323.626f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 10704731.702f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 4740639.026f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 10197132.501f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 9267002.388f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 8247767.787f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 5700008.646f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 7744299.698f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 7237470.561f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 10910999.753f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 5078481.299f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 4292068.969f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 6730757.545f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 3249860.512f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 143853.614f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 1603592.151f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 2429920.796f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 8320141.149f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 1374292.587f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 6264536.746f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 2230598.235f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 10521768.092f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 4603815.905f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 1176269.665f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 1650116.329f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 10956381.429f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 7547294.308f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 10558754.846f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 13072679.284f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 9770960.904f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 9580305.637f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 1862043.458f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 6060423.967f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4354725.86f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 6025271.488f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 5156708.265f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 1953656.286f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 8236658.253f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 8213597.454f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 13834119.961f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 9339886.932f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 9445973.073f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 8758387.667f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 12841649.045f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 8121663.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 10357941.608f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 14463876.443f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 7948533.758f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 9033199.548f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 9585791.033f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 8503850.622f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 13038699.284f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 8380317.587f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 6673792.804f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 9224002.701f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 8467170.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 7032981.291f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 7554985.416f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 7069810.815f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 7051921.185f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 8813393.125f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 9365628.393f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 9104057.165f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 14691649.315f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 8389266.782f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 13685843.248f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 8998892.874f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 3120587.344f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 7992381.28f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 9198840.551f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 14375721.255f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 9429757.574f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 8192745.183f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 6963522.126f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 2194512.581f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 10037379.627f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "MR",
                    name: "Mauritania",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 1usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 7869884.551f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 6875760.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 6511798.989f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 4330331.593f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 6595107.924f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 2291166f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 1923186.695f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 518629.968f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 4251789.718f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2379955.549f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 5186907.105f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 1425727.167f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 5615902.625f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 3170828.829f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 6736426.904f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 3944554.809f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 8061227.591f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 1107629.863f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 701898.653f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 3470489.13f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 5509356.753f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 2839997.781f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 5577757.91f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 3404384.842f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 409153.469f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 984042.011f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 2207779.907f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 3338005.886f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 2385228.09f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 6816565.12f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 1110564.908f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 3285279.61f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 2470112.343f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 7035447.75f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 3340611.887f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 7344787.233f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 7088153.384f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 8902857.795f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 3772668.323f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 9165546.802f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 2634847.742f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 6497772.136f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 888726.225f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 7536287.305f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 5511076.793f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 4970068.526f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 6456778.526f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 7165237.66f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 6372018.88f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 5658791.509f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 1675803.71f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "RW",
                    name: "Rwanda",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 13083721.941f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 1992915.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 1033032.364f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 2018202.875f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 2629578.783f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 3328301.571f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 3873821.244f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 5428593.266f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 1756147.536f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 1839250.289f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 4630660.277f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 2852501.807f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 2609001.511f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 1632675.989f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 4217159.705f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 2724807.419f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 4940843.609f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 5293850.498f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 178477.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 5066670.881f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 2520570.76f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 9226056.71f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 5549487.476f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 5014700.243f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 5511076.793f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 3055831.074f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 4777135.3f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 3172776.986f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 2315438.38f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 1863623.378f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 2974169.224f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 2711128.801f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 3462303.463f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 2391152.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 4009145.307f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 3690900.767f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 7356494.021f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 1767209.146f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 6256597.301f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 2054715.604f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 3205342.427f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 3465989.438f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 3577596.493f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 946070.898f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 2411823.801f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 2085517.541f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 374090.572f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 3835805.212f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "NO",
                    name: "Norway",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 42usize,
                    internet_exchanges_number: 12usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8256192.079f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 4627497.439f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1330115.64f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 1879364.401f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3717491.613f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 5053413.292f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 1673319.792f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4519516.887f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 6594687.051f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 584404.077f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 5147688.218f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3199465f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 613342.463f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 831047.684f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 5180135.935f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8245545.329f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5856905.584f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 9162587.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5647642.873f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 2175540.32f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 2882892.225f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 10111409.722f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 3114849.5f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1199524.664f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 2246064.589f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1010332.203f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 3825657.754f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 9033199.548f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 7718962.571f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4693088.699f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 1846500.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 8180550.594f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 11124049.081f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 3505230.355f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 4280831.975f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 4951405.819f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 8541624.096f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 5005354.171f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 831785.79f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 895173.117f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 5202494.402f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 1728659.319f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 2109740.354f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 2000753.016f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 4405680.331f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 2420292.123f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 1459093.099f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 5998934.236f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1441168.321f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 121314.278f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 5880166.603f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1192638.231f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 8366252.764f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 1796996.439f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 9964904.009f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2889352.761f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 6545254.752f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 2165316.489f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 3108290.819f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 1720437.751f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 1357953.474f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 4126793.872f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 3599991.891f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 2029277.43f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 3885104.69f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 3684267.406f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 1451298.407f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3389601.391f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 2359862.865f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 9066877.2f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 857183.515f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 6197646.166f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 2243241.703f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 6237099.068f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 6592952.242f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 5388900.648f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 9935981.858f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 8412402.953f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 2255875.551f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 1328860.828f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 7469485.262f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 6776082.823f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 1464078.762f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 10310469.229f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1189017.941f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2069866.688f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 6093148.065f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 6840369.344f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 1665754.217f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "GT",
                    name: "Guatemala",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 6usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 877520.346f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 70884.548f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1348504.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1236437.417f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PE",
                            distance: 3295241.789f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1565739.866f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 2163350.912f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 2408023.359f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1669933.983f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 3132347.092f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 2818398.4f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 4670859.343f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1861782.978f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 1836893.81f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 3657820.924f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 627365.059f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 861771.898f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 2115459.818f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 3037192.906f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 201562.354f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 2657042.493f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 2625473.132f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 6241038.007f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 2969023.964f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 666194.673f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 2035540.171f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 1829754.922f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 2097687.997f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 1948237.072f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 2998394.864f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 2229653.921f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 3064231.651f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 3213893.029f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 3050896.571f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 5914620.407f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 1586274.945f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 3003710.957f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 6701101.462f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 4247519.104f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 1439693.6f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 2809268.44f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 2849329.9f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 3033810.616f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 2838578.456f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 2942434.082f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "AG",
                    name: "Antigua and Barbuda",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 2488413.646f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 2665846.9f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1616981.962f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1912030.639f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1469404.746f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 473756.482f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1720715.295f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 1715364.536f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 181542.672f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3355817.143f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1198249.912f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 1137821.726f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 5120175.665f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 3809954.477f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 2026251.113f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 1009451.965f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SX",
                            distance: 166519.151f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 451579.521f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 2790261.231f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 327330.58f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 322557.354f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5389196.59f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 105887.515f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 2375991.654f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 58572.524f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 844907.595f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 212215.059f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 940765.401f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 720119.966f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 513210.412f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 359319.309f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 572768.254f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 4361926.803f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 142659.162f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 95186.958f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 294108.013f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 134411.35f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 2942434.082f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "MY",
                    name: "Malaysia",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 29usize,
                    internet_exchanges_number: 17usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 5207797.309f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 6620746.088f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 10565612.304f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 9756985.974f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 6250674.808f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 6283237.575f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 9746820.04f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 5510016.101f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 3404020.155f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 9587917.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 5037727.277f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 3066381.991f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 11817513.587f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 10677182.397f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 10784383.749f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 5667684.703f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 2381517.004f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 4532511.933f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 722848.497f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5256000.567f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 9452157.55f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 8433168.524f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 189557.05f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 11559916.461f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 4672027.624f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 11122551.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 9378795.577f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 9175706.393f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 6589557.8f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 143853.614f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 4381592.925f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 5285041.794f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 10344050.902f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 1833794.085f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 162495.667f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 8167111.035f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 10252215.78f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 6846503.462f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 5968204.659f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 2373763.372f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 13782757.842f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 6812194.546f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 9168046.846f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 9144321.73f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 14705608.405f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 10240777.622f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 10331555.211f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 9647831.729f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 13706305.945f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 8998527.248f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 11284341.967f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 10062514.603f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 15293254.121f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 8871109.001f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 9964904.009f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 10506138.991f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 2438483.198f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 9404024.688f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 9595542.694f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 4013474.571f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 7844674.287f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 7335543.362f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 11023569.954f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 5175906.352f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 3345885.008f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 6636313.884f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 6588551.796f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 2536880.762f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 48178.402f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 2239307.535f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 8940068.888f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 1602518.884f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 11581619.874f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 10729991.06f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 5492077.421f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 5723722.659f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 13631875.537f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 9265883.057f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 7558968.391f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 10124577.348f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 9383042.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 7863155.042f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 8465980.653f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 7874243.264f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 7874322.532f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 9723462.789f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 10238236.237f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 10028588.396f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 15519554.253f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 9270899.759f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 14380199.169f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 9925025.296f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 3466172.6f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 8880507.825f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 10112435.553f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 15051060.606f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 10340626.434f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 9117450.887f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 7895260.566f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 3126018.624f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 10950550.559f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "RU",
                    name: "Russian Federation",
                    continent: Some("Eurasia"),
                    other_names: vec!["Russia"],
                    cable_connections_number: 13usize,
                    internet_exchanges_number: 167usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 776024.969f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3275810.881f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 2818174.294f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 2588598.568f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 1648982.149f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 3634902.559f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 2443199.647f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 2483667.986f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 4530430.683f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1740757.795f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 3171000.902f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 4953901.222f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 3067718.178f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 2893949.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 3733179.564f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 6353748.119f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 3988422.588f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 7099620.048f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4031729.986f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 2561815.796f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 2439046.569f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 8041660.385f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 4511230.407f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 3318321.922f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 3055394.902f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1407578.175f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 2133730.752f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 6963522.126f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 6097818.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 2628028.136f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 3195814.858f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 6110842.669f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 9070763.967f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2852626.822f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 2962406.077f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 3349972.603f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 6586024.053f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4007343.132f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 202644.775f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1289007.222f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 7164531.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 2866302.513f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 3160933.096f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 2586438.803f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 6283459.568f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 2397376.101f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 3450598.59f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 7935581.346f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1315400.011f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 2069866.688f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 2801925.831f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 6430727.381f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 2225800.59f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 7895260.566f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2866908.826f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7972967.051f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 2398247.11f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 425043.585f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 2774834.839f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 1891147.303f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3384929.363f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2785368.165f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 24083.648f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 3123798.838f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2892188.196f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 2284916.154f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 4878944.338f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 3265135.782f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 7021972.687f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 2281434.675f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 8146718.674f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 2468576.82f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 7913605.305f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 2152197.298f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 4595851.805f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 3809127.079f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 8005351.697f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 6601773.349f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 2133488.937f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 2553516.44f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 5401288.702f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 8529728.773f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 2799142.533f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 8277775.131f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1451058.723f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4975098.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 4770505.205f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 3319588.8f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "KW",
                    name: "Kuwait",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 4usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8147177.816f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 547274.385f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 81412.456f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 436851.587f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 407875.096f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 1195076.969f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 282046.33f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 951624.121f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 2764474.325f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 1525059.516f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 4166826.608f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 3882649.895f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 1534911.75f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 1492731.032f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 4336823.702f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 3443294.311f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 2729142.611f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 3520316.609f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 2332492.202f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 3637139.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 4050897.776f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 2065614.817f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 5914776.765f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 4878911.917f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 5351365.263f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 6680113.247f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 1924804.529f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 6160642.355f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 3067286.243f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 2030073.291f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 6669250.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 4980762.34f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 5127917.755f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 3585871.296f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 3618264.117f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 1266455.021f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 5823089.99f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 7276386.876f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 2725087.741f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 4294518.811f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 5035757.046f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 7985225.232f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 1527536.104f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 6585269.318f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 3881815.518f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 3781276.038f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 9658863.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 3951924.952f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 3910096.679f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 3300965.454f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 8981518.319f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 2605159.265f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 6041959.789f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 10468489.369f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 3186421.653f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 4627497.439f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 4467339.487f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 3191389.171f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 6620746.088f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2482359.215f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 11119182.247f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 2918920.221f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 1529488.652f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 3842341.626f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 3417864.934f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 1255098.643f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 1290892.009f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 2598672.657f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 1253767.617f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 1278004.347f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 3604075.977f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 5359913.234f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 3747205.687f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 6340776.265f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 4162536.274f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 10639878.46f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 2891144.19f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 10863953.34f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 4128949.9f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 7851369.714f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 2599387.471f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 3999303.289f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 4383943.188f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 11384409.943f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 4161238.504f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 7501674.271f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 3441231.945f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 3275810.881f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 4060454.839f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 4744900.838f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "BD",
                    name: "Bangladesh",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 4705954.254f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 4383943.188f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 7941503.046f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 7280930.983f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3752389.375f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 4128871.691f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 7257201.995f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 2994872.82f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 889297.608f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 7076324.751f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 2567170.662f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 9945423.324f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 8341060.833f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 8295237.745f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 4029426.579f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 2685025.921f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 2378647.676f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 1833677.654f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 3233311.256f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 6997186.4f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 6118495.936f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 2707596.363f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 9153149.419f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 8607273.502f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 7272101.924f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 6661139.024f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 4128135.583f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 1862043.458f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 3900524.579f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 2777674.369f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 7914244.171f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 710628.685f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 2554307.013f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 5784955.817f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 8105780.298f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 4545377.766f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 3707193.716f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 2382749.063f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 5301263.807f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 6662830.555f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 6635141.471f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 12423659.532f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 7753082.31f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 7869990.785f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 7180277.247f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 11457924.911f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 6556214.715f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 8828389.71f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 7913936.802f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 13121280.568f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 6356745.48f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 7469485.262f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 7993380.435f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 2043730.795f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 6918093.603f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 2536880.762f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 6651962.999f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 12147192.717f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 6806105.286f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 5103698.415f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 7637464.858f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 6874611.867f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 5637699.413f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 5529398.324f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 5963869.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 5602312.19f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 5558960.585f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 7222293.26f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 9552011.344f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 7801227.655f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 1958851.9f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 7513458.826f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 13346757.186f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 6818606.623f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 12596808.282f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 7409723.029f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 1555232.114f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 3456414.919f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 3489889.895f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 2819243.129f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 6416586.629f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 7606620.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 6031088.352f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 5018739.213f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 5108729.128f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 13293008.974f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 7838241.296f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 3165224.658f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 6602250.602f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 5401288.702f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 660684.946f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 8445158.941f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "LC",
                    name: "Saint Lucia",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 2506001.741f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 2776439.977f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1777102.893f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1969415.094f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1673640.891f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 735519.973f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1993032.066f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 2069535.67f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 518144.549f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3686366.866f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1463069.097f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 1330451.597f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 5435734.621f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 4004692.023f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 2200375.027f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 982241.215f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SX",
                            distance: 503055.23f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 101792.921f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 2931956.087f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 623295.729f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 583393.239f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5722348.211f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 253462.803f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 2443582.048f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 331706.059f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 1067884.955f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 147266.524f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 884351.509f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 379324.191f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 182859.844f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 407958.398f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 359319.309f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 473335.56f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 65481.011f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 241537.474f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 4675832.982f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 453240.423f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 3050896.571f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "CL",
                    name: "Chile",
                    continent: Some("South America"),
                    other_names: vec![],
                    cable_connections_number: 22usize,
                    internet_exchanges_number: 13usize,
                    links: vec![
                        LinkTo {
                            code: "PA",
                            distance: 4795497.71f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GY",
                            distance: 4765443.352f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SR",
                            distance: 4726564.433f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PE",
                            distance: 984719.561f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 5153841.795f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 4133046.302f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 8906910.09f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BO",
                            distance: 1972970.84f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 3434904.317f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 5696694.058f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GF",
                            distance: 4793055.425f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 4878776.421f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 2150144.787f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 4129831.092f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PY",
                            distance: 1695776.305f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 4735230.103f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 4145849.425f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 1413992.23f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 4247519.104f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 5094935.764f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UY",
                            distance: 1505291.202f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "HN",
                    name: "Honduras",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 5usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 840678.585f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 596947.519f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 813881.371f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 1388870.595f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1138739.622f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 1517193.677f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 2029330.593f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 70884.548f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 185261.712f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 621668.448f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1606872.704f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 2346404.723f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1792845.718f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 1877664.028f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 1969554.58f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 2096433.207f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1075183.722f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1298946.598f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 2906043.81f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 2542108.888f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 4489595.426f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 1562518.674f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 3731866.31f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 1847930.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 2764320.852f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 2380943.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 2349147.287f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 6121290.762f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 2692606.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 1588802.237f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 2722584.607f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 1962680.633f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 2796661.784f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 2940548.535f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 2776439.977f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 2732813.23f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 2532724.509f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 2572748.885f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 2758625.541f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 2562136.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 2665846.9f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "UY",
                    name: "Uruguay",
                    continent: Some("South America"),
                    other_names: vec![],
                    cable_connections_number: 3usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "GY",
                            distance: 4649531.726f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SR",
                            distance: 4537766.859f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PE",
                            distance: 3737971.732f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 5430024.798f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BO",
                            distance: 2308519.553f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GF",
                            distance: 4450325.005f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 5256210.9f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 4726623.614f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PY",
                            distance: 1083069.83f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 1473831.604f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 6367159.728f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 235376.623f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 1505291.202f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "YE",
                    name: "Yemen",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 6usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9300215.528f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 373817.14f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 1525059.516f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 5502877.989f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 1971715.103f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 4567250.298f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 4381177.326f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 1126348.479f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 4704744.896f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3812249.513f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 4404713.12f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 5509165.148f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 3285254.25f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 6589757.335f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 6067676.045f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 6723066.407f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 1012432.853f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 7358333.457f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 2751265.075f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 6357964.903f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 1912026.407f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 4175203.196f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 2865491.099f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 6817210.99f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 5574914.79f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 6283025.345f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 3743976.691f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 5113898.607f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 2976571.497f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 6060423.967f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8422483.616f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4160261.431f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 4732438.702f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 5488599.153f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 6572210.732f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2612378.596f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 4597712.701f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 1569547.036f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 1627058.39f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 1291389.714f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 7280883.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 1162991.698f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 5428544.892f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 5317405.781f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 10775950.051f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 5034280.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 4867617.875f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 4413659.087f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 10253912.722f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 3776893.48f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 7414841.704f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 4244898.644f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 11563508.345f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 4687138.391f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 6093148.065f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 5664133.149f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 4212743.727f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 4429662.117f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 6636313.884f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 3289556.812f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 12637373.672f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 4086640.671f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 3137411.625f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 4943162.375f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 4773929.579f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 2011886.947f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2493878.871f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 4105472.542f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 2227008.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2413109.124f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 4850882.69f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 5889332.53f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 4632827.958f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 6748923.452f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 5480707.517f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 11699109.804f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 4030854.618f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 12228520.623f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 5481878.969f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 2214419.2f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 1810825.408f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 8321063.635f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 2685616.856f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 3874787.309f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 5202990.078f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 5018739.213f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 12656990.625f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 5302948.103f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 2270988.092f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 7674717.102f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 244903.157f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 4916074.792f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 4975098.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 4820144.253f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 5806024.851f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "BZ",
                    name: "Belize",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 3usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 1002470.455f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 185261.712f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1173833.904f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1277428.245f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1359441.316f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 2156987.192f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 2345313.003f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1520942.968f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 2850370.34f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 2654171.215f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 4363106.486f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1748900.521f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 1660237.266f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 3444230.65f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 426932.102f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 788186.209f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 2040159.329f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 2929639.313f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 774093.57f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 1578897.668f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 1250804.011f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 201562.354f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 1859569.888f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 2037205.664f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 2490339.139f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 2463107.304f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5929279.238f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 2825752.757f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 1569643.739f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 2865939.296f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 2155702.279f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 2983202.816f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 3102513.858f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 2931956.087f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 2907545.156f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 2652628.377f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 2695373.06f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 2908356.895f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 2677914.804f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 2790261.231f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "TK",
                    name: "Tokelau",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 4usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "PW",
                            distance: 6217579.886f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 5407891.003f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 1272115.535f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 3355145.868f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 518058.825f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 5382243.144f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 592043.194f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 1279029.656f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 7410269.978f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 9008904.837f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 1779308.164f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 4668528.916f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 2012076.008f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 2583101.85f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 794761.942f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 4110147.271f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 5396278.61f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 2348129.981f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 3253396.007f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 781408.176f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 2833107.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 2775586.847f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 4497484.006f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "GQ",
                    name: "Equatorial Guinea",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 8usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 11112745.387f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 4169594.98f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 3424078.875f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 1206430.626f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 3497595.881f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 982062.011f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 1578318.032f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 3171984.387f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 1013881.378f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 4532112.813f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 2960464.915f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 2333163.747f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 2780819.54f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 377702.146f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 3469005.354f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 2534381.196f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 4796592.681f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 2650602.443f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 3025910.85f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 5286615.934f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 2343464.544f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 3913316.436f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 3666745.267f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 166682.7f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 3310895.114f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 2730939.743f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 3338005.886f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 3976456.25f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 3929284.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 4056589.334f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 120336.561f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 4129545.256f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 868403.263f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 3925830.939f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 5650572.464f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 1179989.712f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 954068.733f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 4034952.68f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 3543861.959f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 5925712.803f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 5533329.896f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 3245755.424f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 3925077.684f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 4318238.786f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 2391152.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 3967212.795f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 3303522.182f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 3933340.149f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 3933831.213f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 2638113.441f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 1648907.04f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "SK",
                    name: "Slovakia",
                    continent: Some("Eurasia"),
                    other_names: vec!["Slovak Republic"],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 21usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8876552.524f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 4162536.274f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 570358.611f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 1049115.062f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3832891.223f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 4596177.794f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 852486.361f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4518599.221f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 6624568.429f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 600291.465f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 5044527.731f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2680001.687f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 827716.443f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 1246146.031f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 4730033.803f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8631663.846f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5628539.505f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 9287780.527f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5262170.658f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1386337.056f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 2243621.342f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 10152539.018f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 2384990.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1094720.924f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1389953.861f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 881169.884f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 3578882.094f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 9104057.165f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8271333.827f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4761838.582f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 1053697.676f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 8238615.698f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 11273729.12f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2868494.2f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3822470.787f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 4587080.762f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 8866406.489f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4390449.436f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 1057036.728f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1013109.621f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 5506762.831f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 877832.394f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1260015.996f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 1184167.149f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 4826675.374f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1712721.336f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 1934600.705f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 6316481.209f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1160845.412f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 857183.515f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 521169.495f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 8143477.246f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 1057960.717f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 10028588.396f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2130901.202f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7181316.305f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1419242.158f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2718398.552f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 863559.872f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 745908.42f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3474861.655f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 3007058.53f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1647492.541f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 3253843.547f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 3077177.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 652387.695f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2706195f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 1503924.069f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 9252045.987f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 6496150.946f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1488030.356f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 6759136.704f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 139955.237f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 6478162.821f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4994281.499f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 10286675.102f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 8078048.036f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1609761.014f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 473331.43f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 7513458.826f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 7237989.426f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 641530.787f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 10517453.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 911312.798f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2281434.675f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 5480707.517f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 6921159.339f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 1044517.043f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "MM",
                    name: "Myanmar",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 5usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 3483920.712f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 5035757.046f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 8792522.06f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 8003569.567f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 4463524.543f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 4752446.496f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 7982087.068f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3720354.155f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 1615723.949f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 7796497.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 3284676.219f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 2700951.001f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 10119298.199f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 9377701.335f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 9003645.926f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 4526496.428f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 3106731.398f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 2973317.345f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 1203212.072f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 3799497.945f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 7715539.236f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 6790774.769f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 2001009.18f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 9863187.507f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 9332029.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 7950966.164f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 7384010.297f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 4845510.595f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 1176269.665f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 3869700.082f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 3494263.109f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 8613917.267f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 6670740.195f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 5488599.153f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 1857331.02f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4042133.362f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 5538915.714f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 710628.685f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 1935200.493f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 1833794.085f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 5881419.104f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 1749866.468f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 2738523.969f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 7325957.156f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 1338511.451f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 5778624.984f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 2445904.431f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 9924087.173f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 6559153.911f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 5217869.7f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 4362177.234f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 2044805.824f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 7378875.646f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 7353611.884f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 13068336.112f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 8477790.023f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 8590189.825f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 7901280.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 12088647.473f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 7271465.588f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 9523257.041f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 13738254.085f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 7082626.183f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 8180550.594f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 8719712.182f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 7642318.536f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 12560465.094f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 7525336.75f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 5820602.919f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 8362058.442f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 7601320.315f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 6290555.255f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 6214983.076f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 6690176.027f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 6270694.474f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 6239495.068f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 7948615.645f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 10260989.812f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 8516385.014f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 8238615.698f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 13965472.004f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 7536266.77f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 13100674.636f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 8134051.747f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 2869131.224f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 7136439.276f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 8333279.963f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 13798073.682f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 8564707.632f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 7327324.693f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 6110842.669f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 1341505.866f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 9171821.381f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "GW",
                    name: "Guinea-Bissau",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 1usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 8328644.602f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 6838476.518f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 6319621.414f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 3890992.264f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 6090940.231f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 1970554.198f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 1478522.299f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 205728.568f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 3867689.269f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3060493.985f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 5239054.468f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 819147.707f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 5058093.333f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 2792738.391f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 6375576.092f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 3272913.714f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 7713219.418f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 460227.471f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 1846924.414f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 3025910.85f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 339418.927f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 2089580.795f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 370388.848f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 6219627.631f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 1812386.524f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 2996852.533f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 2190405.768f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 3060203.435f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 701898.653f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 4146813.178f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 5267414.891f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 3398044.656f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 5719937.846f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 6510869.9f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 3848887.439f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 7072078.946f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 6606097.655f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 8582524.906f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 4161347.146f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 8864174.918f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 3310020.285f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 6091699.739f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 988056.136f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 7260975.316f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 5293850.498f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 5278887.819f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 6227921.843f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 6729644.008f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 6405486.422f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 5487951.514f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 1553673.677f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "NR",
                    name: "Nauru",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 1usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "PW",
                            distance: 3669964.281f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 2834070.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 3054028.429f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 4446739.897f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 2830704.447f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 6237407.75f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 2964133.653f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 2410748.872f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 6878206.288f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 4288096.452f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 2583101.85f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 679118.869f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 1185361.321f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 2216026.512f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 2834800.383f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 2038100.759f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 4477838.345f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 1351178.215f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 2369527.72f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 886684.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 5355807.681f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 2302649.085f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "SY",
                    name: "Syria",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 3usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8776153.068f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 1290892.009f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 3103486.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 2184854.657f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 2977752.667f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 1701550.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 2285082.221f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 2984668.36f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 4716091.259f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 3016469.506f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 3025827.888f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 4626618.394f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 3659633.779f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 4240456.787f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 1839051.6f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 7592988.49f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 3145642.972f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 7345381.535f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 2454791.519f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1798768.597f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 775634.677f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 7923519.689f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 3707026.575f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 3897321.104f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 2297065.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 2630880.099f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 1606879.475f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 7032981.291f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 7942982.53f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 3380848.646f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 3018240.095f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 6214983.076f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 9223342.154f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 209441.944f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 1019619.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 1900940.766f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 7582130.301f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 1405466.448f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 2964015.56f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 2848693.691f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 8440083.906f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 2687574.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 2623409.105f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 2037184.328f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 7824013.162f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1349308.947f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 4934438.516f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 9246455.7f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 2211274.247f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 3599991.891f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 3247905.764f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 5477329.967f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 1977233.255f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 7863155.042f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1192828.114f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 10143495.101f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1667623.326f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 949958.693f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 2581846.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 2285437.768f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 601853.453f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 117381.864f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 694648.311f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1646861.926f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 338704.27f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 2399896.158f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 4092759.37f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 2456326.631f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 7482982.397f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 3007058.53f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 9408047.564f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1629309.096f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 9765992.984f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 2998206.16f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 4184955.853f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 2190033.821f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 8922269.959f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 5232154.503f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1398209.79f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 2778242.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 5529398.324f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 10237291.862f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 2917150.915f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 8687061.375f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 2428992.812f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2785368.165f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 2493878.871f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 5121008.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 3482266.329f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "WS",
                    name: "Samoa",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 5usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "PW",
                            distance: 6371913.957f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 5661731.578f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 770706.947f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 2881682.958f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 4341751.634f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 2355403.694f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 7767523.712f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 518058.825f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 1008300.194f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 1394218.657f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 609167.799f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 2438863.051f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 125579.394f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 691284.752f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 8927991.097f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 2830704.447f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 686929.263f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 4361938.221f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 5665495.485f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 2165078.55f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 3284732.806f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 3207162.749f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 4529025.547f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "MT",
                    name: "Malta",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 7usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 10049844.733f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3747205.687f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1123602.304f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 676814.958f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 4484212.831f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 4153701.934f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 842750.732f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4924502.681f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 6934480.56f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 2004872.73f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 5234069.435f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2184426.037f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1616486.327f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 2533849.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 4290531.908f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 9438784.386f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5550024.326f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 9634630.178f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4911085.937f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 818203.521f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1759174.678f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 10317754.092f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 1368131.252f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1759126.951f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 186630.306f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 2011337.823f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 3673426.343f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 9365628.393f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 9351815.671f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 5257949.838f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 721402.716f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 8516385.014f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 11579220.735f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2226212.319f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3461987.349f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 4336132.458f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 9565202.72f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3609291.924f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 2357199.452f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 2262606.993f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 6143839.999f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 637170.767f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 281638.805f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 695491.077f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 5683585.096f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1245048.196f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 3126982.797f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 6931099.584f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1952873.07f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 2359862.865f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1306227.484f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 7933335.037f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 1047609.625f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 10238236.237f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1269236.96f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 8286109.249f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1014550.196f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2697939.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 641241.82f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 1404361.833f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 2692319.579f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2456326.631f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 2012794.8f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 2558689.61f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2476223.458f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 1047712.606f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 1768316.628f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 9702477.908f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 1503924.069f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 7070527.508f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 988978.552f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 7688372.112f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 1614152.376f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 6547963.46f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4646191.831f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 10979351.729f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 7666766.283f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1403070.968f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 1031058.193f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 7801227.655f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 8051266.367f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 933507.831f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 10954415.744f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1875312.03f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 3265135.782f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4632827.958f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 7300369.564f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 1221306.815f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "GY",
                    name: "Guyana",
                    continent: Some("South America"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "TT",
                            distance: 577829.99f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SR",
                            distance: 221548.021f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 712113.274f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 702737.394f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PE",
                            distance: 2520025.267f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 1317842.551f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BO",
                            distance: 2802031.419f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GF",
                            distance: 656722.328f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 1127110.007f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 2891224.313f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PY",
                            distance: 3575052.497f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 3122775.299f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 2706752.1f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 4659495.571f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 4765443.352f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UY",
                            distance: 4649531.726f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "KH",
                    name: "Cambodia",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 4usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 4206588.589f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 6160642.355f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 9739848.671f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 9107675.905f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 5469638.417f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 5867225.048f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 9077466.555f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4787136.003f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 2705926.3f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 8817134.715f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4400608.589f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 11772332.918f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 10112003.415f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 9971883.849f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 5697669.899f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 1722514.012f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 4157574.988f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 722848.497f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 332299.605f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 7864902.152f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 6357964.903f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4960914.598f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 8953328.969f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 8377837.39f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 6573870.43f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 5215364.092f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 6934808.573f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 9846479.044f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 3417464.922f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 1203212.072f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 391925.326f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 8829283.429f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 7908988.838f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 1104198.979f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 10986593.833f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 10375060.827f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 8420078.472f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 5961281.461f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 3650440.439f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4525947.587f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 1986614.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 7600803.163f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 6347389.971f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 5488696.617f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 1608879.246f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 8383511.49f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 8368331.463f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 13809770.69f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 9573675.564f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 9700227.485f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 9009756.821f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 12809524.154f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 8389678.734f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 10444181.986f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 14394221.79f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 8141486.536f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 9162587.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 9780794.88f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 2734542.065f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 8741033.476f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 12810797.281f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 8637585.112f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 6936848.838f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 9458589.903f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 8675954.057f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 7414526.869f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 7345381.535f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 7776453.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 7399092.623f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 7369706.522f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 9033089.146f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 11385240.927f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 9634630.178f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 9287780.527f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 14620677.42f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 8651156.65f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 13514749.083f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 9177074.527f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 1961214.155f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 3552678.526f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 8247618.969f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 9410570.202f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 1833677.654f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 14194704.602f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 9646295.299f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 1342672.524f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 8378183.507f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 7099620.048f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 2371263.227f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 10247780.79f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "LU",
                    name: "Luxembourg",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 7usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9486523.27f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 4161238.504f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 207202.545f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 738579.753f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 4256399.564f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 4590654.422f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 641939.995f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4859492.484f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 6950856.385f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1226309.282f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 5308203.777f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2178556.315f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 767332.337f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 1610238.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 4727869.896f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 9142854.235f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5791207.525f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 9646295.299f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5305615.954f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1131642.384f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 2143921.736f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 10448421.54f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 1760747.195f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 984054.567f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 880375.431f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1402609.943f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 3779143.563f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 9429757.574f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8858386.875f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 5139894.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 418311.77f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 8564707.632f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 11629531.38f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2733746.991f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3837711.017f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 4663554.305f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 9344402.848f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4230833.46f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 1659127.833f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1594544.923f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 5523888.8f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 307575.179f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 661992.816f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 891304.789f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 4951087.524f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1567873.078f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 2233442.632f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 6329506.299f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1542849.593f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 1464078.762f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 388159.414f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 8273972.665f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 981672.326f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 10340626.434f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1862303.151f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7457893.63f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1249661.885f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2843735.679f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 367482.216f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 975537.903f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3297240.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2917150.915f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1874943.291f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 3109049.988f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2967957.596f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 617371.113f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2100748.826f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 933507.831f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 9647694.185f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 641530.787f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 6491236.288f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1290276.75f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 6935576.592f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 775472.674f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 6709722.09f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 5035449.427f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 10769528.967f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 8121365.229f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1567812.033f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 247126.244f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 7838241.296f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 7356150.079f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 10915739.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1352559.531f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2799142.533f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 5302948.103f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 7275769.113f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 613666.503f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "BL",
                    name: "Saint Barthélemy",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 2413958.041f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 2562136.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1504121.804f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1827889.153f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1346156.525f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 349728.497f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1584654.556f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 1613485.718f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 41705.458f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3284047.557f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1064005.221f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 1019958.196f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 4983466.903f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 3684198.569f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 1907907.768f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 969648.233f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SX",
                            distance: 32174.679f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 556955.149f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 2677914.804f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 193846.926f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 208876.269f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5313120.712f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 228644.711f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 2285996.056f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 141924.544f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 722358.471f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 328060.614f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 914620.729f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 812247.769f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 638307.736f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 473335.56f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 664654.01f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 4225006.973f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 49053.481f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 67846.473f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 410305.141f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 134411.35f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 2838578.456f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "LK",
                    name: "Sri Lanka",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 8usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 5493210.871f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 4166826.608f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 8508647.122f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 7588030.181f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 4895110.603f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 3770831.199f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 7635525.232f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3987103.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 2395427.003f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 7859213.58f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 3260359.097f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 4692921.884f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 9446461.231f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 9072054.049f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 9183012.5f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 3637514.922f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 5108967.136f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 2552017.611f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 2734542.065f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 3061558.95f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 7228308.393f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 6305544.711f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 2614041.342f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 9144518.064f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 9196832.185f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 7451310.842f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 7408807.925f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 4571387.891f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 2230598.235f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 5868112.635f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 3973955.081f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 8309287.061f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 1935200.493f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 2367328.315f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 5747530.905f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 7957968.872f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 4152594.09f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 4810528.859f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 3357907.539f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 4054643.133f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4955139.917f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 7536300.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 7472481.054f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 13567163.347f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 8097458.514f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 8088499.753f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 7453960.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 12713789.723f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 6761502.444f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 9820525.606f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 7775985.497f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 14355645.158f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 7019007.184f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 8366252.764f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 8534435.605f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 758392.686f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 5975803.876f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4212743.727f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 3344992.693f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 4151780.724f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 2043730.795f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 2438483.198f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 4566439.237f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 6502994.501f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 525146.62f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 3250351.331f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 5757715.237f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 3878418.302f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 9138652.316f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 7292447.362f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 13968685.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 7065203.35f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 5442207.866f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 7983910.064f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 7413884.882f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 5334240.192f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 5477329.967f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 6495985.119f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 5408586.636f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 5462256.566f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 7678222.32f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 9510900.162f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 7933335.037f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 8143477.246f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 14560201.057f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 7047884.615f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 14223386.118f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 8074954.252f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 6712269.901f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 8082636.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 14889367.84f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 8273972.665f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 7286341.161f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 6430727.381f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 2516001.544f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 8878234.518f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "KG",
                    name: "Kyrgyzstan",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 3usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 5451666.618f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 2725087.741f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 5222001.27f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 4663087.304f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 981722.882f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 2767745.031f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 4603735.377f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 402872.801f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 1902442.315f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 4303158.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 965276.836f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 7301061.293f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 5586534.459f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 5520549.331f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 2763860.276f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 4249956.403f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 1917282.075f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 4525947.587f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 2582794.285f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 4440079.06f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 3682341.587f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 5423486.404f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 6624671.582f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 5850308.058f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 5042122.287f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 3896478.593f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 1774077.763f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 4354725.86f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 4594418.049f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 5470035.665f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 3494263.109f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 6512111.316f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 3612000.829f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 2665495.437f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 2231622.147f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 4316482.826f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3712392.936f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 3885332.177f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 3859387.792f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 9744967.63f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 5096265.203f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 5272359.979f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 4586421.959f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 8821233.047f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 4048417.236f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 6071652.313f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 10490756.33f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 3618447.702f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 4693088.699f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 5256647.877f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 3973955.081f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 4281922.499f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 5285041.794f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 4281437.348f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 10073678.224f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 4243608.858f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2649562.015f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 4984067.399f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 4164806.986f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3743511.249f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 3380848.646f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 3293997.002f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 3591847.493f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 3451863.87f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 4534821.557f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 7023497.545f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 5257949.838f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 4507831.112f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 4761838.582f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 10709077.375f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 4274605.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 10250439.459f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 4651812.858f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 2095065.483f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 2525189.775f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 5722793.857f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 4341562.576f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 3857479.956f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 4899531.355f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 2777674.369f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 10915806.277f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 5139894.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 5775936.568f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 3852438.511f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2628028.136f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4160261.431f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 2162428.914f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 5732473.966f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "NL",
                    name: "Netherlands",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 14usize,
                    internet_exchanges_number: 181usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9369415.788f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 4467339.487f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 216419.667f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 1098953.163f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 4339250.621f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 4899529.743f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 964908.419f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 5000429.847f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 7104093.348f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1105874.434f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 5496342.015f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2159679.546f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 767532.658f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 1228066.886f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 5035898.408f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 9152828.791f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 6032786.584f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 9780794.88f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5597902.657f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1489301.764f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 2472271.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 10624033.378f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 1928400.925f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 664344.552f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 67675.405f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1267180.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1398227.175f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 3996825.396f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 9585791.033f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8779020.27f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 5256647.877f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 672708.653f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 8719712.182f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 11767408.755f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 3076801.866f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 1944427.825f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 4136606.51f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 4940951.599f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 39597.46f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 9385719.407f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 187164.584f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4585729.715f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 1570774.355f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1532667.295f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 5196474.616f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 694645.075f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1027465.779f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 1252489.678f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 4591828.952f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1903090.26f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 2663509.488f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 1781257.311f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 6004892.702f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1639402.469f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 1192638.231f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "US",
                            distance: 5768988.659f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 363414.257f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 261913.167f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 8534435.605f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 1277184.488f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 10506138.991f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2232195.08f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7074609.052f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1586202.597f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 3092229.377f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 752398.336f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 1135168.954f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3653998.862f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 3247905.764f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 2064445.094f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 3456663.074f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 3304838.193f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 864698.61f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2224025.596f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 1306227.484f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 9755865.596f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 521169.495f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 6173081.465f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1635973.968f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 6567488.996f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 6917912.733f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 5328002.639f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 10806702.764f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 8418346.943f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1868709.172f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 7993380.435f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 7001805.523f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 388159.414f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 11022720.219f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1407008.249f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2801925.831f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 5664133.149f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 7410916.421f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 526306.153f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "GM",
                    name: "Gambia",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 1usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 8138729.871f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 6930147.95f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 6449964.357f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 4072016.41f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 6285419.269f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 2118039.849f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 1646571.428f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 1998010.368f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 3171984.387f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2895283.316f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 538925.704f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 2226436.814f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 165957.913f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 6422378.045f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 662258.443f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 1623811.766f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 3137143.697f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 2324027.313f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 3213910.191f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 1016881.304f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 518629.968f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 3984741.306f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 2953227.898f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 205728.568f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 4037471.916f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 5303207.792f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 5259680.813f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 6543967.888f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 3480202.689f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 7880179.957f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 5407990.325f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 3292621.759f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 5759178.147f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 6708602.07f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 3763650.663f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 7222187.716f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 6797326.336f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 8744445.087f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 4119194.33f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 9022298.788f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 3105091.184f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 6268873.043f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 829852.827f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 7411871.811f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 5428593.266f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 5265774.868f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 6366893.886f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 6912885.821f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 6477168.416f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 5611731.158f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 1642852.319f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "SC",
                    name: "Seychelles",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 3usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 11878366.274f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 1898014.661f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 1749858.693f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 3323940.387f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 4468468.441f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 3548975.759f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 4129073.548f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 5303207.792f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 2959144.208f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 1806217.702f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 4817635.16f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 2258312.255f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 3390529.265f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 7313123.207f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 4996273.095f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 456102.396f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 426166.834f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 4822676.65f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 4569084.72f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 3245781.834f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 3369935.514f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 5392557.654f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 4153140.798f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 5029738.893f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 5239054.468f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 2009177.834f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 3759090.442f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 759690.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 8565668.282f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 5374503.343f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 5057268.463f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 5186907.105f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 4892720.342f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 3324904.439f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 5011911.254f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 2762614.217f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 3174173.076f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 3168284.854f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 4530054.518f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 4653374.192f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 2960464.915f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 2464446.923f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 4776929.123f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 6326759.476f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 3588104.509f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 6056082.841f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 3329104.819f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 1839250.289f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 3413097.81f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 3718155.752f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 4184542.045f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 1567440.424f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 3692841.524f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "SH",
                    name: "Saint Helena",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 1usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 11184842.111f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 6209156.174f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 5097757.204f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 2202612.088f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 3417733.096f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 2567435.629f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 2370249.846f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 3480202.689f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 2260339.745f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 6086712.023f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 5392557.654f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 2533249.169f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 2250406.675f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 2265373.682f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 4349069.777f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 2681738.612f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 3125728.705f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 5548834.125f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 2837315.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 3272913.714f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 4079953.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 5930001.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 6134501.813f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 7032778.264f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 3639327.126f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 2961662.256f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 3944554.809f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 3700018.123f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 6130048.957f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 2760550.522f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 5334640.704f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 3977164.265f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 6434751.322f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 2534381.196f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 5943520.135f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 6763419.861f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 6578146.867f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 3897338.871f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 4052455.784f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 5481061.691f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 4217159.705f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 2634349.922f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 2464138.005f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 6497586.943f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 4855675.538f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 4298618.439f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 6185008.903f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 4573479.119f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 3179541.199f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "HR",
                    name: "Croatia",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 3usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9368969.251f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3300965.454f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1089265.797f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 153646.713f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3793730.003f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 3725859.803f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 331796.589f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4263753.462f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 6304146.354f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1528050.146f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4617450.513f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2766410.393f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1654022.228f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 2397695.77f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 3863529.245f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8747887.467f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5008108.816f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 9009756.821f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4456663.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 240685.615f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1271582.019f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 9739077.949f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 2042949.178f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1875101.227f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 99760.066f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1418604.119f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 3059184.952f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 8758387.667f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8661477.613f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4586421.959f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 1001055.401f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 7901280.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 10972520.191f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 1845567.94f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 2987612.131f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 3836411.094f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 8883668.685f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3339654.253f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 1794594.872f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1686754.032f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 6410757.288f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 651411.725f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 691248.474f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 368781.307f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 184516.784f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 5840401.988f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 695987.766f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 3063326.226f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 7214739.182f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1286252.271f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 2000753.016f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1252489.678f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 7453960.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 360754.103f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 9647831.729f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 8313590.879f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 389708.069f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2089288.016f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 544705.055f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 790923.533f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 2406225.368f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2037184.328f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1319690.261f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 2218645.072f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2083059.645f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 549564.466f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2439444.574f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 695491.077f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 9057463.837f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 1184167.149f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 7373089.368f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 409878.106f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 7819858.652f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 1246373.09f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 5972026.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4187189.839f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 10301570.417f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 7261010.242f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 767422.288f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 803615.631f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 7180277.247f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 8247003.491f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 891304.789f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 10316832.81f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1251855.512f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2586438.803f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4413659.087f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 6658372.038f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "GU",
                    name: "Guam",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 15usize,
                    internet_exchanges_number: 6usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 2446190.664f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 3398610.534f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 4689217.239f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PW",
                            distance: 1288983.519f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 9121580.601f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 9807757.595f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 4552056.611f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 2203787.825f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 2543914.817f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 849818.052f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 2522110.704f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 4672027.624f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 4740639.026f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 3417107.044f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 4116100.93f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 89304.21f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 2082644.987f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 5805291.765f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 6585914.128f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 5661731.578f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 7555335.168f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 5795798.254f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 5093932.201f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 5063800.933f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 7120100.847f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 5407891.003f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 2834070.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 5026674.462f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 4329240.874f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 4911124.053f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 2861940.31f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 5176549.536f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 8166077.904f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "MZ",
                    name: "Mozambique",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 4usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 15034904.69f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 3403464.065f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 2551441.922f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 2841752.311f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 944236.063f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 4883526.299f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 5261247.943f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 6912885.821f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 3094809.586f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 8407874.873f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 9284055.647f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 4184542.045f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 5930379.396f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 2066855.134f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 3997022.696f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5326233.694f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 819337.16f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 4298618.439f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 1824374.242f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 6290325.456f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 6729644.008f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 8186854.915f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 8188240.836f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 2275202.851f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 7388393.87f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 5093377.787f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 5323990.759f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 3840371.354f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 7050785.71f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 6398092.467f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 7165237.66f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 994273.375f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 7153731.016f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 341383.55f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 3996141.361f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 1940896.848f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 4784136.488f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 502723.931f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 2144419.602f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 3933340.149f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 6413477.32f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 2475542.745f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 9433393.688f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 714374.974f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 7709106.911f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 8118168.977f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 1596324.144f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 2411823.801f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 4803695.521f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 6635204.803f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 4978643.291f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 6125201.453f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 2243915.003f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 4330537.111f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 2620870.84f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 5582241.863f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "SL",
                    name: "Sierra Leone",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 1usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 8778186.862f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 6565327.252f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 5972150.318f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 3457617.875f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 5637455.568f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 1616132.311f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 1075803.359f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 662258.443f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 3453518.034f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3381270.067f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 5029738.893f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 362604.744f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 4598621.483f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 2390686.859f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 5959579.994f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 2837315.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 7298214.195f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 1474924.758f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 2650602.443f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 125259.498f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 1744650.768f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 828209.543f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 5760159.638f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2203533.485f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 2633416.34f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 1850793.005f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 2669646.282f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 1107629.863f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 4452629.993f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 460227.471f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 4903329.123f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 3579809.351f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 5560717.521f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 6054081.673f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 3980013.123f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 6686628.863f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 6156228.578f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 8174951.752f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 4192511.192f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 8462621.646f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 3740989.115f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 5661872.79f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 1418862.053f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 6873840.179f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 4940843.609f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 5236206.546f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 5864393.066f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 6290325.456f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 6174722.789f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 5155610.04f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 1352700.793f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "UZ",
                    name: "Uzbekistan",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 5854213.072f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 2332492.202f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 4953802.42f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 4348264.547f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 913505.99f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 2396680.902f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 4301623.24f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 2106017.383f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 4093108.977f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 779692.522f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 7002463.001f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 5346231.59f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 5350504.482f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 2401975.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 4628788.92f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 1735740.857f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 4787136.003f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 2277675.388f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 4106546.583f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 3312180.151f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 5636498.612f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 6292633.917f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 5612578.957f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 4710808.213f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 3670258.888f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 1379567.238f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 4586167.208f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 4997289.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 402872.801f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 5173374.169f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 3720354.155f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 6772021.249f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 3218510.973f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 2264104.678f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 1867441.066f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 4673446.67f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3321852.965f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 3696859.048f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 3659337.797f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 9645222.689f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 4796963.756f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 4953419.448f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 4263753.462f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 8747436.681f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 3701104.577f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 5931616.064f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 10409054.943f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 3362402.921f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 4519516.887f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 5000429.847f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 3987103.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 3972042.888f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 5510016.101f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 3911520.49f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 10152283.769f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 3910536.187f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2280547.132f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 4683097.682f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 3888936.25f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3340838.582f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2984668.36f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 2994095.646f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 3190885.419f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 3053902.947f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 4247574.942f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 6692708.771f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 4924502.681f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 4800287.134f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 4518599.221f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 10622915.668f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 3936941.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 10262808.912f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 4415563.491f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 2123028.388f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 2192644.899f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 6068542.808f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 4273547.832f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 3521448.591f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 4623440.435f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 2994872.82f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 10913512.101f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 4859492.484f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 6065448.85f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 3607434.856f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2483667.986f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 3812249.513f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 2416278.254f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 5460867.758f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "SD",
                    name: "Sudan",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 6usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 11703028.225f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 2144583.59f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 1534911.75f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 2645456.77f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 1551558.481f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 4083259.321f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 5137938.965f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 4167528.037f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 4734585.649f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 5759178.147f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 3934044.262f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 4928365.776f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 5031175.782f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 1598069.966f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 759690.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 3116687.825f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 5388647.218f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 5309039.012f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 3952214.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 1807575.057f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 3945607.834f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 6134501.813f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 4052365.475f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 5560717.521f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 5719937.846f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 3798144.989f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 3963974.848f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 2696757.932f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 3655828.873f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 1616054.208f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 4337011.576f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 4094355.086f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 6277109.82f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 5811535.044f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 2948385.31f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 1093893.705f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 3932153.939f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 3702844.872f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 5093377.787f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 1385804.021f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 503768.236f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 3544142.466f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 1627058.39f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 2115599.497f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 4810528.859f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 1960306.332f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 4289960.427f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 3734534.167f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 3296890.458f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 5573808.313f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 5577757.91f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 5540142.297f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 3459040.978f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 5148215.452f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 4924222.038f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 3666745.267f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 2355312.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 4995844.533f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 6367930.134f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 4218757.26f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 6463524.916f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 3709156.668f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 2520570.76f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 4034687.061f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 2204915.505f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 4208324.07f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "KY",
                    name: "Cayman Islands",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 4usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 1052852.635f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 813881.371f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 389436.874f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1105286.026f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 572600.283f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 1592646.57f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 743986.078f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 2154984.178f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 1881700.046f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3791772.516f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 953533.354f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 888511.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 3655935.562f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 618234.069f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 755120.965f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 1244195.138f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 2252493.111f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 861771.898f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 1400573.424f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 2212134.217f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 788186.209f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 1717167.122f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 1693379.173f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5524851.702f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 2069413.494f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 765331.473f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 829881.007f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 1186427.071f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 2120025.305f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 1512285.943f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 2301682.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 2377813.588f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 2200375.027f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 2205646.11f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 1885967.322f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 1930598.42f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 2169579.399f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 1907907.768f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 2026251.113f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "BB",
                    name: "Barbados",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 3usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 2644746.69f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 2940548.535f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1953499.914f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 2123030.013f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GY",
                            distance: 712113.274f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SR",
                            distance: 869899.166f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1855432.167f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 917186.593f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 2176326.853f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 2201459.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 678064.661f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3776395.016f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1646449.064f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 1511985.416f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 5613997.72f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 4183299.41f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 2377813.588f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 1123408.016f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SX",
                            distance: 669434.777f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 172947.95f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 3102513.858f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 795987.113f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 763918.755f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5812845.745f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 410251.967f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 2597742.166f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 497117.736f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 1251533.528f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 312530.574f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 1018760.427f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 346344.603f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 271290.859f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 576263.505f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 513210.412f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 638307.736f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 234056.121f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 182859.844f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 4854417.035f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 623487.581f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 3213893.029f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "BQ",
                    name: "Bonaire, Sint Eustatius and Saba",
                    continent: Some("North America"),
                    other_names: vec!["Sint Eustatius and Saba"],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 2374898.295f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 2532724.509f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1478886.957f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1791294.104f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1327504.644f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 374057.02f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1580967.134f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 1649530.059f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 74954.046f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3327224.619f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1056980.733f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 997464.986f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 4992891.936f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 3667656.576f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 1885967.322f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 923710.179f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SX",
                            distance: 61439.264f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 540384.297f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 2652628.377f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 184748.154f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 194675.314f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5355262.655f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 212835.503f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 2251363.983f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 1407392.553f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 702972.746f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 312121.72f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 867369.639f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 783145.441f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 623487.581f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 453240.423f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 622862.399f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "US",
                            distance: 4233856.033f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 33418.703f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 49053.481f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 390244.764f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 2809268.44f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 142659.162f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "HU",
                    name: "Hungary",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 5usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9008948.161f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3191389.171f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1146834.521f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 386728.392f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3463777.125f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 3623060.591f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 346461.354f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3972042.888f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 6036029.106f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1272310.87f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4366370.938f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3032835.574f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1689404.824f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 2303972.518f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 3759643.654f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8413949.528f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 4814381.675f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 8741033.476f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4328441.714f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 408352.94f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1203347.331f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 9503486.077f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 2370042.456f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1936529.395f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 832971.712f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1094444.229f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 2819991.18f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 8503850.622f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8304647.473f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4281922.499f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 1214134.753f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 7642318.536f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 10714231.674f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 1820981.591f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 2863059.128f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 3682302.515f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 8562751.462f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3341628.866f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 1480133.902f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1366916.527f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 6473454.089f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 836758.892f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 997876.883f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 360754.103f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 5847956.85f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 655168.237f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 2990279.302f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 7282028.075f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 927399.45f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 1796996.439f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1277184.488f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 7292447.362f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 9404024.688f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1093087.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 8239270.561f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 369247.046f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 1869281.502f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 720559.292f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 479119.914f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 2420178.391f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 1977233.255f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 992125.293f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 2205379.833f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2039543.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 423240.306f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2761761.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 1047609.625f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 8772075.033f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 1057960.717f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 7450034.09f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 446246.176f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 7801935.246f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 1081441.961f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 5748524.085f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4058288.513f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 9984013.572f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 7147046.039f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 592004.11f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 808091.387f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 6918093.603f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 8261104.813f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 981672.326f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 10035913.08f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 913157.994f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2225800.59f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4429662.117f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 6379333.188f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 1588187.788f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "CV",
                    name: "Cape Verde",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 20usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 7364625.679f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 7720001.612f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 7275914.213f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 4873226.89f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 7047293.606f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 2873621.685f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 2383326.389f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 829852.827f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 4583390.572f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2991515.052f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 6056082.841f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 1779792.459f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 5885466.625f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 3780319.232f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 7363630.978f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 4052455.784f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 8701249.513f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 1418862.053f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 988056.136f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 6237429.343f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 3603171.91f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 6463524.916f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 3154904.001f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 652979.691f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 1312070.876f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 888726.225f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 7454459.314f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 4139866.161f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 6952787.095f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 3782280.496f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 8051789.073f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 3087873.017f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 7571054.983f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 9569584.627f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 3925077.684f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 4633428.033f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 9849610.566f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 2718558.768f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 2652349.237f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 7077074.111f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 2752637.619f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 1674332.121f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 6691583.597f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 8241361.536f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 6256597.301f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 3061616.628f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 5848608.729f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 7195916.242f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 7709106.911f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 7238544.694f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 6434474.619f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 2450046.333f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "BF",
                    name: "Burkina Faso",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 9467649.423f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 5288547.053f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 4841268.4f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 2806113.815f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 5113628.306f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 756598.158f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 829815.432f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 1642852.319f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 2660684.522f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 3692841.524f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 1221604.622f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 4271396.04f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 1618532.831f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 5095272.914f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 3179541.199f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 6407205.17f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 1352700.793f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 1553673.677f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 3833801.742f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 2751561.459f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 4208324.07f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 5412021.747f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 1741704.103f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 1368007.347f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 1675803.71f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 5581979.102f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 2995250.111f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 5563773.164f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 1605582.983f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 5670565.036f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 936705.651f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 5563800.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 7236265.574f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 1648907.04f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 3001562.948f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 7493984.119f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 3908978.381f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 4892592.972f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 2450046.333f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 5862221.769f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 3835805.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 797165.943f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 771101.719f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 3935144.035f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 4781262.709f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 5582241.863f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 4853489.389f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 3992279.854f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "PE",
                    name: "Peru",
                    continent: Some("South America"),
                    other_names: vec![],
                    cable_connections_number: 7usize,
                    internet_exchanges_number: 4usize,
                    links: vec![
                        LinkTo {
                            code: "PA",
                            distance: 2428518.85f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GY",
                            distance: 2520025.267f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SR",
                            distance: 2618820.888f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 984719.561f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 3295241.789f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 1206768.486f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 1797248.529f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 4321117.43f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 3362395.235f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 2767696.286f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 3593929.797f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 2852114.645f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 4309373.878f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 3558240.407f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 3616836.471f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 2297020.351f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BO",
                            distance: 1467110.722f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GF",
                            distance: 2941768.966f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PY",
                            distance: 2829444.345f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UY",
                            distance: 3737971.732f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "AT",
                    name: "Austria",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 14usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9221812.835f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3520316.609f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 819136.313f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 208886.818f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3764440.959f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 3950370.768f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4301623.24f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 6373687.446f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1221305.789f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4709130.806f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2700855.449f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1375402.775f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 2072969.988f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 4087442.475f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8703332.362f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5160391.37f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 9077466.555f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4663678.283f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 543424.311f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1509766.886f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 9847638.279f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 2086958.168f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1613023.542f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 655825.849f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1171401.598f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 3165281.731f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 8844519.576f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8540389.996f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4603735.377f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 873984.85f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 7982087.068f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 11053315.199f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2111924.652f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3195908.305f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 4022891.176f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 8867393.921f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3623153.563f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 1528375.583f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1428415.607f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 6155613.994f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 496209.1f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 719172.452f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 331796.589f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 5555020.821f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 938287.096f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 2744681.094f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 6962790.166f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1128062.71f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 1673319.792f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 964908.419f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 7635525.232f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 346461.354f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 9746820.04f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1295162.013f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7997889.322f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 621359.729f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2215726.111f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 381523.251f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 562781.616f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 2693125.98f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2285082.221f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1309900.502f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 2492248.926f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2340413.008f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 228955.125f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2470428.375f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 842750.732f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 9101651.017f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 852486.361f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 7127274.938f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 673896.296f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 7524063.548f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 916068.041f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 6094454.556f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4393510.927f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 10290958.653f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 7479792.084f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 926054.669f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 498484.002f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 7257201.995f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 7966033.15f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 641939.995f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 10367038.757f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1032902.994f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2443199.647f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4704744.896f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 6712855.115f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 1243282.327f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "ME",
                    name: "Montenegro",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 10841077.772f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 9658863.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 5336726.773f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 6260059.731f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 8770941.739f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 10092135.547f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 6155613.994f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 9645222.689f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 11611913.874f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 5723355.964f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 10325977.497f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 4390445.16f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 4784168.754f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 4392904.805f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 10227687.94f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 12101482.156f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 11058977.371f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 13809770.69f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 10768881.956f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 6651303.746f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 7665265.048f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 14899209.024f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 5381112.523f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 4542807.499f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 6239941.652f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 6175128.665f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 9018945.309f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 13834119.961f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 10869591.99f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 9744967.63f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 5472624.713f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 13068336.112f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 15425361.641f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 8256293.022f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 9323228.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 10090377.706f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 12597577.429f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 9733027.12f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 6031297.007f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 6097303.076f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 5768152.94f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 5909345.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 6410757.288f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 1002061.541f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 7091010.547f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 3746660.959f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 809927.318f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 6580410.514f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 5202494.402f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 5196474.616f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 13567163.347f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 6473454.089f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 14705608.405f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 7350824.395f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 2875147.234f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 6772656.248f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 8219607.67f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 5867939.039f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 6252338.523f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 8801330.651f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 8440083.906f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 7133613.065f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 8627728.861f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 8491830.699f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 6056505.887f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 5172211.735f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 6143839.999f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 13544161.225f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 5506762.831f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 996077.054f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 6814000.112f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 1875387.071f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 5554650.639f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 11759975.638f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 10501035.383f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 13616909.034f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 13581318.901f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 7064266.373f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 5666238.971f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 12423659.532f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 1975626.356f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 5523888.8f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 14532565.818f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 6312676.215f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 7164531.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 10775950.051f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 11763684.213f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 4981274.855f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "GR",
                    name: "Greece",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 8usize,
                    internet_exchanges_number: 13usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9471731.922f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 2482359.215f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 2425042.446f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 1134047.637f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3658465.245f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 2885157.182f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 1295162.013f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3911520.49f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 5809814.902f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 2351277.236f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4101491.719f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 9159647.559f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2943736.062f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 2848634.737f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 3366495.318f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 2859662.824f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8623946.3f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 4263119.932f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 8377837.39f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 3573613.063f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 751833.976f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 408882.043f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 8983914.634f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 2526316.557f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 2839645.314f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1046399.468f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 2097285.996f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 2569580.839f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 8320141.149f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8958598.313f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4281437.348f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 2700863.128f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 7325957.156f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 9758248.278f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 772972.914f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 2208206.122f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 3088071.829f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 8582873.505f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 2146657.455f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 2485302.105f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 2365227.296f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 7350824.395f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 1590796.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1458583.717f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 368781.307f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 1170091.539f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 512769.622f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 4039773.746f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 8148868.66f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1785582.832f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 2889352.761f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 2232195.08f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 6502994.501f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 1093087.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 12147778.422f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 8940068.888f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 726892.226f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 9745344.262f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 5978921.897f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 8465862.346f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 3283911.443f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 3292431.696f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 9768467.793f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 2650501.68f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 192873.108f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 330674.266f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 3289556.812f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 9292504.076f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 724117.823f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 1632082.603f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 1500051.157f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 1545306.899f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 1450656.351f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 1192828.114f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1453202.57f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 1294651.98f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 1207680.132f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 1478528.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2917885.176f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 1269236.96f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 2130901.202f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 8298409.865f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 647716.071f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 8797565.304f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 2168918.888f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 6399425.814f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 762887.295f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 1783815.156f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 6651962.999f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 9213367.436f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 1862303.151f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1891036.764f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2866908.826f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 6198249.288f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "SR",
                    name: "Suriname",
                    continent: Some("South America"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "GY",
                            distance: 221548.021f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 788389.268f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 869899.166f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 903809.846f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PE",
                            distance: 2618820.888f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 1539397.513f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BO",
                            distance: 2779490.885f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GF",
                            distance: 440620.715f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 1348368.57f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 3052712.687f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PY",
                            distance: 3471722.79f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 2943932.086f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 2928271.537f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 4569083.239f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 4726564.433f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UY",
                            distance: 4537766.859f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "ES",
                    name: "Spain",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 55usize,
                    internet_exchanges_number: 17usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 11261785.195f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 6140785.553f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 5359913.234f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 2136080.654f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 6320267.232f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 2375218.775f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 6225532.923f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 5733127.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 2470428.375f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 6692708.771f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 5177290.304f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 8692913.402f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 3306399.121f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 6987403.746f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 2994623.596f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 2788994.425f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 1623811.766f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 4802874.726f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 1323084.977f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1514575.18f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 3085436.583f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 5864942.405f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 10883162.252f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 7236374.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 2493501.329f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 6482050.171f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 3954022.319f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 11385240.927f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5615475.434f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 2586165.651f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 3477604.495f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 12015927.097f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 400663.786f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 7802794.982f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 2203533.485f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 1812386.524f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 2088857.056f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1645340.282f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 3499709.886f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 5430254.945f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 10910999.753f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 10753471.019f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 7023497.545f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 338108.174f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 10260989.812f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 13306543.6f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 3842966.377f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 423328.774f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 5112097.377f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 4094355.086f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 5993235.336f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 11322400.435f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4575167.86f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 3754829.567f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 3694574.371f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 5172211.735f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 2014538.915f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 4616527.763f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1764035.668f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 3519686.784f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 2083087.49f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 1110564.908f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 2439444.574f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 5019576.729f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 3004627.638f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 3370667.984f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 5875540.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 3580066.081f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 3389601.391f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 2224025.596f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 9510900.162f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 2761761.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 7680728.79f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 3724670.948f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 3107974.002f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 11023569.954f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2917885.176f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7771998.317f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 2782250.068f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 4034952.68f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 4456775.073f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 2111608.514f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 98281.814f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 2995565.203f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3794964.146f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 4092759.37f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 5579225.456f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 3752305.617f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 4113059.781f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 4088215.053f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 2599726.995f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 1674332.121f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 3270534.135f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 5908334.215f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 7716637.572f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 2962918.815f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 6556170.663f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 5175483.401f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 8118168.977f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 3073332.111f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 6068618.618f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 9627037.356f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 5614437.324f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 1768316.628f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 11466372.83f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 2706195f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 2756870.807f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 6955085.324f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 2846102.267f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 12741012.154f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 9131408.251f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 3171360.255f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 2338718.447f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 9552011.344f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 7147691.046f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 2100748.826f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 12712858.337f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 3428721.838f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 4878944.338f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 5889332.53f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 9064396.233f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 1724004.946f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "OM",
                    name: "Oman",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 18usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 6887878.396f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 1930872.965f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 1195076.969f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 5617399.636f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 2838497.825f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 4596518.672f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3002316.384f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 809434.841f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 4663678.283f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 2277675.388f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 2823485.904f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 5087382.889f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 1658583.97f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 6455183.462f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 6305848.891f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 5257855.392f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 6547292.679f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 6360985.692f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 6411341.296f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 710229.556f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 6169702.261f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 866905.185f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 4960914.598f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 2961624.376f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 1912026.407f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 4399188.677f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 5217161.861f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 283435.825f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 2110213.085f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 3233311.256f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 3245532.901f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 3061558.95f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 5256000.567f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 3799497.945f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 5248277.62f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 5445362.927f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 2082113.539f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 6042530.937f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 5615475.434f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 6818894.534f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 7617708.28f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 3122204.656f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 5630599.175f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 5230725.322f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 3747981.571f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 5326233.694f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 1807575.057f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 6622970.082f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 3573613.063f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 2414807.743f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 5233293.098f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 6775469.952f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 8670168.009f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 4812007.282f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 6365926.565f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 6221256.638f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2811113.841f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 320881.98f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 1181255.403f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 6154406.634f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 5087252.874f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 4471931.386f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 2722723.297f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 4225270.524f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 6261446.526f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 4641095.57f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 1902155.765f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 2582794.285f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 5766837.619f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 4858004.226f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 4769235.936f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 10768881.956f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 5106252.19f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 4456663.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 10045096.73f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 3760809.458f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 7092053.027f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 11578489.139f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 4217934.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 5647642.873f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 5597902.657f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 4328441.714f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 12002280.704f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 4071610.281f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2555140.431f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 4995255.582f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 4516825.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 2341578.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2454791.519f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 3645964.863f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 2391690.302f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2438442.548f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 4733244.104f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 4911085.937f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 5262170.658f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 11757717.889f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 4047442.887f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 11861878.667f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 5215997.848f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 3738259.817f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 5133414.022f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 12422619.893f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 5305615.954f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 4482194.758f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 4031729.986f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 3249303.594f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 5896802.676f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "CG",
                    name: "Congo",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 5usize,
                    internet_exchanges_number: 5usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 12114802.847f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 3769411.753f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 3033496.613f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 406463.585f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 2500340.547f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 1822616.574f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 2207218.577f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 4037471.916f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 1890490.53f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 4802874.726f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 1695296.978f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 1159849.173f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 4583390.572f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 5428087.107f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 1876563.39f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 3106848.007f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 6516019.177f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 4006532.991f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 2976086.034f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 3924892.167f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 5608373.599f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 773568.819f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 3859003.169f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 3094809.586f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 5518754.215f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 4646162.501f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 3934044.262f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5257855.392f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4350608.906f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 2260339.745f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 2959144.208f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 3107136.534f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 1082792.175f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 2507952.521f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 3453518.034f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 3867689.269f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 1646736.653f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 4798552.683f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 3549745.008f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 4251789.718f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 2984789.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 4732197.079f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 3270033.52f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 2913751.587f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 4721729.837f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 1013881.378f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 4210595.034f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 5012375.582f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 6545046.92f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 2246159.48f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 3451375.097f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 1756147.536f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 1879671.056f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 2090508.613f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 2660684.522f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "PW",
                    name: "Palau",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "SG",
                            distance: 3455633.878f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 988171.093f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 11084217.016f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 1255021.7f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 439777.09f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 7349448.189f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 1288983.519f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 6347532.937f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 6595505.683f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 6371913.957f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 8850091.938f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 6506662.867f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 5601588.722f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 3768485.802f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 7804730.402f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 6217579.886f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 3669964.281f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 5694808.711f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 1439345.515f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 4651395.965f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 4706601.514f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 5929920.787f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 3188913.673f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 5831406.876f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 3827229.06f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 8987248.409f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 2108506.126f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "AS",
                    name: "American Samoa",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "PW",
                            distance: 6506662.867f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 5795798.254f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 781078.613f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 2837642.665f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 125579.394f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 5807291.089f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "US",
                            distance: 4193277.771f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 4401706.968f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 1201930.649f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 9043154.573f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 1324308.697f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 592043.194f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 2964133.653f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 818764.88f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 4495820.854f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 5798919.984f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 2273885.768f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 1779566.648f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 3415131.132f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 699873.737f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 3329807.167f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 2510746.734f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 4658454.58f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "KN",
                    name: "Saint Kitts and Nevis",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 3usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 2405190.695f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 2572748.885f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1521897.134f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1824853.366f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1373657.243f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 380042.137f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1630038.902f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 1681145.319f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 107856.077f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3347906.848f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1105859.815f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 1042134.889f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 5040735.76f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 3714318.609f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 1930598.42f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 941166.018f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SX",
                            distance: 95373.009f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 489837.568f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 2695373.06f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 233261.562f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 227575.668f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5377912.954f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 170215.955f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 2286901.558f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 79843.57f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 749182.226f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 264312.94f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 879655.987f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 744424.943f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 576263.505f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 407958.398f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 596814.092f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 4281821.969f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 33418.703f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 95186.958f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 67846.473f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 345860.598f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 2849329.9f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "ZW",
                    name: "Zimbabwe",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 14358353.717f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 3122441.279f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 1819392.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 2204882.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 983981.704f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 4208510.935f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 4617297.992f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 6268873.043f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 2246159.48f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 3588104.509f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 5305759.899f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 1791799.888f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 3327323.667f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 490405.797f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 3897338.871f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 1689610.732f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 5661872.79f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 6091699.739f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 1615090.986f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 6680929.845f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 4218757.26f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 10218251.994f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 6416826.845f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 5765265.253f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 6497772.136f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 1325425.245f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 6459146.694f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 1469424.075f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 3297477.433f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 1515803.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 3955890.999f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 944189.41f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 2589372.571f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 3245755.424f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 5736503.553f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 2907489.241f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 8725542.573f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 7077074.111f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 1628033.028f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 1767209.146f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 4122745.319f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 4291642.535f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 5339552.331f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 1518145.221f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 714374.974f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 3534979.542f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 2024203.752f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 4892592.972f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "SB",
                    name: "Solomon Islands",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 4usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "PW",
                            distance: 3188913.673f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 2861940.31f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 3166039.251f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 3749615.721f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 3284732.806f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 7572702.447f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 3415131.132f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 2418128.883f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 5797864.752f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 4663418.9f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 3253396.007f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 1351178.215f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 2598137.983f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 1816758.877f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 2939913.118f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 1489271.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 2954783.545f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 3422862.529f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 1485504.117f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 2717618.325f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 2183119.718f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 5925739.967f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "GE",
                    name: "Georgia",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 7920147.177f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 1529488.652f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 2990336.436f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 2202955.618f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 2091597.735f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 1948499.709f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 2215726.111f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 2280547.132f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 4237197.42f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 2538591.452f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 2536612.967f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 4852899.698f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 3492807.679f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 3857269.593f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 2073086.711f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 6899062.636f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 2947576.413f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 6936848.838f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 2555140.431f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1895522.665f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1032819.34f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 7649926.587f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 4056460.021f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 3754868.132f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 2494014.079f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 2097999.769f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 975575.533f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 6673792.804f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 7109444.041f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 2649562.015f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 3072228.546f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 5820602.919f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 8888472.536f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 1097703.549f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 1184496.68f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 1870775.173f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 6953661.614f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 2124704.935f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 2352347.096f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 2252420.965f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 8219607.67f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 2699210.135f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 2773174.088f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 2089288.016f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 7492273.63f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1109424.887f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 4540985.938f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 9028336.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1669182.329f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 3108290.819f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 3092229.377f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 5442207.866f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 1869281.502f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 7558968.391f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1632082.603f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 9591595.496f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1707235.582f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 425043.585f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 2583040.51f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 1977968.786f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 1524946.605f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 949958.693f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1091040.604f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 1275208.118f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 1053847.122f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 2238737.57f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 4456775.073f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 2697939.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 7009874.957f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 2718398.552f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 9211658.443f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1715732.535f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 9344229.26f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 2665066.451f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 3884943.39f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 2290902.732f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 8342812.327f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 5361986.552f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1321873.857f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 2643089.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 5103698.415f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 9880968.648f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 2843735.679f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 8257567.914f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1930451.016f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 3137411.625f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 4608398.415f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 3455100.775f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "EG",
                    name: "Egypt",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 30usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9612467.426f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NE",
                            distance: 10414135.379f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 3526567.71f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 1492731.032f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 3137469.269f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 3763776.691f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 1816175.498f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 4718789.673f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 6192691.525f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 4148445.925f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 4756534.005f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 5265774.868f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 8819315.206f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 4646162.501f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3847160.116f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 3606678.227f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 1938925.196f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8211256.553f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 4817635.16f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 3711465.11f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 5155618.471f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 6154626.767f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 4232269.659f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 7864902.152f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 2961624.376f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 656791.743f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 8405125.336f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 5128501.849f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 3276444.991f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 6497586.943f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 5433910.625f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 5236206.546f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 5278887.819f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1693553.067f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 7744299.698f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8791169.808f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 2533483.705f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 3740320.826f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 6670740.195f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 8178314.306f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 553953.61f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 2119124.615f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 1540484.735f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 1385804.021f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 2334880.159f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 1421120.181f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 4190062.344f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 2407294.581f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 5364234.706f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 5216232.419f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 4970068.526f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 6631604.062f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 1956313.056f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 5975803.876f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 6457487.696f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 3739783.726f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 4862121.221f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 11440642.9f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 4077135.932f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 6283190.389f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 7844674.287f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 726892.226f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 6231780.728f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 3967212.795f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 1569030.238f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 6300625.87f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 3294202.882f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 524451.25f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 694648.311f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 664312.162f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 5339552.331f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 5848608.729f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3270534.135f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 8002393.939f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 4999784.421f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 3577596.493f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 4034435.37f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 4500828.725f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 2671651.846f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 9329692.696f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 4428938.518f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 5168002.213f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 6031088.352f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 2270988.092f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 2572084.213f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 4058692.037f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 6125201.453f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 9248780.136f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 3324927.183f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 3935144.035f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "WF",
                    name: "Wallis and Futuna",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "PW",
                            distance: 5831406.876f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 5176549.536f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 758089.701f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 2905077.2f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 691284.752f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 6143270.434f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 699873.737f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 386297.674f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 8359612.176f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 1974218.841f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 781408.176f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 2369527.72f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 155134.342f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 3883722.211f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 5191084.111f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 1612986.347f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 4454703.812f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 1801793.273f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 2717618.325f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 2860957.551f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 3208504.392f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 3959455.25f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "CY",
                    name: "Cyprus",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 13usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8822755.356f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 3111959.137f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 1527536.104f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 2987340.777f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 4381891.06f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 1996348.066f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3169196.343f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 1927699.788f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 2111924.652f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3218510.973f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 4970655.029f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 2925875.547f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 3278319.985f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 8464401.053f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3701697.954f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 3475047.557f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 4110873.738f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 2064388.954f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 7985762.859f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 4996273.095f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 3490154.986f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 7600803.163f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 2811113.841f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1605111.276f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 208864.238f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 8211133.594f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 3459053.262f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 3717311.593f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1808240.955f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 2563094.884f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 1838956.105f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 7547294.308f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8371570.825f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 3612000.829f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 2597434.881f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 6559153.911f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 8988809.531f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 553953.61f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 2333451.72f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 370515.346f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 9014730.133f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 772972.914f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 5222653.028f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 7715700.266f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 2793735.259f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 2528677.234f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 1616264.246f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 8167111.035f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 5747530.905f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 11430904.369f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 9003520.903f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 3421071.506f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 209441.944f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 201647.879f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 1269643.777f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 2150385.499f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 7830719.749f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 2913639.971f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 2795510.004f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 8256293.022f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 2491323.084f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 2404751.692f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 1845567.94f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1174414.054f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 4802463.975f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 9060202.501f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 2157079.44f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 3505230.355f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 3076801.866f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 1820981.591f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 10034765.728f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1490599.828f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 1097703.549f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 2389095.692f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 2166437.249f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 622577.235f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1620996.022f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 385373.034f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 2243774.805f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3842966.377f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 2226212.319f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 2868494.2f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 9217351.368f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1443877.718f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 9622799.099f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 2870414.577f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 5447271.272f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1263565.762f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 2609315.01f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 5784955.817f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 10077249.09f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 2733746.991f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 2356211.938f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2852626.822f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 2612378.596f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 5374745.467f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 3284257.473f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "AF",
                    name: "Afghanistan",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 6116763.255f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 2065614.817f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 5426813.86f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 4722157.741f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 1683161.408f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 1988081.69f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 4709130.806f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 779692.522f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 1708753.847f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 4677763.926f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 7383855.1f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 5867164.525f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 5975545.761f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 1951638.739f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 4625388.701f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 964120.724f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 4400608.589f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 1658583.97f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 4430948.236f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 3517804.704f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 5140583.49f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 6587928.704f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 6135208.973f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 5030609.488f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 4237250.753f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 1561128.435f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 4141052.337f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 5239627.758f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 965276.836f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 5580444.428f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 3284676.219f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 6355079.369f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 3278319.985f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 2118343.434f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 1452549.371f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 4567811.125f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3002704.45f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 4316348.838f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 4264257.213f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 10325977.497f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 5203101.205f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 5305727.471f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 4617450.513f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 9454450.305f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 3989079.695f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 6587432.7f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 11104077.333f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 3885756.031f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 5147688.218f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 5496342.015f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 3260359.097f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 4366370.938f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 5037727.277f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 4101491.719f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 10930291.509f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 4240672.092f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2536612.967f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 5086930.027f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 4363266.62f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3246123.921f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 3025827.888f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 3437694.34f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 3155027.658f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 3071082.777f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 4690899.855f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 6987403.746f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 5234069.435f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 4488294.604f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 5044527.731f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 11313140.831f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 4251919.281f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 11021439.905f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 4954891.609f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 1446277.648f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 1645992.74f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 5896480.161f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 3501757.61f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 3851953.59f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 5084829.348f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 2567170.662f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 11664000.703f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 5308203.777f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 5725665.115f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 4145068.215f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 3171000.902f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 3285254.25f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 2100135.332f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 5920483.081f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "GF",
                    name: "French Guiana",
                    continent: Some("South America"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "GY",
                            distance: 656722.328f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SR",
                            distance: 440620.715f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PE",
                            distance: 2941768.966f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 1987510.807f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 2119101.45f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BO",
                            distance: 2900313.616f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 1970519.607f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 1401643.348f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 1722355.002f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 1808249.138f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 3775124.556f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 1195092.288f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 3452881.94f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PY",
                            distance: 3414179.497f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 3356363.243f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 4529276.611f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 4793055.425f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UY",
                            distance: 4450325.005f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "PF",
                    name: "French Polynesia",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 21usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "PW",
                            distance: 8987248.409f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 8166077.904f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 2908072.975f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 4458673.713f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 2438863.051f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 2176337.853f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 2510746.734f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 3606485.951f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 11441741.344f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 1109745.095f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 2775586.847f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 5355807.681f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 3328882.847f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 6875005.551f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 8144017.773f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 4699521.511f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 7006177.921f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 3391713.433f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 5925739.967f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 3208504.392f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "US",
                            distance: 4122543.913f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 5495804.961f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 7167710.823f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "LV",
                    name: "Latvia",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 3usize,
                    internet_exchanges_number: 8usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8102697.811f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3618264.117f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1410865.675f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 1361140.219f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 2956650.891f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 4043411.842f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 1171401.598f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3670258.888f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 5774124.443f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 271106.591f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4237250.753f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3546324.937f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1693780.423f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 1783104.112f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 4169884.704f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 7761318.536f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 4890795.429f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 8420078.472f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4641095.57f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1501184.354f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1959236.946f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 9306056.347f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 3146795.54f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1955186.992f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1826760.203f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 53542.587f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 2844168.812f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 8247767.787f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 7458772.123f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 3896478.593f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 1810501.009f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 7384010.297f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 10404279.401f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2563094.884f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3271578.208f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 3946517.768f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 7987676.992f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4033130.236f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 390178.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 273211.816f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 6175128.665f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 1510903.356f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1848506.327f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 1418604.119f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 5406066.938f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1589252.95f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 2452914.285f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 6977978.884f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 432584.243f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 1010332.203f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1398227.175f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 7408807.925f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 1094444.229f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 9175706.393f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2097285.996f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7534596.942f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1413621.214f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2097999.769f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 1435858.032f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 627685.506f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3184598.079f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2630880.099f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1022326.781f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 2932986.295f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2721219.331f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 965921.22f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3499709.886f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 2011337.823f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 8375516.578f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 881169.884f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 7171166.874f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1497139.586f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 7247187.752f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 760097.295f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 5681359.457f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4381027.345f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 9409249.919f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 7419242.69f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1372266.165f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 1161189.767f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 6661139.024f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 7784809.397f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 1402609.943f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 9639705.256f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 1407578.175f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 5113898.607f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 6058605.433f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 1912524.388f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "KM",
                    name: "Comoros",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 8usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 14916923.082f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 1545569.024f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 936774.126f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 3375808.675f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 2395670.477f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 5104298.963f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 5610414.738f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 7222187.716f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 3270033.52f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 3174173.076f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 6353363.581f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 3306071.366f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 4298284.499f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 1026276.136f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 5334640.704f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 1296633.689f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 6686628.863f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 7072078.946f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 1840433.553f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 6811026.251f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 3544142.466f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 11077947.637f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 7352540.135f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 6772669.043f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 7344787.233f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 2555694.292f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 6448224.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 2257756.914f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 4098771.52f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 695843.443f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 2588007.936f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 1940896.848f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 242992.293f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 4775627.85f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 2065399.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 1601422.096f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 4129545.256f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 5614050.86f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 1829212.7f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 9200157.281f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 1515803.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 8051789.073f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 1863623.378f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 4991298.961f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 5225448.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 4862121.221f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 1831004.198f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 5670565.036f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "GP",
                    name: "Guadeloupe",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 11usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 2489576.472f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 2692606.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1654993.736f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1922444.222f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1519590.564f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 539426.726f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1791443.031f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 1809790.889f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 272934.678f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3443221.822f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1265498.784f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 1182995.995f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 5204613.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 3860994.739f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 2069413.494f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 991079.925f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SX",
                            distance: 269880.556f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 346807.682f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 2825752.757f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 405210.59f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 383027.768f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5477557.999f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 170215.955f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 90685.014f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 106544.719f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 618115.985f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 105887.515f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 228644.711f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 188220.848f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 410251.967f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 471574.233f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 253462.803f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 2390446.889f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 897129.932f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 913787.766f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "US",
                            distance: 4445811.711f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 212835.503f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 2969023.964f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "MV",
                    name: "Maldives",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 17usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 7443050.852f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3882649.895f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 8293847.053f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 7404282.269f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 5184094.977f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 3460048.101f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 7479792.084f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4273547.832f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 3021699.913f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 7870074.702f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 3501757.61f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 9777607.477f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 8827886.13f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 9201050.203f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 3320457.427f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 5336656.233f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 2614400.628f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 3552678.526f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 2722723.297f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 7025769.849f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 5989438.239f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 3399982.923f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 8787180.613f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 9081603.176f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 7522417.609f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 7419242.69f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 4588983.895f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 3120587.344f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 6684102.296f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4341562.576f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 8249983.568f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 2869131.224f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 4688890.781f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 5447271.272f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3883951.926f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 4289960.427f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 3145578.556f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 4899789.102f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3491423.574f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 7598195.519f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 7520380.604f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 13581318.901f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 7912322.208f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 7851947.617f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 7261010.242f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 12816452.029f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 6565703.225f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 9869466.135f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 14389424.489f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 7006225.099f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 8412402.953f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 8418346.943f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 758392.686f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 7147046.039f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 3466172.6f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 6399425.814f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 14414896.273f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 6880132.565f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 5361986.552f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 7803298.857f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 7333885.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 4992578.338f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 5232154.503f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 6447924.915f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 5108351.7f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 5199370.447f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 7553650.573f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 9131408.251f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 7666766.283f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 3961351.387f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 8078048.036f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 14573588.603f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 6851142.075f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 14509729.849f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 8027049.35f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 1659248.141f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 3046195.972f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 5502429.641f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 2685616.856f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 5168002.213f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 6555862.745f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 7953154.443f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 2819243.129f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 15130871.527f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 8121365.229f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 4609377.3f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 7273296.06f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 6601773.349f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 3219237.28f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 8705911.215f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "FR",
                    name: "France",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 25usize,
                    internet_exchanges_number: 60usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 10492443.133f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 6051010.452f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 4294518.811f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 646494.508f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 6287366.358f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 872101.237f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 4611187.801f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 4715977.019f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 873984.85f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 5173374.169f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 7247667.026f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1643924.681f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 5580444.428f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 4321827.118f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 3984741.306f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 10492081.247f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 5518754.215f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 1334265.749f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 245916.536f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 1864382.43f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 4615006.126f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 9660331.085f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 7313123.207f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5846335.847f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 4656416.21f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 5386546.783f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 9846479.044f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5248277.62f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1228398.101f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 2018062.638f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 10530623.838f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 1343118.447f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 7773449.5f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 4452629.993f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 4146813.178f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1037976.905f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 993826.143f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JE",
                            distance: 27708.437f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1810501.009f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 4031648.065f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 10521768.092f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GG",
                            distance: 109606.288f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 9698553.259f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 5470035.665f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "US",
                            distance: 5482689.346f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 2533483.705f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 738872.804f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2597434.881f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4732438.702f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 10327968.75f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4964890.566f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 5009710.186f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 7914244.171f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 8309287.061f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 10344050.902f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 8613917.267f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3620181.602f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 4231472.422f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 338108.174f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 8687378.38f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 3851171.567f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 6535496.238f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 4102474.514f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 4787413.121f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 8188240.836f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 3963974.848f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 11300698.404f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2700863.128f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 8490851.291f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 10279450.4f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 14760425.83f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 11703359.066f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 1364394.726f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 6017882.758f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 5286615.934f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 4348460.11f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 4654279.078f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 5173924.919f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 3470489.13f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2798099.914f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 769753.231f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3985645.133f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 4837371.892f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 9710655.572f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 2076851.552f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 2010348.628f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 5472624.713f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 377908.851f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 450598.416f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 1001055.401f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 4975790.859f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1694198.716f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 2422848.989f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 6268763.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1914289.606f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 1846500.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 672708.653f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 1214134.753f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7564929.806f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1390415.366f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 3072228.546f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 493700.029f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 1332243.778f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3330955.034f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 3018240.095f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 2179511.375f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 3169362.803f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 942761.541f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 721402.716f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 1053697.676f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1407495.889f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 6977895.986f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 1190188.346f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 8249983.568f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1756601.241f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 649781.465f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 7356905.856f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 418311.77f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1744869.2f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 3195814.858f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 7586038.269f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 504338.288f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "RS",
                    name: "Serbia",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 12usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9147373.084f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 2918920.221f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1436760.362f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 524908.568f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3484974.807f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 3345922.689f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 621359.729f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3910536.187f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 5933371.117f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1632630.389f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4240672.092f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3145664.467f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1996172.628f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 2663002.156f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 3483437.421f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8436475.71f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 4618860.882f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 8637585.112f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4071610.281f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 196481.986f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 894538.615f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 9354921.142f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 2382403.605f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 2230179.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 800327.308f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1413621.214f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 2680357.33f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 8380317.587f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8414809.152f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4243608.858f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 1390415.366f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 7525336.75f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 10594941.571f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 1490599.828f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 2602146.149f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 3447605.54f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 8553073.911f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3003053.558f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 1803694.944f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1686299.101f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 6772656.248f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 1034775.291f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1065943.391f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 389708.069f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 6175988.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 318354.835f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 3345204.444f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 7578837.951f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1167250.688f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 2165316.489f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1586202.597f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 7065203.35f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 369247.046f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 9265883.057f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 724117.823f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 8597698.833f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 1707235.582f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 923774.26f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 828815.738f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 2074768.739f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 1667623.326f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1037767.286f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 1871032.735f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 1720355.461f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 771022.718f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2782250.068f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 1014550.196f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 8694586.192f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 1419242.158f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 7740880.862f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 83531.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 8141913.028f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 1448975.12f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 5586357.147f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 3801868.262f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 9965614.633f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 6880132.565f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 390750.482f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 1119269.12f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 6806105.286f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 8587296.327f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 1249661.885f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 9950428.637f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1216521.077f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2398247.11f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4086640.671f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 6293293.523f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 1826082.668f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "DZ",
                    name: "Algeria",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 9usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 8137268.373f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 4955294.223f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 5783571.346f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 5085383.613f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 7241173.19f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 3402248.01f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 3573396.297f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 3292621.759f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 4798552.683f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 3759090.442f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5719765.193f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 3691021.84f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 6685835.349f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 4044747.821f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 10441346.641f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 6676580.738f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 5930001.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 7755146.613f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 3579809.351f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 3398044.656f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 512354.63f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 9770960.904f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 738872.804f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 5166103.216f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2333451.72f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 2119124.615f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 423328.774f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 191882.262f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 7592052.475f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 7957968.872f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 8105780.298f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4757307.002f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3475750.665f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 10252215.78f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 4718091.63f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4597712.701f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 3655828.873f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 5048005.868f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 3233965.357f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 3501421.563f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 2839997.781f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 7730624.228f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 7769825.906f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 3737262.051f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 6811026.251f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 3340579.47f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 7552537.892f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 8369133.969f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 3913316.436f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 1393828.675f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 8519057.611f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 2631447.438f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 6680929.845f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 3603171.91f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 6986307.609f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 5066670.881f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 3368795.161f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 3479862.628f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 5879584.389f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 7388393.87f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 4996213.941f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 2751561.459f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "TZ",
                    name: "Tanzania",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 4usize,
                    internet_exchanges_number: 6usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 13973362.753f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 1194163.493f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 311227.425f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 2732589.418f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 2501411.459f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 4258456.326f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 4990959.86f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 6366893.886f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 2976086.034f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 7117736.601f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 7658164.021f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 1806217.702f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 5545573.058f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 3107205.011f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 3501800.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 3122204.656f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 1142706.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 4855675.538f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 1251541.944f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 5864393.066f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 6227921.843f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 6455712.815f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 6535496.238f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 961236.468f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 5879584.389f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 2948385.31f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3147329.75f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 3403727.362f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 6694478.159f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 5942318.715f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 6456778.526f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 2819002.676f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 5534430.372f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 2583653.41f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 3245062.778f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 695843.443f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 4241525.119f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 2376722.895f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 2543009.314f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 3303522.182f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 4715761.71f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 2756152.34f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 8256488.677f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 1518145.221f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 7195916.242f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 6556170.663f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 1130295.276f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 946070.898f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 4138456.544f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 4674200.358f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 4591308.013f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 4058692.037f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 2092428.437f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 2243915.003f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 888212.867f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 4781262.709f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "AI",
                    name: "Anguilla",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 1usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 2405182.353f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 2542108.888f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1480730.518f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1815984.45f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1317836.072f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 417028.629f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1547988.01f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 1575801.532f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 107856.077f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 678064.661f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 518144.549f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 850994.912f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 597678.091f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 451913.03f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 272934.678f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 703609.998f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 375477.552f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SX",
                            distance: 20795.997f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 181542.672f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 164042.905f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3252532.269f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1029081.577f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 994762.005f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 4942646.432f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 3653928.039f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 1881700.046f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 974775.469f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 2654171.215f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 193083.245f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5280355.138f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 2271543.542f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 1373014.182f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 695339.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 924226.535f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "US",
                            distance: 4184305.113f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 74954.046f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 41705.458f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 2818398.4f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "DK",
                    name: "Denmark",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 38usize,
                    internet_exchanges_number: 16usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8736600.688f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 4128949.9f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 710313.825f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 1119997.057f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3716408.815f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 4562079.372f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 916068.041f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4415563.491f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 6521402.338f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 95022.007f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4954891.609f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2814950.703f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 625514.608f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 1140948.374f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 4694829.814f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8499314.538f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5557381.719f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 9177074.527f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5215997.848f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1434653.775f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 2243530.734f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 10051613.598f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 2523933.718f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1173747.429f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1488708.676f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 760097.295f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 3505488.834f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 8998892.874f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8132025.563f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4651812.858f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 1190188.346f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 8134051.747f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 11162154.669f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2870414.577f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3786652.589f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 4535777.02f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 8738160.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4390547.722f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 918242.55f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 877400.15f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 5554650.639f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 997293.265f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1378598.403f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 1246373.09f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 4853398.796f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1730370.801f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 1800834.973f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 6363625.309f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1069497.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 121314.278f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 261913.167f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 8074954.252f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 1081441.961f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 9925025.296f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2168918.888f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7167975.506f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1448975.12f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2665066.451f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 973047.553f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 109429.778f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3482646.929f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2998206.16f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1583287.964f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 3255530.739f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 3072099.218f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 700283.376f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2846102.267f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 1614152.376f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 9135491.969f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 139955.237f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 6546648.637f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1521892.85f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 6770078.563f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 45122.594f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 5987314.18f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 6392382.544f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4949235.339f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 10157337.702f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 8027049.35f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1607129.375f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 7409723.029f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 7261203.389f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 775472.674f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 10399800.741f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 811136.758f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2152197.298f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 5481878.969f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 6812844.776f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 1180610.669f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "JP",
                    name: "Japan",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 50usize,
                    internet_exchanges_number: 71usize,
                    links: vec![
                        LinkTo {
                            code: "EG",
                            distance: 9612467.426f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 9342297.515f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 11261785.195f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 7858698.659f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 1001536.955f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 9542418.707f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 2870993.778f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 6721222.796f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 10167729.227f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 5207797.309f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 9946211.755f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 5133469.819f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 7793835.748f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 8827044.241f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 2446190.664f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 3023791.234f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 4258602.418f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 5299719.531f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 2482982.972f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 776024.969f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 4241297.335f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 9471731.922f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 2309108.231f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 8902934.561f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 6028248.901f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 9065338.863f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 5493210.871f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 6887878.396f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 9854471.671f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 10492443.133f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 6588158.189f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 3483920.712f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 11535098.222f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 11561383.886f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 8822755.356f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 8147177.816f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 9373141.275f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 5828956.544f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 8104708.653f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 9221812.835f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 5854213.072f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 4944934.662f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 8276261.446f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 6116763.255f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 8787313.349f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 8062954.099f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 4206588.589f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 9324846.18f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 11245643.118f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 9659842.215f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 8102697.811f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 7190054.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 5451666.618f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 8115679.208f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 7568581.459f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 2620841.993f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 7828388.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 7892713.925f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 10841077.772f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 9612877.608f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 9934099.138f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 9368969.251f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 9935353.751f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 9075823.553f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 8871253.612f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 11096739.09f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 8097835.31f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 8256192.079f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 9369415.788f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 9008948.161f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 8910835.674f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 9147373.084f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 7920147.177f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 9532696.744f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 8662174.473f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 8776153.068f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 8113581.323f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 9020305.267f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 8858600.513f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 9047958.534f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 10049844.733f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 8876552.524f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 11288536.946f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 9208930.732f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 9814948.984f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 8736600.688f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 7443050.852f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 8826185.812f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 9255026.867f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 4705954.254f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 10410171.32f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 9486523.27f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 8200837.518f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 9300215.528f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 4560506.005f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 9887342.244f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "KE",
                    name: "Kenya",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 8usize,
                    internet_exchanges_number: 5usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 13901718.84f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 2003372.766f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 1781914.586f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 311227.425f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 2839804.803f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 2551441.922f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 2891740.621f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 4451123.27f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 3763776.691f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 4964049.468f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 4555261.588f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 6320267.232f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 7408166.787f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 6915391.792f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 6628625.265f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 6197461.8f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 4189861.859f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 3393767.682f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 1486167.32f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 6287366.358f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 3033496.613f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 2645456.77f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 2838497.825f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 936774.126f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 3709599.544f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 1144953.998f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 4063664.373f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 1749858.693f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 4381891.06f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 5783571.346f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 5533613.653f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 1971715.103f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 2944971.095f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 2803113.774f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 4358003.477f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 6449964.357f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 5663534.452f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 3400187.75f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 3638767.603f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 1430099.409f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 5097757.204f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 5972150.318f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 6319621.414f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 1097029.735f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 6044518.14f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 6511798.989f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 3113803.031f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 3346341.011f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 2665098.864f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 2600195.919f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 3424078.875f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 4569139.233f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 2782528.118f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 8208940.974f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 1819392.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 7275914.213f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 1033032.364f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 4233531.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 859538.625f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 4841268.4f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "BM",
                    name: "Bermuda",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 4usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 3160441.705f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 2906043.81f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1999981.277f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 2584589.769f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1735551.803f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 1812592.201f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1419127.095f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "US",
                            distance: 1183635.879f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 2588312.389f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 4869267.029f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 2424792.738f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 1545422.401f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 1575801.532f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 1779547.004f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1370121.946f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 1696942.837f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 3791666.692f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 3395740.883f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 2154984.178f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 2266209.554f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 2172908.823f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 2850370.34f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 1585113.201f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 3755001.97f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 1809790.889f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 2875882.219f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 1329046.421f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 1565009.43f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 1923353.404f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 2282366.563f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 2427112.201f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 2201459.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 2069535.67f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 2267018.926f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 1649530.059f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 1681145.319f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 2001507.5f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 1613485.718f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 3132347.092f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 1715364.536f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "PL",
                    name: "Poland",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 42usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8662174.473f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3417864.934f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1067111.224f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 739261.52f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3284058.842f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 3851390.676f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 562781.616f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3888936.25f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 5985999.154f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 179235.545f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4363266.62f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3149518.792f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1522285.711f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 1956085.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 3984930.888f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8193397.675f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 4904810.314f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 8675954.057f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4516825.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 886965.654f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1539645.751f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 9496668.859f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 2622113.325f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1788004.283f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1210094.577f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 627685.506f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 2863274.711f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 8467170.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 7988389.906f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4164806.986f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 1332243.778f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 7601320.315f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 10660877.237f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2166437.249f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3077110.564f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 3843791.835f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 8379562.68f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3682523.387f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 1006501.017f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 896575.838f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 6252338.523f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 981517.342f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1272522.209f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 790923.533f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 5567092.09f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1063319.547f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 2650515.628f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 7062123.727f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 584791.003f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 1357953.474f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1135168.954f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 7413884.882f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 479119.914f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 9383042.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1545306.899f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7868353.658f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 828815.738f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 1977968.786f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 885144.911f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 109429.778f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 2783770.276f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2285437.768f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 929329.908f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 2550416.834f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2361580.219f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 395838.389f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2995565.203f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 1404361.833f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 8672630.28f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 745908.42f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 7241052.508f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 910921.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 7485371.197f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 5782758.466f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4248729.731f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 9804886.797f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 7333885.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 904928.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 735105.545f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 6874611.867f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 7976173.938f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 975537.903f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 9940743.548f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 471359.987f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 1891147.303f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4773929.579f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 6304780.537f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 1571954.36f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "PA",
                    name: "Panama",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 13usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 365123.035f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 1138739.622f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 596391.544f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 1498038.217f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 477108.402f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 1921463.003f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 1105286.026f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 4807748.049f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 5643599.615f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PE",
                            distance: 2428518.85f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 1416220.4f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 1878039.659f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 4795497.71f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 1108176.443f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 1236437.417f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 1277428.245f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 522826.054f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1723414.712f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 1787230.2f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1603152.722f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 1508332.59f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 1222083.228f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 1145785.552f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 4838520.683f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 1927532.143f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 853687.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 2584589.769f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 1815984.45f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 4319165.585f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 945800.835f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 1944357.467f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 6146147.354f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 1922444.222f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 1307240.805f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 1934739.461f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 1120269.227f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 1954106.468f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 2123030.013f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 1969415.094f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 1902071.163f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 1791294.104f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 1824853.366f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 1960281.585f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 1827889.153f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 1912030.639f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "NU",
                    name: "Niue",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "PW",
                            distance: 8850091.938f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 7555335.168f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 6587941.589f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 8894474.785f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 609167.799f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1944427.825f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 1066845.263f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 2176337.853f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 5807291.089f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 6766701.919f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 12616953.47f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 5382243.144f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 6237407.75f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 6109092.147f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 6885641.231f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 7416467.799f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 7480187.475f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 10441826.023f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 4452732.989f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 7572702.447f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 6143270.434f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 5528534.081f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 8451689.815f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "BE",
                    name: "Belgium",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 5usize,
                    internet_exchanges_number: 17usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9854471.671f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 4336823.702f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 3137469.269f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 11505972.07f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 10654881.106f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2425042.446f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 9019376.701f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 7991319.756f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 9645657.439f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 5706481.604f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 9845899.689f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 5339607.114f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 9072375.61f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 585672.749f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4553280.104f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 6095972.929f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 2557954.577f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1690997.235f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 10565612.304f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 8508647.122f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5617399.636f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 646494.508f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 14266083.977f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 8792522.06f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 9928954.95f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 1703892.227f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 10635401.759f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 11073139.641f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 1863761.311f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2987340.777f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 216419.667f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 935744.083f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 4320087.227f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 4767703.745f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 819136.313f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4953802.42f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 7052745.492f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1170641.959f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 5426813.86f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 1411540.965f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 4904576.747f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 9739848.671f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1328460.123f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 1820225.646f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 793950.446f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1410865.675f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 3911402.081f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 5222001.27f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 4009749.868f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 4825778.791f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 9389710.157f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 1624679.803f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1573764.599f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 5336726.773f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 511564.19f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 845876.298f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 1089265.797f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 4751136.395f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1754969.686f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 2027488.749f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 6143709.593f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1606233.742f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 1330115.64f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 1146834.521f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7250869.666f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1436760.362f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2990336.436f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 574359.502f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 1067111.224f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3495079.744f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 3103486.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1989159.725f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 3302972.584f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 3157091.37f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 751615.242f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2136080.654f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 1123602.304f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 570358.611f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 6308257.47f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1481835.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 6732678.741f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 710313.825f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 8293847.053f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1738147.751f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 347302.381f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 7941503.046f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 7158303.399f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 207202.545f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1391821.934f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2818174.294f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 5502877.989f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 7368616.803f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 511870.77f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "SE",
                    name: "Sweden",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 24usize,
                    internet_exchanges_number: 45usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8276261.446f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 4050897.776f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1170641.959f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 1429514.019f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3347496.444f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 4478665.322f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 1221305.789f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4093108.977f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 6191852.57f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 95022.007f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 271106.591f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 233168.261f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 344258.892f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 179235.545f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 248183.512f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4677763.926f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3260498.651f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1328987.724f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 1331527.425f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 4606696.455f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8066223.681f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5341720.45f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 8817134.715f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5087382.889f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1670846.649f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 2306223.263f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 9723079.363f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 2982042.753f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1577567.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1853416.634f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 3295866.274f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 8657878.853f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 7674381.266f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4303158.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 1643924.681f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 7796497.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 10796746.476f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2925875.547f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3704433.381f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 4394197.427f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 8319096.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4421928.538f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 5723355.964f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 1418410.223f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1792117.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 1528050.146f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 4958113.306f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1865558.206f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 2004760.825f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 6526276.096f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 869829.463f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 584404.077f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1105874.434f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 7859213.58f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 1272310.87f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 9587917.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2351277.236f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7129586.935f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1632630.389f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2538591.452f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 1374534.177f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3548107.691f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 3016469.506f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1452610.897f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 3304244.45f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 3101524.17f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 992496.642f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3306399.121f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 2004872.73f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 8755872.011f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 600291.465f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 6719396.376f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1713779.198f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 6813186.256f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 6123225.666f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4826096.664f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 9733769.096f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 7870074.702f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1685542.464f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 1018680.838f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 7076324.751f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 7342391.637f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 1226309.282f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 10015153.748f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 1740757.795f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 5509165.148f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 6464815.591f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 1632024.786f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "DE",
                    name: "Germany",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 7usize,
                    internet_exchanges_number: 183usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9255026.867f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3999303.289f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 347302.381f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 652856.961f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 4011459.109f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 4431116.553f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 498484.002f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4623440.435f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 6718474.071f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1018680.838f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 5084829.348f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2424847.13f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1090963.603f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 1213074.711f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 4567654.818f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8895814.147f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5589307.527f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 9410570.202f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5133414.022f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1033925.267f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 2002627.387f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 10223103.985f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 1990645.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1128842.951f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 926536.658f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1161189.767f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 3565363.271f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 9198840.551f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8619588.689f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4899531.355f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 649781.465f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 8333279.963f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 11395056.681f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2609315.01f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3669937.867f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 4481042.008f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 9097661.046f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4121629.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 914292.604f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1362795.933f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 5666238.971f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 406773.572f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 788340.772f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 803615.631f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 5056738.535f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1435007.175f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 1865620.607f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 6474502.907f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1296798.785f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 1328860.828f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 363414.257f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 8082636.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 808091.387f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 10112435.553f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1783815.156f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7509978.272f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1119269.12f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2643089.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 392523.386f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 735105.545f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3191502.306f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2778242.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1647573.071f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 2990295.906f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2835900.609f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 404476.878f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2338718.447f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 1031058.193f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 9407265.906f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 473331.43f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 6641984.333f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1172192.114f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 7026076.949f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 45122.594f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 6493977.235f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4863359.107f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 10522732.003f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 7953154.443f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1400022.716f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "US",
                            distance: 5906222.527f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 7606620.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 7468103.378f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 247126.244f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 10675412.084f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1105753.829f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2553516.44f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 5202990.078f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 7039505.304f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 838542.857f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "NZ",
                    name: "New Zealand",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 14usize,
                    internet_exchanges_number: 40usize,
                    links: vec![
                        LinkTo {
                            code: "PW",
                            distance: 6595505.683f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 6585914.128f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 2322329.295f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 2155952.619f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 2881682.958f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KI",
                            distance: 5169688.705f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 10491806.504f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 3355145.868f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 2266894.918f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 7007709.736f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 2837642.665f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 8894474.785f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 7446108.256f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 3236894.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 4446739.897f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 2994643.766f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 5545663.081f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 6676861.717f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 2421244.126f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 3749615.721f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 2905077.2f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 5253033.478f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 4458673.713f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 4509137.306f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "AL",
                    name: "Albania",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9887342.244f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 4744900.838f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 511870.77f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 1301635.267f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 4831917.539f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 5171082.926f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 1243282.327f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 5460867.758f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 7556968.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1632024.786f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 5920483.081f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 1635975.468f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 506736.097f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 1481814.785f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 5308696.35f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 9672933.815f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 6401934.167f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 10247780.79f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5896802.676f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1683500.39f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 2717057.061f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 11060074.824f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 1461065.9f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 554100.438f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 217104.662f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1912524.388f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 4392798.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 10037379.627f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 9303839.214f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 5732473.966f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 504338.288f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 9171821.381f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 12232831.597f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 3284257.473f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 4427354.207f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 5263721.325f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 9897741.759f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 4752295.406f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 2097055.077f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 2057513.678f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 4981274.855f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 794733.622f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 954776.389f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 184516.784f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 4471738.304f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 2140302.016f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 1972677.955f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 5780830.846f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 2117964.675f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 1665754.217f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 526306.153f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 8878234.518f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 1588187.788f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 10950550.559f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 192873.108f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 7066241.234f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1826082.668f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 3455100.775f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 902612.994f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 1571954.36f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 3820083.339f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 3482266.329f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 2484803.944f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 3649919.719f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 3525333.65f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 1229946.131f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 1724004.946f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 1221306.815f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 10238966.839f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 1044517.043f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 5934180.058f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1855438.835f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 6473567.972f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 1180610.669f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 7323388.539f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 5626874.494f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 11320548.426f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 8705911.215f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 2166295.371f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 838542.857f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 8445158.941f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 6855628.817f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 613666.503f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 11507024.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1902434.994f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 3319588.8f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 5806024.851f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 7876547.837f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "CU",
                    name: "Cuba",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 4usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 1426415.69f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 1298946.598f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 225298.782f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 853687.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "US",
                            distance: 849724.282f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 1419480.438f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 956028.415f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 522679.321f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 1735551.803f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 1317836.072f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3466238.923f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 405555.779f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 343637.884f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 3938046.724f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 2341454.917f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 572600.283f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 1020181.852f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 1699414.499f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 1359441.316f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 1153443.663f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 1133215.581f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5318225.056f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 1519590.564f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 1160745.662f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 469801.289f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 624534.849f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 1579978.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 1115573.41f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 1823488.049f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 1855432.167f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 1673640.891f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 1708979.471f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 1327504.644f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 1373657.243f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 1636059.06f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 1346156.525f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 1565739.866f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 1469404.746f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "MC",
                    name: "Monaco",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9934099.138f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3910096.679f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 845876.298f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 611726.488f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 4461541.882f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 4324957.484f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 719172.452f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4953419.448f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 6994857.95f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1792117.89f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 5305727.471f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 1500910.096f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1196018.012f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 2254063.958f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 4462457.318f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 9410038.69f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5671313.735f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 9700227.485f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5087252.874f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 880249.227f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1892423.206f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 10419337.976f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 1373560.145f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1484003.909f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 105330.052f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1848506.327f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 3745969.673f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 9445973.073f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 9258668.586f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 5272359.979f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 450598.416f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 8590189.825f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 11660511.272f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2404751.692f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 3612269.777f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 4477252.137f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 9560305.57f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3828439.85f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 2172871.145f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 2086239.395f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 5909345.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 382183.867f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 2407294.581f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 4855079.393f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 4948318.589f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 6601047.646f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 1306971.65f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 691248.474f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 5425388.96f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 1341430.647f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 2845433.626f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 6701910.05f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1846556.091f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 2109740.354f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1027465.779f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 8088499.753f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 997876.883f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 10331555.211f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1458583.717f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 8012847.384f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1065943.391f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2773174.088f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 419699.609f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 1272522.209f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 2903086.332f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 2623409.105f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1989348.798f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 2752962.321f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 2652654.328f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 887585.403f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 1764035.668f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 281638.805f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 9748514.541f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 1260015.996f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 6846637.376f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1062337.5f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 7428093.426f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 1378598.403f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 10980967.097f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 7851947.617f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 1453775.144f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 788340.772f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 7869990.785f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 7802920.362f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 661992.816f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 11008081.156f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1734285.738f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 3160933.096f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4867617.875f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 7349616.082f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 954776.389f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "TR",
                    name: "Turkey",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 7usize,
                    internet_exchanges_number: 7usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9065338.863f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 2030073.291f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 2557954.577f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 1416016.824f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3078260.88f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 2454277.812f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 1509766.886f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3312180.151f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 5226468.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 2306223.263f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 3517804.704f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 8750798.214f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3271070.369f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 3034997.755f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 3484506.86f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 2591948.994f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8218589.714f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 3901209.678f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 7908988.838f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 3245532.901f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1037227.518f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 208864.238f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 656791.743f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 2865491.099f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1169478.72f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 8406352.507f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 2962429.227f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 3182149.739f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 6118495.936f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 6305544.711f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 8433168.524f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 6790774.769f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 2018062.638f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 8622199.707f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 1704311.192f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 9339890.84f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 408882.043f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 5659410.747f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 8067098.578f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8561594.282f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 11875684.872f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 7951374.905f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 9380005.854f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 3006391.992f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 1059031.202f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 220389.951f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 147364.131f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 3080666.207f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 3122479.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1959236.946f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 1975510.112f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 3682341.587f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 1722129.21f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 2584983.288f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 7983979.12f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 2322400.625f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 2202518.213f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 7665265.048f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 1922950.488f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1892423.206f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 1271582.019f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 4176661.425f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 8472112.881f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1569687.25f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 2882892.225f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 2472271.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 1203347.331f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 9407801.752f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 894538.615f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 1032819.34f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 1814657.546f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 1539645.751f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 1244939.207f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 775634.677f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1085456.064f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 1012019.595f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 836337.408f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 1626502.442f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3477604.495f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 1759174.678f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 2243621.342f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 8635095.561f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 861737.811f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 9001077.582f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 2243530.734f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 5989438.239f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 2002627.387f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 9464451.887f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 2143921.736f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1749928.593f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2439046.569f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 5610175.59f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 2717057.061f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "IS",
                    name: "Iceland",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 5usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8871253.612f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 6041959.789f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 2027488.749f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 2913556.794f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 5089929.503f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 6472661.823f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 2744681.094f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 5931616.064f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 7970477.245f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 2004760.825f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 6587432.7f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2852454.144f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 922757.355f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 676269.358f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 6602672.058f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 9265625.148f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 7314803.329f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 10444181.986f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 7092053.027f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 3287941.053f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 4176661.425f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 11445381.031f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 3256902.352f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1402943.274f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 3109894.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 2452914.285f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 5284412.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 10357941.608f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8489983.625f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 6071652.313f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 2422848.989f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 9523257.041f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 12355025.628f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 4802463.975f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 5696635.111f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 6398868.821f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 9633168.032f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 6324117.674f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 2285013.558f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 2354041.654f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 3746660.959f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 2538959.778f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 2845433.626f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 3063326.226f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 2953392.089f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 3645426.588f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 1800834.973f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 1865620.607f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 2663509.488f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 1529872.115f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 4540568.093f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 2874141.717f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 1459093.099f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 9820525.606f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 2990279.302f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 11284341.967f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 4039773.746f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 5253732.992f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 3345204.444f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 4540985.938f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 2596074.364f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 2650515.628f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 5409327.471f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 4934438.516f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 3451251.011f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 5187836.012f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 5007728.23f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 2574288.882f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3370667.984f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 3126982.797f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 10297396.23f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 1934600.705f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 4740750.971f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 3409214.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 4835537.895f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 8028706.241f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 6830331.65f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 10963687.156f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 9869466.135f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 3541131.085f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 8828389.71f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 5343099.971f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 2233442.632f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 11498894.57f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 2610688.801f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 3450598.59f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 7414841.704f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 8183386.491f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 1972677.955f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "MQ",
                    name: "Martinique",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 4usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 2505587.791f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 2758625.541f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1748027.642f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1960281.585f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1636059.06f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 889310.344f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 684552.961f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1943256.388f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 2001507.5f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 451913.03f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3620721.418f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 1413783.723f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 1293816.695f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 5378389.285f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 3971607.048f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 2169579.399f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 984283.146f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SX",
                            distance: 440502.633f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 163929.985f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 2908356.895f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 563792.384f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 530429.03f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5656472.498f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 188220.848f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 2433500.051f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GF",
                            distance: 1401643.348f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 769735.381f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 268400.902f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 1024477.602f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 82604.157f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 891127.83f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 441077.325f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 234056.121f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 65481.011f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 3214337.033f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 299484.257f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 2352741.498f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 390244.764f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 345860.598f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 294108.013f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 410305.141f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 3033810.616f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "MW",
                    name: "Malawi",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 14546643.112f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 2705158.588f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 1430099.409f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 2530004.527f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 1426813.07f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 4448079.617f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 4896798.548f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 6543967.888f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 2507952.521f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 3369935.514f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 5609932.961f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 2279869.074f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 3585812.246f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 4349069.777f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 1338640.699f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 5959579.994f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 6375576.092f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 1514445.806f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 6676580.738f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 3945607.834f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 10478674.623f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 6686417.14f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 6057199.765f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 6736426.904f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 1688991.964f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 6406666.262f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 1854216.149f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 3489696.594f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 1026276.136f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 4164279.403f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 1235087f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 2224028.691f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 3469005.354f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 5641100.822f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 2527520.729f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 8849793.056f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 490405.797f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 7363630.978f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 1145384.757f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 1632675.989f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 4351251.343f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 4546244.433f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 5128501.849f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 1142706.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 819337.16f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 3174688.052f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 1811718.746f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 5095272.914f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "KI",
                    name: "Kiribati",
                    continent: Some("Oceania"),
                    other_names: vec![],
                    cable_connections_number: 2usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "PW",
                            distance: 5929920.787f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 4911124.053f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TO",
                            distance: 2442935.852f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NZ",
                            distance: 5169688.705f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "WS",
                            distance: 2355403.694f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NU",
                            distance: 4452732.989f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AS",
                            distance: 1779566.648f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FJ",
                            distance: 3287369.522f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 5413813.798f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CX",
                            distance: 9175173.675f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CK",
                            distance: 2767008.564f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TK",
                            distance: 2012076.008f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NR",
                            distance: 679118.869f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NC",
                            distance: 1726599.956f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FM",
                            distance: 1699926.861f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MP",
                            distance: 4861831.705f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VU",
                            distance: 3030769.46f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 6675281.478f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SB",
                            distance: 3422862.529f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "WF",
                            distance: 1801793.273f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MH",
                            distance: 2168432.456f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PF",
                            distance: 3391713.433f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PG",
                            distance: 4571888.942f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "UA",
                    name: "Ukraine",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 1usize,
                    internet_exchanges_number: 26usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8113581.323f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 2598672.657f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1989159.725f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 1377623.118f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 2474755.293f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 3026055.068f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 1309900.502f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 2994095.646f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 5077159.242f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1452610.897f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 3437694.34f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 4009740.325f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 2449018.281f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 2766338.6f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 3154215.753f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 7428334.754f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 3981848.62f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 7776453.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 3645964.863f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 1223704.773f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1085456.064f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 8575576.646f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 3358681.253f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 2715694.634f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 1793921.104f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1022326.781f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 1935481.743f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 7554985.416f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 7377079.163f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 3293997.002f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 2179511.375f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 6690176.027f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 9757171.573f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 1620996.022f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 2252097.259f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 2958919.135f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 7570957.116f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3033947.087f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 1323660.49f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1211938.641f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 7133613.065f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 1803786.668f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 1989348.798f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 1319690.261f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 6401505.652f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 985892.081f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 3451251.011f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 7941502.942f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 589764.279f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 2029277.43f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 2064445.094f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 6495985.119f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 992125.293f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 8465980.653f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 1453202.57f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 8553692.99f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 1037767.286f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 1091040.604f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 1690738.242f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 929329.908f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 2227866.745f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 1646861.926f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 24083.648f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 1967391.504f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 1744220.711f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 1258440.041f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3752305.617f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 2012794.8f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 7792953.825f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 1647492.541f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 8127140.72f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 1095915.854f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 8265292.08f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 1583287.964f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 4853636.801f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 3381943.289f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 8991921.8f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 6447924.915f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 724099.108f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 1647573.071f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 5963869.382f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 8793196.316f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 1874943.291f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 9059131.663f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 842928.623f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4105472.542f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 5408299.897f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 2484803.944f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "SA",
                    name: "Saudi Arabia",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 17usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9542418.707f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 2570220.174f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 407875.096f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 4553280.104f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 2839804.803f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 3492815.879f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3690247.607f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 44351.533f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 3623153.563f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 3321852.965f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 4461498.665f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 4421928.538f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 3002704.45f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 4959339.464f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 8290461.365f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 4350608.906f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 4729023.153f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 5027513.301f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 5631969.593f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 149108.618f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 7626703.653f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 2922769.21f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 6934808.573f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 2082113.539f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 3099776.451f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1704311.192f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 7472588.636f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 4588559.985f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 4512725.433f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 5213924.803f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 3085303.536f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 4033130.236f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 2196137.546f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 6730757.545f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8614151.234f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 3712392.936f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 3620181.602f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 5881419.104f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 7236568.357f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 1616264.246f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 3475750.665f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 436780.132f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 503768.236f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 304783.024f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 7421973.432f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 1421120.181f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 988157.981f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 4575167.86f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 1796265.137f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 3517840.032f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 6812194.546f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 1162991.698f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 1488544.828f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 5301263.807f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 4955139.917f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 3147329.75f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 5323990.759f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 5663993.982f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 4579498.89f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 5884562.231f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 4185967.334f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 4056827.282f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 8628547.128f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2146657.455f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 7237201.777f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 10082889.556f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 8329242.925f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 4583375.142f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 1477109.031f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 3828439.85f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 2855614.752f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 3491423.574f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 3318067.115f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 4357220.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 4243981.684f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 9733027.12f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 3970526.446f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 3339654.253f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 9177555.853f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 2690772.971f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 6324117.674f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 10529501.606f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 3609611.645f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 5005354.171f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 4585729.715f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 3341628.866f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 11547591.057f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 3003053.558f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2124704.935f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 3875384.802f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 3682523.387f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 1405466.448f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 3033947.087f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 1136750.187f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 3763725.51f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 3609291.924f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 4390449.436f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 10675506.436f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 2949974.286f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 11143224.648f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 4390547.722f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 2783532.248f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 4121629.93f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 11586413.512f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 4230833.46f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 3832903.842f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 4007343.132f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 4889672.618f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 4752295.406f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "FO",
                    name: "Faroe Islands",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 3usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8787313.349f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 5351365.263f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1411540.965f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 2251121.249f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 4542890.364f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 5782787.513f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 2072969.988f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 5350504.482f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 7422765.484f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1331527.425f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 5975545.761f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2715130.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 412770.048f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 1140948.374f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 1213074.711f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 676269.358f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 5913499.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8960112.939f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 6668303.151f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 9971883.849f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 6411341.296f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 2615872.874f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 3484506.86f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 10934056.651f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 2896313.3f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 1000652.023f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 2489785.914f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1783104.112f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 4626099.09f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 9853096.831f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8321504.491f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 5520549.331f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 1864382.43f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 9003645.926f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 11921726.717f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 4110873.738f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 5006563.384f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 5720916.606f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 9285560.017f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 5631969.593f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 1659658.309f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1713428.062f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 4392904.805f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 1917594.318f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 2254063.958f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 2397695.77f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 3635266.999f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 2958860.742f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 5194947.409f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 2195871.075f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 831047.684f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1228066.886f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 9183012.5f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 2303972.518f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 10784383.749f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 3366495.318f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 5935394.214f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 2663002.156f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 3857269.593f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 1960527.99f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 1956085.398f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 4720037.919f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 4240456.787f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 2766338.6f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 4496189.841f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 4314354.493f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 1892473.798f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 3085436.583f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 2533849.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 9861037.322f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 1246146.031f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 5388978.546f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 2729457.043f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 5529965.407f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 7421395.613f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 6148063.08f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 10659112.86f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 9201050.203f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 2848494.109f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 8295237.745f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 6033047.493f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 1610238.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 11093342.926f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1929908.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2893949.044f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 6723066.407f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 7662553.786f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 1481814.785f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "JM",
                    name: "Jamaica",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 13usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 1161354.437f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 1075183.722f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "US",
                            distance: 998104.063f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 849837.353f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 696880.264f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 1281157.444f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 389436.874f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 440044.314f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 1399233.577f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 225298.782f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 596391.544f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 1171466.026f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 722128.402f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 1999981.277f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 1480730.518f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3723662.397f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 662445.645f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 3999224.438f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 2232267.438f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 990416.908f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 1786821.41f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 1173833.904f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 1289350.488f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5556403.754f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 1654993.736f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 900272.166f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 711243.001f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 1700764.385f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 1099057.804f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 1876702.21f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 1953499.914f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 1777102.893f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 1779696.914f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 1478886.957f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 1521897.134f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 1748027.642f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 1504121.804f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 1348504.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 1616981.962f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "QA",
                    name: "Qatar",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 7usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8062954.099f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 547274.385f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 4904576.747f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 4007158.369f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 2966528.256f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 111562.253f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 4087442.475f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 2401975.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 3351731.555f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 4606696.455f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 1951638.739f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 6444876.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 5447559.28f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 5913499.006f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 565895.158f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 149108.618f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 710229.556f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 386276.754f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 492801.789f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 2314700.703f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 1012432.853f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 3637514.922f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 3320457.427f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 1598069.966f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 1938925.196f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 3639022.452f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 6336287.907f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 2859662.824f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 1759316.145f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 1561575.765f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 5667684.703f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 4615006.126f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 4526496.428f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 5551630.432f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 5697669.899f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 6067809.869f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 3628374.677f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 2591948.994f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 6196294.336f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 5493208.456f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 5696118.019f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 4169884.704f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 1628220.388f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 7184265.397f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 2763860.276f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 7524558.397f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2064388.954f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 6312188.306f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 4420899.375f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 4323578.299f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 10227687.94f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 4514872.409f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 4462457.318f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 3863529.245f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 9545959.91f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 3168395.787f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 6602672.058f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 11037326.855f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 3739372.147f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 5180135.935f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 5035898.408f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 3759643.654f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 11642569.943f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 3483437.421f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 2073086.711f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 4406107.109f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 3984930.888f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 1699600.625f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 1839051.6f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 3154215.753f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 1754749.212f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 1814309.843f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 4172820.624f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 5864942.405f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 4290531.908f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 4730033.803f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 11208624.742f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 3453670.353f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 11416979.434f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 4694829.814f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 7518484.65f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 3167649.109f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 4567654.818f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 4029426.579f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 11945771.96f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 4727869.896f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 7088487.005f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 3997107.341f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 3733179.564f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 3779917.632f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 5308696.35f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "TW",
                    name: "Taiwan",
                    continent: Some("China"),
                    other_names: vec![],
                    cable_connections_number: 17usize,
                    internet_exchanges_number: 5usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 2482982.972f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 9845899.689f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 944304.082f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 1649155.707f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 2937980.785f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 664763.028f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 3066381.991f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 8819315.206f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 3496397.607f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 9159647.559f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 4915973.809f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 1476975.833f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 8251724.88f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 6495338.625f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 10377136.125f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 8290461.365f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 5439046.548f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 8750798.214f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 9982218.606f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 4692921.884f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 6305848.891f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 10492081.247f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 6048716.153f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 2700951.001f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 2811034.877f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 11474808.083f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 2023997.112f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 11439512.529f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 8464401.053f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 9747026.253f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 10898205.449f64,
                            link_type: LinkType::Submarine,
                        }
                    ],
                },
                Country {
                    code: "VN",
                    name: "Vietnam",
                    continent: Some("Eurasia"),
                    other_names: vec![],
                    cable_connections_number: 7usize,
                    internet_exchanges_number: 3usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 2309108.231f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 6340776.265f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 9645657.439f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 9146634.79f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 5419281.035f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 6073460.774f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 9101651.017f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4800287.134f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 2779577.308f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 8755872.011f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4488294.604f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 1476975.833f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 11118645.089f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 10219141.108f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 9861037.322f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 6067809.869f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 2185192.028f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 4384110.373f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 391925.326f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 5233293.098f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BA",
                            distance: 8888892.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 8067098.578f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 1710919.898f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 11065875.138f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GU",
                            distance: 4116100.93f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 10327507.314f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 9405618.621f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 8375516.578f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 6037988.402f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 1374292.587f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 2917878.071f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4507831.112f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 10279450.4f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 1338511.451f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 2471088.549f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 7715700.266f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 6503868.208f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 5664402.108f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 1166469.653f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 12884034.985f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 7237201.777f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 8310649.241f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 8304267.02f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 13544161.225f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 9596606.632f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 9748514.541f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 9057463.837f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 12542116.284f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 8461812.099f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 10297396.23f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 14088997.681f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 8122137.01f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 9066877.2f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 9755865.596f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 3250351.331f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 8772075.033f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 5399732.921f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 1602518.884f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 8465862.346f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 12405265.789f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 8694586.192f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 7009874.957f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 9483045.651f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 10981144.861f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 8672630.28f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 7595289.183f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 7482982.397f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 7792953.825f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 7561016.241f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 7514916.704f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 9041203.276f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 11466372.83f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 9702477.908f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 8002393.939f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 1403680.253f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 3523124.938f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 7016411.591f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 5461680.87f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 1435437.814f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 10062962.896f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 6748923.452f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 9252045.987f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 14313235.739f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 8714079.04f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 13141362.956f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 9135491.969f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 3961351.387f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 8303853.641f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 9407265.906f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 1958851.9f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 13813137.833f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 9647694.185f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 8348890.666f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 7021972.687f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 2402168.842f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 10238966.839f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "DJ",
                    name: "Djibouti",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 11usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 8902934.561f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NE",
                            distance: 12797605.637f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 659221.481f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 5706481.604f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 1781914.586f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 4000646.756f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 4508629.835f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 4642123.232f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 5228774.454f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 6477168.416f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TW",
                            distance: 8251724.88f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 3924892.167f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 5976667.638f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 6125069.309f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 1759316.145f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8230759.835f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 2258312.255f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 2915256.668f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LR",
                            distance: 5946925.568f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 4923612.036f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 4210452.591f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 6573870.43f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 2110213.085f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 3182149.739f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 6765593.584f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 3174688.052f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 5562955.817f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 6185008.903f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 3056976.83f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 6174722.789f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 6405486.422f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 4017205.04f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 6264536.746f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8864890.794f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 5009710.186f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 2257301.906f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 5538915.714f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 6519030.3f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 2793735.259f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 4718091.63f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 1093893.705f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 1488544.828f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 3922165.446f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 4948318.589f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 6552054.855f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 6209578.949f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 6372018.88f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 4849332.086f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 4374183.114f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 4151780.724f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 4671470.11f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 3763521.164f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 2588007.936f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AU",
                            distance: 9108344.1f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 4396059.703f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 4409466.421f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 6588551.796f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 3283911.443f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 3856640.769f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 3933831.213f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 3864288.835f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 3912134.901f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 5545538.949f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 3534979.542f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 7238544.694f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 5175483.401f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 7016411.591f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 2721965.815f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 2085517.541f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 4505272.926f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 3289457.572f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 2046770.978f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 8417496.149f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 4808092.43f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 5108729.128f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 2572084.213f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 2092428.437f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 7911485.489f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 4330537.111f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 244903.157f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 1712734.046f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 4853489.389f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "BA",
                    name: "Bosnia and Herzegovina",
                    continent: Some("Eurasia"),
                    other_names: vec!["Bosnia-Herzegovina"],
                    cable_connections_number: 0usize,
                    internet_exchanges_number: 1usize,
                    links: vec![
                        LinkTo {
                            code: "JP",
                            distance: 9324846.18f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KW",
                            distance: 3067286.243f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BE",
                            distance: 1328460.123f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SI",
                            distance: 393127.377f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KZ",
                            distance: 3679027.978f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BH",
                            distance: 3490655.858f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AT",
                            distance: 543424.311f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UZ",
                            distance: 4106546.583f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NP",
                            distance: 6125828.608f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SE",
                            distance: 1670846.649f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AF",
                            distance: 4430948.236f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 2958866.319f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UK",
                            distance: 1892922.868f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FO",
                            distance: 2615872.874f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "QA",
                            distance: 3628374.677f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CN",
                            distance: 8631446.097f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PK",
                            distance: 4794320.021f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KH",
                            distance: 8829283.429f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "OM",
                            distance: 4225270.524f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TR",
                            distance: 1037227.518f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SG",
                            distance: 9539162.827f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GI",
                            distance: 2186201.88f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IE",
                            distance: 2115588.918f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IT",
                            distance: 604751.146f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LV",
                            distance: 1501184.354f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TM",
                            distance: 2870047.946f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TH",
                            distance: 8569314.718f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KR",
                            distance: 8598343.688f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KG",
                            distance: 4440079.06f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 1228398.101f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MM",
                            distance: 7715539.236f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ID",
                            distance: 10783993.595f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CY",
                            distance: 1605111.276f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IQ",
                            distance: 2757255.945f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IR",
                            distance: 3611710.851f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HK",
                            distance: 8749424.305f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SA",
                            distance: 3099776.451f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "FI",
                            distance: 1887958.997f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EE",
                            distance: 1774062.056f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ME",
                            distance: 6651303.746f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CH",
                            distance: 888812.386f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MC",
                            distance: 880249.227f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HR",
                            distance: 240685.615f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IL",
                            distance: 6079305.546f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BG",
                            distance: 466963.648f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IS",
                            distance: 3287941.053f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MD",
                            distance: 7455105.472f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BY",
                            distance: 1299872.37f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NO",
                            distance: 2175540.32f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NL",
                            distance: 1489301.764f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LK",
                            distance: 7228308.393f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HU",
                            distance: 408352.94f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MY",
                            distance: 9452157.55f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GR",
                            distance: 751833.976f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AZ",
                            distance: 8540795.852f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RS",
                            distance: 196481.986f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GE",
                            distance: 1895522.665f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LI",
                            distance: 784280.856f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PL",
                            distance: 886965.654f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JO",
                            distance: 2166620.275f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SY",
                            distance: 1798768.597f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UA",
                            distance: 1223704.773f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PS",
                            distance: 1977967.606f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LB",
                            distance: 1843277.025f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CZ",
                            distance: 735849.148f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2586165.651f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MT",
                            distance: 818203.521f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VN",
                            distance: 8888892.708f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SK",
                            distance: 1386337.056f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VA",
                            distance: 7613013.73f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MK",
                            distance: 182470.485f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MN",
                            distance: 8056594.828f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DK",
                            distance: 1434653.775f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "IN",
                            distance: 5769361.32f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AE",
                            distance: 3956169.85f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PH",
                            distance: 10162092.424f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MV",
                            distance: 7025769.849f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RO",
                            distance: 585581.745f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DE",
                            distance: 1033925.267f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BD",
                            distance: 6997186.4f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MO",
                            distance: 8486689.45f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LU",
                            distance: 1131642.384f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BN",
                            distance: 10143830.963f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LT",
                            distance: 1315187.526f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RU",
                            distance: 2561815.796f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YE",
                            distance: 4175203.196f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BT",
                            distance: 6487298.485f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AL",
                            distance: 1683500.39f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "LR",
                    name: "Liberia",
                    continent: Some("Africa"),
                    other_names: vec![],
                    cable_connections_number: 1usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "NE",
                            distance: 9140691.258f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SO",
                            distance: 6306027.785f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KE",
                            distance: 5663534.452f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AO",
                            distance: 3100928.99f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BW",
                            distance: 5274889.991f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TG",
                            distance: 1328795.021f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CI",
                            distance: 756841.097f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GM",
                            distance: 1016881.304f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CG",
                            distance: 3107136.534f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PT",
                            distance: 3604630.859f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SC",
                            distance: 4822676.65f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GH",
                            distance: 1174800.837f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GQ",
                            distance: 2333163.747f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GN",
                            distance: 479728.808f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BJ",
                            distance: 1462903.162f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SN",
                            distance: 1182354.83f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ZA",
                            distance: 5409320.099f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SL",
                            distance: 362604.744f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ES",
                            distance: 2493501.329f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CM",
                            distance: 2325035.255f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NG",
                            distance: 1571501.067f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GA",
                            distance: 2340975.517f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MR",
                            distance: 1425727.167f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 4656416.21f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "ST",
                            distance: 2055162.228f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GW",
                            distance: 819147.707f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "NA",
                            distance: 4239340.766f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MW",
                            distance: 5609932.961f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SH",
                            distance: 2533249.169f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MG",
                            distance: 6948429.294f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BI",
                            distance: 4585866.952f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DZ",
                            distance: 3691021.84f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SD",
                            distance: 5388647.218f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LS",
                            distance: 5692281.483f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TN",
                            distance: 4046917.281f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KM",
                            distance: 6353363.581f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "SZ",
                            distance: 5793761.873f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RE",
                            distance: 7828510.809f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LY",
                            distance: 4178317.467f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MU",
                            distance: 8119153.154f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MA",
                            distance: 4057634.876f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "ZW",
                            distance: 5305759.899f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CV",
                            distance: 1779792.459f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "YT",
                            distance: 6539422.205f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "RW",
                            distance: 4630660.277f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EG",
                            distance: 5155618.471f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TZ",
                            distance: 5545573.058f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MZ",
                            distance: 5930379.396f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "DJ",
                            distance: 5946925.568f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "UG",
                            distance: 4858926.536f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BF",
                            distance: 1221604.622f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "DO",
                    name: "Dominican Republic",
                    continent: Some("North America"),
                    other_names: vec![],
                    cable_connections_number: 9usize,
                    internet_exchanges_number: 2usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 1715992.369f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 1877664.028f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 696880.264f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1508332.59f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PE",
                            distance: 3558240.407f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 624534.849f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 877834.163f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 256063.29f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 714110.312f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 1565009.43f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 695339.707f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3343841.947f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 272219.464f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 226451.36f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 4419914.193f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 1680440.825f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 1186427.071f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 716484.788f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 1107767.16f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 1859569.888f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 587411.218f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VI",
                            distance: 381746.517f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5305826.857f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 897129.932f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 1645006.906f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 901153.884f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 782193.085f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 2694641.36f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 1077977.401f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 4378654.671f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 1189911.313f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 1948237.072f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 4129831.092f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 6249230.343f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 963485.92f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 757495.089f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 1268900.881f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 1251533.528f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 1067884.955f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 1135621.741f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 702972.746f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 749182.226f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 1024477.602f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 722358.471f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 844907.595f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "VI",
                    name: "Virgin Islands, U.S.",
                    continent: Some("North America"),
                    other_names: vec!["Virgin Islands (U.S.)"],
                    cable_connections_number: 18usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "CR",
                            distance: 2218902.457f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HN",
                            distance: 2349147.287f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "JM",
                            distance: 1289350.488f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PA",
                            distance: 1878039.659f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PE",
                            distance: 3593929.797f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CU",
                            distance: 1133215.581f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CW",
                            distance: 768186.186f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "PR",
                            distance: 156399.469f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BS",
                            distance: 1393788.482f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BM",
                            distance: 1585113.201f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AI",
                            distance: 193083.245f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "PM",
                            distance: 3306611.689f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "TC",
                            distance: 866992.598f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "HT",
                            distance: 805214.008f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "CA",
                            distance: 4825093.223f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "MX",
                            distance: 3473031.365f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "KY",
                            distance: 1693379.173f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AW",
                            distance: 806019.35f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "SX",
                            distance: 190553.62f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VC",
                            distance: 643677.73f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BZ",
                            distance: 2463107.304f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "VG",
                            distance: 50099.974f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GP",
                            distance: 383027.768f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "US",
                            distance: 2672298.547f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "KN",
                            distance: 227575.668f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MS",
                            distance: 297522.823f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DM",
                            distance: 457547.556f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "TT",
                            distance: 858624.576f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AG",
                            distance: 322557.354f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BL",
                            distance: 208876.269f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "MQ",
                            distance: 530429.03f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BB",
                            distance: 763918.755f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GD",
                            distance: 718665.219f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "LC",
                            distance: 583393.239f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "VE",
                            distance: 827085.321f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GF",
                            distance: 1970519.607f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "BR",
                            distance: 3743481.873f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CO",
                            distance: 2038713.787f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "AR",
                            distance: 6091828.31f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "CL",
                            distance: 5696694.058f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "DO",
                            distance: 381746.517f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "EC",
                            distance: 2842228.198f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "GL",
                            distance: 5322963.5f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "NI",
                            distance: 2079830.758f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "AN",
                            distance: 788463.442f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "BQ",
                            distance: 194675.314f64,
                            link_type: LinkType::Terrestrial,
                        },
                        LinkTo {
                            code: "GT",
                            distance: 2625473.132f64,
                            link_type: LinkType::Terrestrial,
                        }
                    ],
                },
                Country {
                    code: "GG",
                    name: "Guernsey",
                    continent: None,
                    other_names: vec![],
                    cable_connections_number: 6usize,
                    internet_exchanges_number: 0usize,
                    links: vec![
                        LinkTo {
                            code: "UK",
                            distance: 119051.712f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "JE",
                            distance: 32371.021f64,
                            link_type: LinkType::Submarine,
                        },
                        LinkTo {
                            code: "FR",
                            distance: 109606.288f64,
                            link_type: LinkType::Submarine,
                        }
                    ],
                }
            ];
        }
        lazy_static! {
            static ref COUNTRY_CODE_TO_COUNTRY: HashMap<&'static str, usize> = {
                let mut result: HashMap<&str, usize> = HashMap::with_capacity(COUNTRIES.len());
                result.insert("christmas island", 0usize);
                result.insert("cx", 0usize);
                result.insert("dominica", 1usize);
                result.insert("dm", 1usize);
                result.insert("micronesia, federated states of", 2usize);
                result.insert("micronesia", 2usize);
                result.insert("fm", 2usize);
                result.insert("nicaragua", 3usize);
                result.insert("ni", 3usize);
                result.insert("papua new guinea", 4usize);
                result.insert("pg", 4usize);
                result.insert("angola", 5usize);
                result.insert("ao", 5usize);
                result.insert("brunei", 6usize);
                result.insert("bn", 6usize);
                result.insert("tunisia", 7usize);
                result.insert("tn", 7usize);
                result.insert("tonga", 8usize);
                result.insert("to", 8usize);
                result.insert("india", 9usize);
                result.insert("in", 9usize);
                result.insert("portugal", 10usize);
                result.insert("pt", 10usize);
                result.insert("finland", 11usize);
                result.insert("fi", 11usize);
                result.insert("mongolia", 12usize);
                result.insert("mn", 12usize);
                result.insert("trinidad and tobago", 13usize);
                result.insert("tt", 13usize);
                result.insert("bolivia", 14usize);
                result.insert("bo", 14usize);
                result.insert("united states", 15usize);
                result.insert("us", 15usize);
                result.insert("philippines", 16usize);
                result.insert("ph", 16usize);
                result.insert("liechtenstein", 17usize);
                result.insert("li", 17usize);
                result.insert("azerbaijan", 18usize);
                result.insert("az", 18usize);
                result.insert("holy see (vatican city state)", 19usize);
                result.insert("va", 19usize);
                result.insert("palestine", 20usize);
                result.insert("palestinian territory", 20usize);
                result.insert("ps", 20usize);
                result.insert("iran", 21usize);
                result.insert("ir", 21usize);
                result.insert("bulgaria", 22usize);
                result.insert("bg", 22usize);
                result.insert("turkmenistan", 23usize);
                result.insert("tm", 23usize);
                result.insert("bhutan", 24usize);
                result.insert("bt", 24usize);
                result.insert("senegal", 25usize);
                result.insert("sn", 25usize);
                result.insert("greenland", 26usize);
                result.insert("gl", 26usize);
                result.insert("jersey", 27usize);
                result.insert("je", 27usize);
                result.insert("burundi", 28usize);
                result.insert("bi", 28usize);
                result.insert("colombia", 29usize);
                result.insert("co", 29usize);
                result.insert("cook islands", 30usize);
                result.insert("ck", 30usize);
                result.insert("pakistan", 31usize);
                result.insert("pk", 31usize);
                result.insert("united kingdom", 32usize);
                result.insert("gb", 32usize);
                result.insert("uk", 32usize);
                result.insert("cameroon", 33usize);
                result.insert("cm", 33usize);
                result.insert("macao", 34usize);
                result.insert("mo", 34usize);
                result.insert("singapore", 35usize);
                result.insert("sg", 35usize);
                result.insert("puerto rico", 36usize);
                result.insert("pr", 36usize);
                result.insert("haiti", 37usize);
                result.insert("ht", 37usize);
                result.insert("argentina", 38usize);
                result.insert("ar", 38usize);
                result.insert("isle of man", 39usize);
                result.insert("im", 39usize);
                result.insert("switzerland", 40usize);
                result.insert("ch", 40usize);
                result.insert("uganda", 41usize);
                result.insert("ug", 41usize);
                result.insert("romania", 42usize);
                result.insert("ro", 42usize);
                result.insert("mauritius", 43usize);
                result.insert("mu", 43usize);
                result.insert("australia", 44usize);
                result.insert("au", 44usize);
                result.insert("belarus", 45usize);
                result.insert("by", 45usize);
                result.insert("czech republic", 46usize);
                result.insert("cz", 46usize);
                result.insert("gabon", 47usize);
                result.insert("ga", 47usize);
                result.insert("nigeria", 48usize);
                result.insert("ng", 48usize);
                result.insert("northern mariana islands", 49usize);
                result.insert("mp", 49usize);
                result.insert("somalia", 50usize);
                result.insert("so", 50usize);
                result.insert("benin", 51usize);
                result.insert("bj", 51usize);
                result.insert("ghana", 52usize);
                result.insert("gh", 52usize);
                result.insert("bahrain", 53usize);
                result.insert("bh", 53usize);
                result.insert("north macedonia", 54usize);
                result.insert("macedonia", 54usize);
                result.insert("mk", 54usize);
                result.insert("nepal", 55usize);
                result.insert("np", 55usize);
                result.insert("grenada", 56usize);
                result.insert("gd", 56usize);
                result.insert("mexico", 57usize);
                result.insert("mx", 57usize);
                result.insert("israel", 58usize);
                result.insert("il", 58usize);
                result.insert("curaçao", 59usize);
                result.insert("cw", 59usize);
                result.insert("ecuador", 60usize);
                result.insert("ec", 60usize);
                result.insert("morocco", 61usize);
                result.insert("ma", 61usize);
                result.insert("sint maarten", 62usize);
                result.insert("saint martin", 62usize);
                result.insert("sx", 62usize);
                result.insert("ireland", 63usize);
                result.insert("ie", 63usize);
                result.insert("niger", 64usize);
                result.insert("ne", 64usize);
                result.insert("turks and caicos islands", 65usize);
                result.insert("tc", 65usize);
                result.insert("montserrat", 66usize);
                result.insert("ms", 66usize);
                result.insert("venezuela", 67usize);
                result.insert("ve", 67usize);
                result.insert("kazakhstan", 68usize);
                result.insert("kz", 68usize);
                result.insert("virgin islands, british", 69usize);
                result.insert("virgin islands (u.k.)", 69usize);
                result.insert("vg", 69usize);
                result.insert("saint pierre and miquelon", 70usize);
                result.insert("pm", 70usize);
                result.insert("united arab emirates", 71usize);
                result.insert("ae", 71usize);
                result.insert("jordan", 72usize);
                result.insert("jo", 72usize);
                result.insert("italy", 73usize);
                result.insert("it", 73usize);
                result.insert("ivory coast", 74usize);
                result.insert("côte d'ivoire", 74usize);
                result.insert("ci", 74usize);
                result.insert("moldova", 75usize);
                result.insert("md", 75usize);
                result.insert("lithuania", 76usize);
                result.insert("lt", 76usize);
                result.insert("bahamas", 77usize);
                result.insert("bs", 77usize);
                result.insert("lebanon", 78usize);
                result.insert("lb", 78usize);
                result.insert("saint vincent and the grenadines", 79usize);
                result.insert("vc", 79usize);
                result.insert("netherlands antilles", 80usize);
                result.insert("an", 80usize);
                result.insert("libyan arab jamahiriya", 81usize);
                result.insert("libya", 81usize);
                result.insert("ly", 81usize);
                result.insert("togo", 82usize);
                result.insert("tg", 82usize);
                result.insert("lesotho", 83usize);
                result.insert("ls", 83usize);
                result.insert("mayotte", 84usize);
                result.insert("yt", 84usize);
                result.insert("south korea", 85usize);
                result.insert("korea", 85usize);
                result.insert("kr", 85usize);
                result.insert("swaziland", 86usize);
                result.insert("eswatini", 86usize);
                result.insert("sz", 86usize);
                result.insert("slovenia", 87usize);
                result.insert("si", 87usize);
                result.insert("brazil", 88usize);
                result.insert("br", 88usize);
                result.insert("china", 89usize);
                result.insert("cn", 89usize);
                result.insert("indonesia", 90usize);
                result.insert("id", 90usize);
                result.insert("canada", 91usize);
                result.insert("ca", 91usize);
                result.insert("gibraltar", 92usize);
                result.insert("gi", 92usize);
                result.insert("iraq", 93usize);
                result.insert("iq", 93usize);
                result.insert("hong kong", 94usize);
                result.insert("hk", 94usize);
                result.insert("namibia", 95usize);
                result.insert("na", 95usize);
                result.insert("sao tome and principe", 96usize);
                result.insert("st", 96usize);
                result.insert("madagascar", 97usize);
                result.insert("mg", 97usize);
                result.insert("guinea", 98usize);
                result.insert("gn", 98usize);
                result.insert("botswana", 99usize);
                result.insert("bw", 99usize);
                result.insert("reunion", 100usize);
                result.insert("réunion", 100usize);
                result.insert("re", 100usize);
                result.insert("costa rica", 101usize);
                result.insert("cr", 101usize);
                result.insert("south africa", 102usize);
                result.insert("za", 102usize);
                result.insert("estonia", 103usize);
                result.insert("ee", 103usize);
                result.insert("aruba", 104usize);
                result.insert("aw", 104usize);
                result.insert("paraguay", 105usize);
                result.insert("py", 105usize);
                result.insert("fiji islands", 106usize);
                result.insert("fiji", 106usize);
                result.insert("fj", 106usize);
                result.insert("new caledonia", 107usize);
                result.insert("nc", 107usize);
                result.insert("marshall islands", 108usize);
                result.insert("mh", 108usize);
                result.insert("vanuatu", 109usize);
                result.insert("vu", 109usize);
                result.insert("thailand", 110usize);
                result.insert("th", 110usize);
                result.insert("mauritania", 111usize);
                result.insert("mr", 111usize);
                result.insert("rwanda", 112usize);
                result.insert("rw", 112usize);
                result.insert("norway", 113usize);
                result.insert("no", 113usize);
                result.insert("guatemala", 114usize);
                result.insert("gt", 114usize);
                result.insert("antigua and barbuda", 115usize);
                result.insert("ag", 115usize);
                result.insert("malaysia", 116usize);
                result.insert("my", 116usize);
                result.insert("russian federation", 117usize);
                result.insert("russia", 117usize);
                result.insert("ru", 117usize);
                result.insert("kuwait", 118usize);
                result.insert("kw", 118usize);
                result.insert("bangladesh", 119usize);
                result.insert("bd", 119usize);
                result.insert("saint lucia", 120usize);
                result.insert("lc", 120usize);
                result.insert("chile", 121usize);
                result.insert("cl", 121usize);
                result.insert("honduras", 122usize);
                result.insert("hn", 122usize);
                result.insert("uruguay", 123usize);
                result.insert("uy", 123usize);
                result.insert("yemen", 124usize);
                result.insert("ye", 124usize);
                result.insert("belize", 125usize);
                result.insert("bz", 125usize);
                result.insert("tokelau", 126usize);
                result.insert("tk", 126usize);
                result.insert("equatorial guinea", 127usize);
                result.insert("gq", 127usize);
                result.insert("slovakia", 128usize);
                result.insert("slovak republic", 128usize);
                result.insert("sk", 128usize);
                result.insert("myanmar", 129usize);
                result.insert("mm", 129usize);
                result.insert("guinea-bissau", 130usize);
                result.insert("gw", 130usize);
                result.insert("nauru", 131usize);
                result.insert("nr", 131usize);
                result.insert("syria", 132usize);
                result.insert("sy", 132usize);
                result.insert("samoa", 133usize);
                result.insert("ws", 133usize);
                result.insert("malta", 134usize);
                result.insert("mt", 134usize);
                result.insert("guyana", 135usize);
                result.insert("gy", 135usize);
                result.insert("cambodia", 136usize);
                result.insert("kh", 136usize);
                result.insert("luxembourg", 137usize);
                result.insert("lu", 137usize);
                result.insert("saint barthélemy", 138usize);
                result.insert("bl", 138usize);
                result.insert("sri lanka", 139usize);
                result.insert("lk", 139usize);
                result.insert("kyrgyzstan", 140usize);
                result.insert("kg", 140usize);
                result.insert("netherlands", 141usize);
                result.insert("nl", 141usize);
                result.insert("gambia", 142usize);
                result.insert("gm", 142usize);
                result.insert("seychelles", 143usize);
                result.insert("sc", 143usize);
                result.insert("saint helena", 144usize);
                result.insert("sh", 144usize);
                result.insert("croatia", 145usize);
                result.insert("hr", 145usize);
                result.insert("guam", 146usize);
                result.insert("gu", 146usize);
                result.insert("mozambique", 147usize);
                result.insert("mz", 147usize);
                result.insert("sierra leone", 148usize);
                result.insert("sl", 148usize);
                result.insert("uzbekistan", 149usize);
                result.insert("uz", 149usize);
                result.insert("sudan", 150usize);
                result.insert("sd", 150usize);
                result.insert("cayman islands", 151usize);
                result.insert("ky", 151usize);
                result.insert("barbados", 152usize);
                result.insert("bb", 152usize);
                result.insert("bonaire, sint eustatius and saba", 153usize);
                result.insert("sint eustatius and saba", 153usize);
                result.insert("bq", 153usize);
                result.insert("hungary", 154usize);
                result.insert("hu", 154usize);
                result.insert("cape verde", 155usize);
                result.insert("cv", 155usize);
                result.insert("burkina faso", 156usize);
                result.insert("bf", 156usize);
                result.insert("peru", 157usize);
                result.insert("pe", 157usize);
                result.insert("austria", 158usize);
                result.insert("at", 158usize);
                result.insert("montenegro", 159usize);
                result.insert("me", 159usize);
                result.insert("greece", 160usize);
                result.insert("gr", 160usize);
                result.insert("suriname", 161usize);
                result.insert("sr", 161usize);
                result.insert("spain", 162usize);
                result.insert("es", 162usize);
                result.insert("oman", 163usize);
                result.insert("om", 163usize);
                result.insert("congo", 164usize);
                result.insert("cg", 164usize);
                result.insert("palau", 165usize);
                result.insert("pw", 165usize);
                result.insert("american samoa", 166usize);
                result.insert("as", 166usize);
                result.insert("saint kitts and nevis", 167usize);
                result.insert("kn", 167usize);
                result.insert("zimbabwe", 168usize);
                result.insert("zw", 168usize);
                result.insert("solomon islands", 169usize);
                result.insert("sb", 169usize);
                result.insert("georgia", 170usize);
                result.insert("ge", 170usize);
                result.insert("egypt", 171usize);
                result.insert("eg", 171usize);
                result.insert("wallis and futuna", 172usize);
                result.insert("wf", 172usize);
                result.insert("cyprus", 173usize);
                result.insert("cy", 173usize);
                result.insert("afghanistan", 174usize);
                result.insert("af", 174usize);
                result.insert("french guiana", 175usize);
                result.insert("gf", 175usize);
                result.insert("french polynesia", 176usize);
                result.insert("pf", 176usize);
                result.insert("latvia", 177usize);
                result.insert("lv", 177usize);
                result.insert("comoros", 178usize);
                result.insert("km", 178usize);
                result.insert("guadeloupe", 179usize);
                result.insert("gp", 179usize);
                result.insert("maldives", 180usize);
                result.insert("mv", 180usize);
                result.insert("france", 181usize);
                result.insert("fr", 181usize);
                result.insert("serbia", 182usize);
                result.insert("rs", 182usize);
                result.insert("algeria", 183usize);
                result.insert("dz", 183usize);
                result.insert("tanzania", 184usize);
                result.insert("tz", 184usize);
                result.insert("anguilla", 185usize);
                result.insert("ai", 185usize);
                result.insert("denmark", 186usize);
                result.insert("dk", 186usize);
                result.insert("japan", 187usize);
                result.insert("jp", 187usize);
                result.insert("kenya", 188usize);
                result.insert("ke", 188usize);
                result.insert("bermuda", 189usize);
                result.insert("bm", 189usize);
                result.insert("poland", 190usize);
                result.insert("pl", 190usize);
                result.insert("panama", 191usize);
                result.insert("pa", 191usize);
                result.insert("niue", 192usize);
                result.insert("nu", 192usize);
                result.insert("belgium", 193usize);
                result.insert("be", 193usize);
                result.insert("sweden", 194usize);
                result.insert("se", 194usize);
                result.insert("germany", 195usize);
                result.insert("de", 195usize);
                result.insert("new zealand", 196usize);
                result.insert("nz", 196usize);
                result.insert("albania", 197usize);
                result.insert("al", 197usize);
                result.insert("cuba", 198usize);
                result.insert("cu", 198usize);
                result.insert("monaco", 199usize);
                result.insert("mc", 199usize);
                result.insert("turkey", 200usize);
                result.insert("tr", 200usize);
                result.insert("iceland", 201usize);
                result.insert("is", 201usize);
                result.insert("martinique", 202usize);
                result.insert("mq", 202usize);
                result.insert("malawi", 203usize);
                result.insert("mw", 203usize);
                result.insert("kiribati", 204usize);
                result.insert("ki", 204usize);
                result.insert("ukraine", 205usize);
                result.insert("ua", 205usize);
                result.insert("saudi arabia", 206usize);
                result.insert("sa", 206usize);
                result.insert("faroe islands", 207usize);
                result.insert("fo", 207usize);
                result.insert("jamaica", 208usize);
                result.insert("jm", 208usize);
                result.insert("qatar", 209usize);
                result.insert("qa", 209usize);
                result.insert("taiwan", 210usize);
                result.insert("tw", 210usize);
                result.insert("vietnam", 211usize);
                result.insert("vn", 211usize);
                result.insert("djibouti", 212usize);
                result.insert("dj", 212usize);
                result.insert("bosnia and herzegovina", 213usize);
                result.insert("bosnia-herzegovina", 213usize);
                result.insert("ba", 213usize);
                result.insert("liberia", 214usize);
                result.insert("lr", 214usize);
                result.insert("dominican republic", 215usize);
                result.insert("do", 215usize);
                result.insert("virgin islands, u.s.", 216usize);
                result.insert("virgin islands (u.s.)", 216usize);
                result.insert("vi", 216usize);
                result.insert("guernsey", 217usize);
                result.insert("gg", 217usize);
                result
            };
        }
        let lowered = s.to_lowercase();
        COUNTRY_CODE_TO_COUNTRY
            .get(lowered.as_str())
            .map(|index| unsafe { COUNTRIES.get_unchecked(*index) })
    }
}
